@@ -1,22 +1,22 @@
 /*
- 
- *****************************************************************************
- * Author:                                                                   *
- * ------                                                                    *
- *  Anton Kokalj                                  Email: Tone.Kokalj@ijs.si  *
- *  Department of Physical and Organic Chemistry  Phone: x 386 1 477 3523    *
- *  Jozef Stefan Institute                          Fax: x 386 1 477 3811    *
- *  Jamova 39, SI-1000 Ljubljana                                             *
- *  SLOVENIA                                                                 *
- *                                                                           *
- * Source: $XCRYSDEN_TOPDIR/C/cryDispFuncMultiFS.c
- * ------                                                                    *
- * Copyright (c) 1996-2004 by Anton Kokalj                                   *
- *****************************************************************************
+
+*****************************************************************************
+* Author:                                                                   *
+* ------                                                                    *
+*  Anton Kokalj                                  Email: Tone.Kokalj@ijs.si  *
+*  Department of Physical and Organic Chemistry  Phone: x 386 1 477 3523    *
+*  Jozef Stefan Institute                          Fax: x 386 1 477 3811    *
+*  Jamova 39, SI-1000 Ljubljana                                             *
+*  SLOVENIA                                                                 *
+*                                                                           *
+* Source: $XCRYSDEN_TOPDIR/C/cryDispFuncMultiFS.c
+* ------                                                                    *
+* Copyright (c) 1996-2004 by Anton Kokalj                                   *
+*****************************************************************************
 
 */
 
-#include "togl.h"
+#include <togl.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -52,17 +52,19 @@ int
 CRY_DispFuncMultiFSCmd(ClientData clientData,Tcl_Interp *interp,
 		       int argc, char *argv[])
 {
-  struct Togl *togl;
+  Togl *togl;
   NEW_WIN_CONTEXT *wc;
 
   if ( argc < 2 || argc%2 ) {
-    interp->result = "Usage: cry_dispfuncmultiFS <togl> ?-togllist? ?-antialias 0|1?";
+    Tcl_SetResult(interp, "Usage: cry_dispfuncmultiFS <togl> ?-togllist? ?-antialias 0|1?", TCL_STATIC);
     return TCL_ERROR;
   }
 
-  if ( ( togl = Togl_FindTogl(argv[1]) ) == NULL ) {
-    sprintf(interp->result, 
-	    "couldn't find %s togl widget", argv[1]);
+  if ( Togl_GetToglFromName(interp, argv[1], &togl) == TCL_ERROR ) {
+    char rss[1024];
+    snprintf(rss, sizeof(rss), 
+	     "couldn't find %s togl widget", argv[1]);
+    Tcl_SetResult(interp, rss, TCL_VOLATILE);
     return TCL_ERROR;
   }
   wc = FindWinContextByTogl( togl );
@@ -73,10 +75,10 @@ CRY_DispFuncMultiFSCmd(ClientData clientData,Tcl_Interp *interp,
 
   wc->ss.minX = 0.0;
   wc->ss.maxX = 0.0;
-  
+
   wc->ss.minY = 0.0;
   wc->ss.maxY = 0.0;
-  
+
   wc->ss.minZ = 0.0;
   wc->ss.maxZ = 0.0;
 
@@ -98,7 +100,7 @@ CRY_DispFuncMultiFSCmd(ClientData clientData,Tcl_Interp *interp,
       free(wc->fermiContext.toglVector);
       wc->fermiContext.toglVector = NULL;
     }
-  
+
   if (argc > 2) {
     int i, it, anti_alias;
     for (i=2; i<argc; i+=2)
@@ -108,19 +110,21 @@ CRY_DispFuncMultiFSCmd(ClientData clientData,Tcl_Interp *interp,
 	*/
 	if ( strncmp(argv[i], "-togll", 6) == 0 ) {
 	  int argcList;
-	  char **argvList;
+	  const char **argvList;
 	  struct Togl **toglVector;
 	  Tcl_SplitList(interp, argv[i+1], &argcList, &argvList);
 	  toglVector = (struct Togl**) malloc ( sizeof(struct Togl*) * argcList );
 	  for (it=0; it<argcList; it++)
 	    {
 	      NEW_WIN_CONTEXT *ith_wc;
-	      if ( ( toglVector[it] = Togl_FindTogl(argvList[it]) ) == NULL ) {
-		sprintf(interp->result, 
-			"couldn't find %s togl widget", argvList[it]);
+	      if ( Togl_GetToglFromName(interp, argvList[it], &(toglVector[it])) == TCL_ERROR ) {
+		char rss[1024];
+		snprintf(rss, sizeof(rss), 
+			 "couldn't find %s togl widget", argvList[it]);
+		Tcl_SetResult(interp, rss, TCL_VOLATILE);
 		return TCL_ERROR;
 	      }
-	      
+
 	      ith_wc = FindWinContextByTogl( toglVector[it] );
 
 	      if (ith_wc->VPf.stropened) 
@@ -128,10 +132,10 @@ CRY_DispFuncMultiFSCmd(ClientData clientData,Tcl_Interp *interp,
 		  wc->VPf.stropened = 1;
 		  wc->ss.minX = MIN(wc->ss.minX, ith_wc->ss.minX);
 		  wc->ss.maxX = MAX(wc->ss.maxX, ith_wc->ss.maxX);
-		  
+
 		  wc->ss.minY = MIN(wc->ss.minY, ith_wc->ss.minY);
 		  wc->ss.maxY = MAX(wc->ss.maxY, ith_wc->ss.maxY);
-		  
+
 		  wc->ss.minZ = MIN(wc->ss.minZ, ith_wc->ss.minZ);
 		  wc->ss.maxZ = MAX(wc->ss.maxZ, ith_wc->ss.maxZ);
 		}		
@@ -139,24 +143,28 @@ CRY_DispFuncMultiFSCmd(ClientData clientData,Tcl_Interp *interp,
 	  wc->fermiContext.ntogl      = argcList;
 	  wc->fermiContext.toglVector = toglVector;
 	}
-	
+
 	/*
 	  -ANTIALIAS
 	*/
 	else if ( strncmp(argv[i], "-antialias", 6) == 0 ) {
 	  if ( Tcl_GetInt(interp, argv[i+1], &anti_alias) == TCL_ERROR ) {
-	    sprintf(interp->result,"wanted integer, but got \"%s\"", argv[i+1]);
+	    char rss[1024];
+	    snprintf(rss, sizeof(rss),"wanted integer, but got \"%s\"", argv[i+1]);
+	    Tcl_SetResult(interp, rss, TCL_VOLATILE);
 	    return TCL_ERROR;
 	  }
 	  wc->VPf.antialias = anti_alias;
 	} else {
-	  sprintf(interp->result, 
-		  "unknown option %s, must be -antialias or -togllist", argv[i]);
+	  char rss[1024];
+	  snprintf(rss, sizeof(rss), 
+		   "unknown option %s, must be -antialias or -togllist", argv[i]);
+	  Tcl_SetResult(interp, rss, TCL_VOLATILE);
 	  return TCL_ERROR;
 	}
       }
   }
-  
+
   return TCL_OK;
 }
 
@@ -210,7 +218,7 @@ cryDisplayMultiFS(struct Togl *togl)
       enum {
 	XORG, YORG, WID, HT
       }; 
-      
+
       size   = _getSize (wc);
       aspect = (GLfloat) width / (GLfloat) height;
       if ( aspect>1 ) {
@@ -221,20 +229,20 @@ cryDisplayMultiFS(struct Togl *togl)
 	sizeY = size / aspect;
       }
       glGetIntegerv(GL_VIEWPORT, viewport);
-      
+
       sx = 2.0 * sizeX / viewport[WID];
       sy = 2.0 * sizeX / viewport[WID];
-      
+
       min    = -antialias.degree;
       max    = -min + 1;
       count  = -min + max;
       count *= count;
-      
+
       /* uniform scaling, less than one pixel wide */
       scale = -antialias.offset / min;
-      
+
       glClear(GL_ACCUM_BUFFER_BIT);
-      
+
       for (j = min; j < max; j++) {
 	for (i = min; i < max; i++) 
 	  {
@@ -253,7 +261,7 @@ cryDisplayMultiFS(struct Togl *togl)
       }
       glAccum(GL_RETURN, 1.0);
     }
-  
+
   Togl_SwapBuffers(togl);
 }
 
@@ -268,13 +276,13 @@ static void _cryDisplayMultiFS(struct Togl *togl, NEW_WIN_CONTEXT *wc)
   glLoadIdentity();
   glTranslated(0.0, 0.0, -0.5*wc->MVf.structsize); /* see crySetProj.c */
   glMultMatrixd( wc->vec.crdvec );
-  
+
   /* fog */
   xcFog (togl, wc->VPf.fog, GL_FALSE);
 
   glDisable(GL_BLEND); 
   glDepthMask(GL_TRUE);  
-  
+
   for (it=0; it<wc->fermiContext.ntogl; it++)
     {
       NEW_WIN_CONTEXT *ith_wc = FindWinContextByTogl( wc->fermiContext.toglVector[it] );
