@@ -1,22 +1,22 @@
 /*
- 
- *****************************************************************************
- * Author:                                                                   *
- * ------                                                                    *
- *  Anton Kokalj                                  Email: Tone.Kokalj@ijs.si  *
- *  Department of Physical and Organic Chemistry  Phone: x 386 1 477 3523    *
- *  Jozef Stefan Institute                          Fax: x 386 1 477 3811    *
- *  Jamova 39, SI-1000 Ljubljana                                             *
- *  SLOVENIA                                                                 *
- *                                                                           *
- * Source: $XCRYSDEN_TOPDIR/C/crySurf.c
- * ------                                                                    *
- * Copyright (c) 1996-2003 by Anton Kokalj                                   *
- *****************************************************************************
+
+*****************************************************************************
+* Author:                                                                   *
+* ------                                                                    *
+*  Anton Kokalj                                  Email: Tone.Kokalj@ijs.si  *
+*  Department of Physical and Organic Chemistry  Phone: x 386 1 477 3523    *
+*  Jozef Stefan Institute                          Fax: x 386 1 477 3811    *
+*  Jamova 39, SI-1000 Ljubljana                                             *
+*  SLOVENIA                                                                 *
+*                                                                           *
+* Source: $XCRYSDEN_TOPDIR/C/crySurf.c
+* ------                                                                    *
+* Copyright (c) 1996-2003 by Anton Kokalj                                   *
+*****************************************************************************
 
 */
 
-#include "togl.h"
+#include <togl.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -51,111 +51,111 @@ extern float ***cryGeneralGridRegPeriodInterpolator_f_LCASI3D(int n[3], int degr
 static void Set_Orig_and_Size( NEW_WIN_CONTEXT *wc, MOL_SURF *m, 
 			       struct Togl *togl );
 /*
-     -TYPE 
-     -FS
-     -RADIU 
-     -LEVEL 
-     -CUTOFF
-     -COLORSHEME 
-     -DRAWSTYLE 
-     -TRANSPARENT 
-     -SHADEMODEL 
-     -MONOCOLOR 
-     -FRONTMONOCOLOR 
-     -BACKMONOCOLOR 
-     -SURFACETYPE 
-     -RESOLUTION 
-     -SMOOTHSTEPS 
-     -SMOOTHWEIGHT
-     -FRONTFACE
-     -REVERTNORMALS
+  -TYPE 
+  -FS
+  -RADIU 
+  -LEVEL 
+  -CUTOFF
+  -COLORSHEME 
+  -DRAWSTYLE 
+  -TRANSPARENT 
+  -SHADEMODEL 
+  -MONOCOLOR 
+  -FRONTMONOCOLOR 
+  -BACKMONOCOLOR 
+  -SURFACETYPE 
+  -RESOLUTION 
+  -SMOOTHSTEPS 
+  -SMOOTHWEIGHT
+  -FRONTFACE
+  -REVERTNORMALS
 
-     Sample READSURF_OPT struct:
+  Sample READSURF_OPT struct:
 
-     struct READSURF_OPT *ReadSurf_Options = {
-        {"-type",           XC_ALLOWED},
-	{"-fs",             XC_ALLOWED},
-	{"-render",         XC_ALLOWED},
-        {"-radiu", 	    XC_ALLOWED},
-        {"-level", 	    XC_ALLOWED},
-        {"-cutoff"	    XC_ALLOWED},
-        {"-colorsheme",     XC_ALLOWED},
-        {"-drawstyle",      XC_ALLOWED},
-        {"-transparent",    XC_ALLOWED},
-        {"-shademodel",     XC_ALLOWED},
-        {"-monocolor",      XC_ALLOWED},
-        {"-frontmonocolor", XC_ALLOWED},
-        {"-backmonocolor",  XC_ALLOWED},
-        {"-surfacetype",    XC_ALLOWED},
-        {"-resolution",     XC_ALLOWED},
-        {"-smoothsteps",    XC_ALLOWED},
-        {"-smoothweight",   XC_ALLOWED},
-	{"-frontface",      XC_ALLOWED},
-	{"-revertnormals",  XC_ALLOWED},
-	{NULL, NULL}
-     }
+  struct READSURF_OPT *ReadSurf_Options = {
+  {"-type",           XC_ALLOWED},
+  {"-fs",             XC_ALLOWED},
+  {"-render",         XC_ALLOWED},
+  {"-radiu", 	    XC_ALLOWED},
+  {"-level", 	    XC_ALLOWED},
+  {"-cutoff"	    XC_ALLOWED},
+  {"-colorsheme",     XC_ALLOWED},
+  {"-drawstyle",      XC_ALLOWED},
+  {"-transparent",    XC_ALLOWED},
+  {"-shademodel",     XC_ALLOWED},
+  {"-monocolor",      XC_ALLOWED},
+  {"-frontmonocolor", XC_ALLOWED},
+  {"-backmonocolor",  XC_ALLOWED},
+  {"-surfacetype",    XC_ALLOWED},
+  {"-resolution",     XC_ALLOWED},
+  {"-smoothsteps",    XC_ALLOWED},
+  {"-smoothweight",   XC_ALLOWED},
+  {"-frontface",      XC_ALLOWED},
+  {"-revertnormals",  XC_ALLOWED},
+  {NULL, NULL}
+  }
+
+  *** option: -fs { 
+  -gridindex    <index> \
+  -gridsubindex <subindex> \
+  -bandindex    <index> \
+  -celltype     para|bz \
+  -cropbz       0|1  \    
+  -displaycell  0|1 \		    ?  
+  -celldisplaytype     wire|rod|solid  ?
+  -interpolationdegree {n1 n2 n3}
+  -wirecellcolor  {r g b a}
+  -solidcellcolor {r g b a}
+  }
 
-     *** option: -fs { 
-           -gridindex    <index> \
-	   -gridsubindex <subindex> \
-           -bandindex    <index> \
-           -celltype     para|bz \
-	   -cropbz       0|1  \    
-           -displaycell  0|1 \		    ?  
-	   -celldisplaytype     wire|rod|solid  ?
-	   -interpolationdegree {n1 n2 n3}
-	   -wirecellcolor  {r g b a}
-	   -solidcellcolor {r g b a}
-	   }
-                   
 */
 
 /*****************************************************************************
-  cry_surf <togl>   -ident        <identifier>
-                    -type         gauss|exp|unigauss|uniexp|fermisurface \
-		    -fs           {options}
-                    -radius       cov|VdW \
-                    -level        <isoleve> \
-		    -cutoff       <cutoff> \
-                    -colorscheme  atomic|monochrome \
-                    -drawstyle    solid|wire|dot \
-		    -transparent  0|1 \
-		    -shademodel   smooth|flat \
-		    -monocolor      {<r> <g> <b>} \
-                    -frontmonocolor {<r> <g> <b>} \
-                    -backmonocolor" {<r> <g> <b>} \
-		    -surfacetype  molsurf|gap
-		    -resolution   <x> \
-		    -smoothsteps  <steps> \
-		    -smoothweight <weight>
-	            -frontface    CW|CCW
-	            -revertnormals 0|1
+cry_surf <togl>   -ident        <identifier>
+-type         gauss|exp|unigauss|uniexp|fermisurface \
+-fs           {options}
+-radius       cov|VdW \
+-level        <isoleve> \
+-cutoff       <cutoff> \
+-colorscheme  atomic|monochrome \
+-drawstyle    solid|wire|dot \
+-transparent  0|1 \
+-shademodel   smooth|flat \
+-monocolor      {<r> <g> <b>} \
+-frontmonocolor {<r> <g> <b>} \
+-backmonocolor" {<r> <g> <b>} \
+-surfacetype  molsurf|gap
+-resolution   <x> \
+-smoothsteps  <steps> \
+-smoothweight <weight>
+-frontface    CW|CCW
+-revertnormals 0|1
 
-  ADD:
+ADD:
 
-  cry_surfreg <togl>
+cry_surfreg <togl>
 
-  cry_surfconfig <tolg>   -ident <identifier> \
-                          -render 0|1 \
-			  -level <isolevel >
-                          -colorscheme atomic|monochrome \
-                          -drawstyle solid|wire|dot \
-			  -transparent  0|1 \
-			  -shademodel   smooth|flat
-			  -monocolor    {<r> <g> <b>} \			  
-                          -frontmonocolor {<r> <g> <b>} \
-                          -backmonocolor" {<r> <g> <b>} \
-			  -surfacetype  molsurf|gap \
-		          -smoothsteps  <steps> \
-		          -smoothweight <weight>
-  	                  -frontface    CW|CCW
-	                  -revertnormals 0|1
+cry_surfconfig <tolg>   -ident <identifier> \
+-render 0|1 \
+-level <isolevel >
+-colorscheme atomic|monochrome \
+-drawstyle solid|wire|dot \
+-transparent  0|1 \
+-shademodel   smooth|flat
+-monocolor    {<r> <g> <b>} \			  
+-frontmonocolor {<r> <g> <b>} \
+-backmonocolor" {<r> <g> <b>} \
+-surfacetype  molsurf|gap \
+-smoothsteps  <steps> \
+-smoothweight <weight>
+-frontface    CW|CCW
+-revertnormals 0|1
 
 
 
-  preveri se pointerje pri iso. V zacetku jih postavi na NULL, 
-  potem pa v MarchCube, ce niso NULL jih najprej free();
- *****************************************************************************/
+preveri se pointerje pri iso. V zacetku jih postavi na NULL, 
+potem pa v MarchCube, ce niso NULL jih najprej free();
+*****************************************************************************/
 
 int FindSurfaceOfWindow( NEW_WIN_CONTEXT *wc, MOL_SURF *mols )
 { 
@@ -170,7 +170,7 @@ int FindSurfaceOfWindow( NEW_WIN_CONTEXT *wc, MOL_SURF *mols )
 
 int 
 CRY_SurfRegCmd(ClientData clientData,Tcl_Interp *interp,
-	      int argc, char *argv[])
+	       int argc, char *argv[])
 {
   int ident;
   char *result = (char *) Tcl_Alloc((size_t) 10 * sizeof(char));
@@ -179,9 +179,11 @@ CRY_SurfRegCmd(ClientData clientData,Tcl_Interp *interp,
   MOL_SURF *m;
 
   /* find togl associated with toglName */
-  if ( ( togl = Togl_FindTogl(argv[1]) ) == NULL ) {
-    sprintf(interp->result, 
-	    "couldn't find %s togl widget", argv[1]);
+  if ( Togl_GetToglFromName(interp, argv[1], &togl) == TCL_ERROR ) {
+    char rss[1024];
+    snprintf(rss, sizeof(rss), 
+	     "couldn't find %s togl widget", argv[1]);
+    Tcl_SetResult(interp, rss, TCL_VOLATILE);
     return TCL_ERROR;
   }
   wc = FindWinContextByTogl( togl );
@@ -246,9 +248,11 @@ CRY_SurfConfigCmd(ClientData clientData,Tcl_Interp *interp,
   };
 
   /* find togl associated with toglName */
-  if ( ( togl = Togl_FindTogl(argv[1]) ) == NULL ) {
-    sprintf(interp->result, 
-	    "couldn't find %s togl widget", argv[1]);
+  if ( Togl_GetToglFromName(interp, argv[1], &togl) == TCL_ERROR ) {
+    char rss[1024];
+    snprintf(rss, sizeof(rss), 
+	     "couldn't find %s togl widget", argv[1]);
+    Tcl_SetResult(interp, rss, TCL_VOLATILE);
     return TCL_ERROR;
   }
   wc   = FindWinContextByTogl( togl );
@@ -257,21 +261,25 @@ CRY_SurfConfigCmd(ClientData clientData,Tcl_Interp *interp,
   if ( strncmp(argv[2], "-iden", 5) == 0 ) {
     int ident;
     if ( Tcl_GetInt(interp, argv[3], &ident) == TCL_ERROR ) {
-      sprintf(interp->result,"wanted integer, but got \"%s\", while executing %s %s %s %s ...", argv[2], argv[0], argv[1], argv[2], argv[3]);
+      char rss[1024];
+      snprintf(rss, sizeof(rss),"wanted integer, but got \"%s\", while executing %s %s %s %s ...", argv[2], argv[0], argv[1], argv[2], argv[3]);
+      Tcl_SetResult(interp, rss, TCL_VOLATILE);
       return TCL_ERROR;
     }
     mols = FindMolSurf( ident );
     if (!mols) {
-      sprintf(interp->result,"couldn't find MolSurface %d !!!\n",
-	      ident);
+      char rss[1024];
+      snprintf(rss, sizeof(rss),"couldn't find MolSurface %d !!!\n",
+	       ident);
+      Tcl_SetResult(interp, rss, TCL_VOLATILE);
       return TCL_ERROR;
     }
     if (mols->isosurf_index < 0) {
-      interp->result = "cry_surf must be called before cry_surfconfig!!!";
+      Tcl_SetResult(interp, "cry_surf must be called before cry_surfconfig!!!",TCL_STATIC);
       return TCL_ERROR;
     }
   } else {
-    interp->result = "Usage: cry_surfconfig <tolg> -ident indent options ...";
+    Tcl_SetResult(interp, "Usage: cry_surfconfig <tolg> -ident indent options ...",TCL_STATIC);
     return TCL_ERROR;
   }
   fs.gridindex    = mols->fs.gridindex;
@@ -304,7 +312,7 @@ CRY_SurfConfigCmd(ClientData clientData,Tcl_Interp *interp,
        fs.gridsubindex != mols->fs.gridsubindex ||
        fs.bandindex    != mols->fs.bandindex ||
        fs.celltype     != mols->fs.celltype ) {
-    interp->result = "can't change gridindex, gridsubindex, bandindex and celltype by cry_surfconfig command";
+    Tcl_SetResult(interp, "can't change gridindex, gridsubindex, bandindex and celltype by cry_surfconfig command", TCL_STATIC);
     return TCL_ERROR;
   }
 
@@ -329,7 +337,7 @@ CRY_SurfConfigCmd(ClientData clientData,Tcl_Interp *interp,
     if ( mols->interp_n[0] * mols->interp_n[1] * mols->interp_n[2] > 1 ) {
 
       /* mols->interp_molgrid = cryGeneralGridRegPeriodInterpolator_f_LCASI3D (_n, mols->interp_n, mols->molgrid); */
-      
+
       mols->interp_molgrid = general_grid_fft_interpolator_tensor3f(_n, mols->interp_n, mols->molgrid);
       /* mols->interp_molgrid = general_grid_shankland_interpolator_tensor3f(_n, mols->interp_n, mols->molgrid); */
 
@@ -366,8 +374,8 @@ CRY_SurfConfigCmd(ClientData clientData,Tcl_Interp *interp,
   }
   else if ( s_nstep  != iso->smooth_nstep  || s_weight != iso->smooth_weight ) {
     /*
-    xcSurfSmoothing( iso, mols->isolevel );
-    if ( mols->fs.cropbz && mols->fs.celltype == XCR_BZ )
+      xcSurfSmoothing( iso, mols->isolevel );
+      if ( mols->fs.cropbz && mols->fs.celltype == XCR_BZ )
       CropBz_New( wc, iso );
     */
     ;
@@ -385,15 +393,15 @@ CRY_SurfConfigCmd(ClientData clientData,Tcl_Interp *interp,
     if ( mols->fs.cropbz && mols->fs.celltype == XCR_BZ )
       CropBz_New( wc, iso );
   }        
-  
+
   /* HERE GOES THE CROPPING algorithm */
   /* this is the safer, although time demanding */
-  
+
   /*
-  if ( mols->fs.cropbz && mols->fs.celltype == XCR_BZ )
+    if ( mols->fs.cropbz && mols->fs.celltype == XCR_BZ )
     CropBz_New( wc, iso );
   */
-  
+
   if ( !mols->fs.cropbz )
     for(i=0; i<iso->ntriangl; i++)
       iso->triangl_status[i] = 1;
@@ -435,30 +443,38 @@ CRY_SurfCmd(ClientData clientData,Tcl_Interp *interp,
     {"-revertnormals",  XC_ALLOWED},
     {NULL, 0},
   };
-  
+
   /* find togl associated with toglName */
-  if ( ( togl = Togl_FindTogl(argv[1]) ) == NULL ) {
-    sprintf(interp->result, 
-	    "couldn't find %s togl widget", argv[1]);
+  if ( Togl_GetToglFromName(interp, argv[1], &togl) == TCL_ERROR ) {
+    char rss[1024];
+    snprintf(rss, sizeof(rss), 
+	     "couldn't find %s togl widget", argv[1]);
+    Tcl_SetResult(interp, rss, TCL_VOLATILE);
     return TCL_ERROR;
   }
   wc = FindWinContextByTogl( togl );
-  
+
   /* -IDENTIFIER */
   if ( strncmp(argv[2], "-iden", 5) == 0 ) {
     int ident;
     if ( Tcl_GetInt(interp, argv[3], &ident) == TCL_ERROR ) {
-      sprintf(interp->result,"wanted integer, but got \"%s\", while executing %s %s %s %s ...", argv[3], argv[0], argv[1], argv[2], argv[3]);
+      char rss[1024];
+      snprintf(rss, sizeof(rss),"wanted integer, but got \"%s\", while executing %s %s %s %s ...", argv[3], argv[0], argv[1], argv[2], argv[3]);
+      Tcl_SetResult(interp, rss, TCL_VOLATILE);
       return TCL_ERROR;
     }
     mols = FindMolSurf( ident );
     if (!mols) {
-      sprintf(interp->result,"couldn't find Surface %d !!!\n",
-	      ident);
+      char rss[1024];
+      snprintf(rss, sizeof(rss),"couldn't find Surface %d !!!\n",
+	       ident);
+      Tcl_SetResult(interp, rss, TCL_VOLATILE);
       return TCL_ERROR;
     }
   } else {
-    sprintf(interp->result,"Usage: %s <tolg> -ident indent ...", argv[0]);
+    char rss[1024];
+    snprintf(rss, sizeof(rss),"Usage: %s <tolg> -ident indent ...", argv[0]);
+    Tcl_SetResult(interp, rss, TCL_VOLATILE);
     return TCL_ERROR;
   }
 
@@ -480,17 +496,19 @@ CRY_SurfCmd(ClientData clientData,Tcl_Interp *interp,
     wc->recprim_cage = cage;
   } 
   else {
-    interp->result="Sorry, so far just fermisurface type surfaces supported by cry_surf command";
+    Tcl_SetResult(interp, "Sorry, so far just fermisurface type surfaces supported by cry_surf command", TCL_STATIC);
     return TCL_ERROR;
   }
 
-  
+
 
   iso = FindIsoSurf( mols->isosurf_index );
   i = FindSurfaceOfWindow( wc, mols );
   if ( i < 0 ) {
-    sprintf(interp->result, "couldn't find surface #%d on window %s !!!\n",
-	    mols->isosurf_index, argv[1]);  
+    char rss[1024];
+    snprintf(rss, sizeof(rss), "couldn't find surface #%d on window %s !!!\n",
+	     mols->isosurf_index, argv[1]);  
+    Tcl_SetResult(interp, rss, TCL_VOLATILE);
     return TCL_ERROR;
   }
   wc->VPf.surface[i] = 1;
@@ -507,16 +525,16 @@ CRY_SurfCmd(ClientData clientData,Tcl_Interp *interp,
     _n[0] = mols->i;
     _n[1] = mols->j;
     _n[2] = mols->k;
-    
+
     if ( mols->interp_molgrid != (float***) NULL ) {
       xcFree_Tensor3f (mols->interp_molgrid);
       mols->interp_molgrid = (float***) NULL;
     }
-    
+
     /*mols->interp_molgrid = cryRegPeriodInterpolator_f_LCASI3D(_n, mols->interp_n, mols->molgrid);*/
 
     /* mols->interp_molgrid = cryGeneralGridRegPeriodInterpolator_f_LCASI3D (_n, mols->interp_n, mols->molgrid); */
-    
+
     mols->interp_molgrid = general_grid_fft_interpolator_tensor3f(_n, mols->interp_n, mols->molgrid);
 
     /* mols->interp_molgrid = general_grid_shankland_interpolator_tensor3f(_n, mols->interp_n, mols->molgrid); */
@@ -535,7 +553,7 @@ CRY_SurfCmd(ClientData clientData,Tcl_Interp *interp,
 
   /* HERE GOES THE CROPPING algorithm */
   /* this is the safer, although time demanding */
-  
+
   if ( mols->fs.cropbz && mols->fs.celltype == XCR_BZ )
     CropBz_New( wc, iso );  
 
@@ -557,17 +575,17 @@ static void
 Set_Orig_and_Size( NEW_WIN_CONTEXT *wc, MOL_SURF *m, struct Togl *togl )
 {
   int i;
-    
+
   if ( m->fs.celltype == XCR_BZ ) {
     for (i=0; i<3; i++)
       wc->MVf.o_shift[i] = 0.0;
-  
+
     wc->ss.minX = m->lowcoor[0];
     wc->ss.maxX = -wc->ss.minX;	  
-				  
+
     wc->ss.minY = m->lowcoor[1];
     wc->ss.maxY = -wc->ss.minY;	  
-    
+
     wc->ss.minZ = m->lowcoor[2];
     wc->ss.maxZ = -wc->ss.minZ;      
   } else {
@@ -580,14 +598,14 @@ Set_Orig_and_Size( NEW_WIN_CONTEXT *wc, MOL_SURF *m, struct Togl *togl )
       wc->MVf.o_shift[i] = -(m->vec[0][i] + m->vec[1][i] + m->vec[2][i])/2.0;
     }
     /*
-    wc->ss.minX =  wc->MVf.o_shift[0];
-    wc->ss.maxX = -wc->MVf.o_shift[0];
+      wc->ss.minX =  wc->MVf.o_shift[0];
+      wc->ss.maxX = -wc->MVf.o_shift[0];
 
-    wc->ss.minY =  wc->MVf.o_shift[1];
-    wc->ss.maxY = -wc->MVf.o_shift[1];
-    
-    wc->ss.minZ =  wc->MVf.o_shift[2];
-    wc->ss.maxZ = -wc->MVf.o_shift[2];
+      wc->ss.minY =  wc->MVf.o_shift[1];
+      wc->ss.maxY = -wc->MVf.o_shift[1];
+
+      wc->ss.minZ =  wc->MVf.o_shift[2];
+      wc->ss.maxZ = -wc->MVf.o_shift[2];
     */
 
     wc->ss.minX = -size;
