@@ -1,60 +1,72 @@
 /*
- 
- *****************************************************************************
- * Author:                                                                   *
- * ------                                                                    *
- *  Anton Kokalj                                  Email: Tone.Kokalj@ijs.si  *
- *  Department of Physical and Organic Chemistry  Phone: x 386 1 477 3523    *
- *  Jozef Stefan Institute                          Fax: x 386 1 477 3811    *
- *  Jamova 39, SI-1000 Ljubljana                                             *
- *  SLOVENIA                                                                 *
- *                                                                           *
- * Source: $XCRYSDEN_TOPDIR/C/gl2psPrintTogl.c
- * ------                                                                    *
- * Copyright (c) 1996-2003 by Anton Kokalj                                   *
- *****************************************************************************
+
+*****************************************************************************
+* Author:                                                                   *
+* ------                                                                    *
+*  Anton Kokalj                                  Email: Tone.Kokalj@ijs.si  *
+*  Department of Physical and Organic Chemistry  Phone: x 386 1 477 3523    *
+*  Jozef Stefan Institute                          Fax: x 386 1 477 3811    *
+*  Jamova 39, SI-1000 Ljubljana                                             *
+*  SLOVENIA                                                                 *
+*                                                                           *
+* Source: $XCRYSDEN_TOPDIR/C/gl2psPrintTogl.c
+* ------                                                                    *
+* Copyright (c) 1996-2003 by Anton Kokalj                                   *
+*****************************************************************************
 
 */
 
 #include <stdio.h>
 #include <string.h>
-#include "togl.h"
+#include <togl.h>
 #include "gl2ps.h"
 #include "xcfunc.h"
 
+extern struct Togl *mesa_togl;
 extern void (*xcDisplay)(struct Togl *togl); 
 
 /************************************************************************
 
- Tcl-usage: $togl cry_gl2psPrintTogl $format $sort $options $pointsize $linewidth $stream $filename
- 
- Usage: 
+Tcl-usage: cry_gl2psPrintTogl $togl $format $sort $options $pointsize $linewidth $stream $filename
 
- CRY_gl2psPrintToglCb format sort options pointsize linewidth filename
+Usage: 
+
+CRY_gl2psPrintToglCb format sort options pointsize linewidth filename
 
 
 ************************************************************************/
 int 
-CRY_gl2psPrintToglCb(struct Togl *togl, int argc, char *argv[])
+CRY_gl2psPrintToglCb(ClientData clientData, Tcl_Interp *interp,
+		     int argc, const char *argv[])
 {
-  Tcl_Interp *interp = Togl_Interp(togl);
+  Togl *togl;
   FILE  *fp;
   int   argcList, i;
-  char  **argvList;
+  const char  **argvList;
   GLint format, sort, options = GL2PS_NONE;
-  GLint buffersize = Togl_Width (togl) * Togl_Height (togl) * 8;
+  GLint buffersize;
   GLint state = GL2PS_OVERFLOW;
   GLfloat pointsize=2.0, linewidth=2.0;
   GLint viewport[4];
   double num;
 
+  if ( Togl_GetToglFromName(interp, argv[1], &togl) == TCL_ERROR ) {
+    char rss[1024];
+    snprintf(rss, sizeof(rss), 
+	     "couldn't find %s togl widget", argv[3]);
+    Tcl_SetResult(interp, rss, TCL_VOLATILE);
+    return TCL_ERROR;
+  }
+
   if (argc != 8) {
     Tcl_SetResult(interp,
-		  "wrong # args: should be \"toglname cry_gl2psPrintTogl format sort options pointsize linewidth filename\"",
+		  "wrong # args: should be \"cry_gl2psPrintTogl toglname format sort options pointsize linewidth filename\"",
 		  TCL_STATIC);
     return TCL_ERROR;
   }
-  
+
+  buffersize = Togl_Width (togl) * Togl_Height (togl) * 8;
+
   /*
     FORMAT
   */
@@ -66,8 +78,12 @@ CRY_gl2psPrintToglCb(struct Togl *togl, int argc, char *argv[])
     format = GL2PS_TEX;
   } else if ( strcmp(argv[2], "GL2PS_PDF") == 0 ) {
     format = GL2PS_PDF;
+  } else if ( strcmp(argv[2], "GL2PS_SVG") == 0 ) {
+    format = GL2PS_SVG;
   } else {
-    sprintf(interp->result, "wrong format %s, must be one ofGL2PS_PS, GL2PS_EPS, or GL2PS_TEX", argv[2]);
+    char rss[1024];
+    snprintf(rss, sizeof(rss), "wrong format %s, must be one ofGL2PS_PS, GL2PS_EPS, or GL2PS_TEX", argv[2]);
+    Tcl_SetResult(interp, rss, TCL_VOLATILE);
     return TCL_ERROR;
   }
 
@@ -81,7 +97,9 @@ CRY_gl2psPrintToglCb(struct Togl *togl, int argc, char *argv[])
   } else if ( strcmp(argv[3], "GL2PS_BSP_SORT") == 0 ) {
     sort = GL2PS_BSP_SORT;
   } else {
-    sprintf(interp->result, "wrong sort %s, must be one of GL2PS_NO_SORT, GL2PS_SIMPLE_SORT, or GL2PS_BSP_SORT", argv[3]);
+    char rss[1024];
+    snprintf(rss, sizeof(rss), "wrong sort %s, must be one of GL2PS_NO_SORT, GL2PS_SIMPLE_SORT, or GL2PS_BSP_SORT", argv[3]);
+    Tcl_SetResult(interp, rss, TCL_VOLATILE);
     return TCL_ERROR;
   }
 
@@ -111,31 +129,37 @@ CRY_gl2psPrintToglCb(struct Togl *togl, int argc, char *argv[])
     } else if ( strcmp(argvList[i], "GL2PS_NO_BLENDING") == 0 ) {
       options |= GL2PS_NO_BLENDING;
     } else if ( strcmp(argvList[i], "GL2PS_NONE") != 0 ) {
-      sprintf(interp->result, "wrong options %s, must be one of GL2PS_DRAW_BACKGROUND, GL2PS_SIMPLE_LINE_OFFSET, GL2PS_SILENT, GL2PS_BEST_ROOT, GL2PS_OCCLUSION_CULL, GL2PS_NO_TEXT, GL2PS_LANDSCAPE, GL2PS_NO_PS3_SHADING, or GL2PS_NONE", argvList[i]);
+      char rss[1024];
+      snprintf(rss, sizeof(rss), "wrong options %s, must be one of GL2PS_DRAW_BACKGROUND, GL2PS_SIMPLE_LINE_OFFSET, GL2PS_SILENT, GL2PS_BEST_ROOT, GL2PS_OCCLUSION_CULL, GL2PS_NO_TEXT, GL2PS_LANDSCAPE, GL2PS_NO_PS3_SHADING, or GL2PS_NONE", argvList[i]);
+      Tcl_SetResult(interp, rss, TCL_VOLATILE);
       return TCL_ERROR;
     }
   }
-    
+
   /*
-     PointSize
+    PointSize
   */
   if ( Tcl_GetDouble(interp, argv[5], &num) == TCL_ERROR ) {
-    sprintf(interp->result, "wanted double but got %s", argv[5]);
+    char rss[1024];
+    snprintf(rss, sizeof(rss), "wanted double but got %s", argv[5]);
+    Tcl_SetResult(interp, rss, TCL_VOLATILE);
     return TCL_ERROR;
   } else {
     pointsize = (GLfloat) num;    
   }
 
   /*
-     LineWidth
+    LineWidth
   */
   if ( Tcl_GetDouble(interp, argv[6], &num) == TCL_ERROR ) {
-    sprintf(interp->result, "wanted double but got %s", argv[6]);
+    char rss[1024];
+    snprintf(rss, sizeof(rss), "wanted double but got %s", argv[6]);
+    Tcl_SetResult(interp, rss, TCL_VOLATILE);
     return TCL_ERROR;
   } else {
     linewidth = (GLfloat) num;
   }
-    
+
   if ( format == GL2PS_PDF ) {
     fp = fopen(argv[7], "wb");
   } else {
@@ -143,7 +167,9 @@ CRY_gl2psPrintToglCb(struct Togl *togl, int argc, char *argv[])
   }
 
   if ( fp == NULL ) {
-    sprintf(interp->result, "coudn't open file %s", argv[7]);
+    char rss[1024];
+    snprintf(rss, sizeof(rss), "couldn't open file %s", argv[7]);
+    Tcl_SetResult(interp, rss, TCL_VOLATILE);
     return TCL_ERROR;
   }
 
@@ -162,7 +188,7 @@ CRY_gl2psPrintToglCb(struct Togl *togl, int argc, char *argv[])
     gl2psLineWidth (linewidth);  
 
     /**/
-    if ( togl == Togl_FindTogl(".mesa") ) 
+    if ( togl == mesa_togl ) 
       {
 	(*xcDisplay)(togl);  
       }
@@ -178,7 +204,7 @@ CRY_gl2psPrintToglCb(struct Togl *togl, int argc, char *argv[])
     buffersize *= 2;
   }
   fclose(fp);
-  
+
   return TCL_OK;
 }
 
