@@ -222,7 +222,7 @@ gradient_SurfNmlNew(float origin[],
     {1,0,1}
   };
 
-  fprintf(stderr,"gradient_SurfNmlNew used,             normals address=%d\n", nml);
+  /*fprintf(stderr,"gradient_SurfNmlNew used,             normals address=%ld\n", nml);*/
   
   for(iv=0; iv<nvertex; iv++) 
     {
@@ -360,7 +360,7 @@ gradient_SurfNmlNew(float origin[],
   
   for(iv=0; iv<nvertex; iv++)
     {
-      normalizeXYZ( &nml[iv] );      
+      normalizeXYZ( &nml[iv] );
     }
 
   /* for(it=0; it<ntriangl; it++)  */
