@@ -47,7 +47,7 @@ void
 xcRenderIsosurf(int obj)
 {
   register int j, ix, iy, iz, j3;
-  int index;
+  int is_solid, index, ind[3] = {0, 1, 2};
   GLuint i;
   GLint shade_model;
   GLboolean switch_shademodel = GL_FALSE;
@@ -73,6 +73,13 @@ xcRenderIsosurf(int obj)
     switch_lightmodel = GL_TRUE;
     glLightModelfv( GL_LIGHT_MODEL_TWO_SIDE, lightmodel.two_side_iso );
   }
+
+  /* isosurface render-style */
+  if ( isoDisp.drawstyle == ISOSURF_SOLID ) {
+    is_solid = MAT_SOLID;
+  } else {
+    is_solid = 0;
+  }
   
   /****************************************************/
   /* load isosurf's material properties               */
@@ -90,9 +97,16 @@ xcRenderIsosurf(int obj)
     } else if ( isodata.nlevel == 2 && j == 0 ) {
       LoadIsoMaterial( MAT_POSLEVEL | MAT_ISOSURF );
     } else if ( isodata.nlevel == 2 && j == 1 ) {
-      LoadIsoMaterial( MAT_NEGLEVEL | MAT_ISOSURF );
+      LoadIsoMaterial( MAT_NEGLEVEL | MAT_ISOSURF | is_solid );
     }
 
+    /* t.k. */
+    if ( isodata.cell_orientation == XC_RIGHT ) {
+      ind[0] = 2;
+      ind[1] = 1;
+      ind[2] = 0;
+    }
+       
     /* RENDER */
     glPushMatrix();
       glTranslated( -mx + isodata.points[obj][0][0], 
@@ -119,7 +133,7 @@ xcRenderIsosurf(int obj)
 		glBegin( GL_TRIANGLES );  
 		  for (i=0; i<surf.numT[j]; i++) {
 		    for (j3=0; j3<3; j3++) {
-		      index = tri2verIN[j][i].ver_ind[j3];		    
+		      index = tri2verIN[j][i].ver_ind[ind[j3]];		    
 		      glNormal3fv( &(normal[j][index].x) );
 		      glVertex3fv( &(vertex[j][index].x) );
 		    }
