@@ -727,16 +727,19 @@ LoadIsoMaterial(int type)
     glMaterialfv(back, GL_EMISSION,
 		 back_mat_pos_isosurf[isoDisp.transparent].emission);
   }
-    
-  if ( type == (MAT_NEGLEVEL | MAT_ISOSURF) ) {
+  
+  if ( type == (MAT_NEGLEVEL | MAT_ISOSURF)
+       || type == (MAT_NEGLEVEL | MAT_ISOSURF | MAT_SOLID) ) {
     GLenum front = GL_FRONT, back  = GL_BACK;
     GLint twoside_lighting;
     glGetIntegerv (GL_LIGHT_MODEL_TWO_SIDE, &twoside_lighting);
 
     if ( twoside_lighting ) {
-      if ( frontface_isosurf[GLPAR_FACE_WHAT_ISOSURF_NEG] == GL_CCW ) {
-	back  = GL_FRONT;
-	front = GL_BACK;
+      if ( type & MAT_SOLID ) {
+        if ( frontface_isosurf[GLPAR_FACE_WHAT_ISOSURF_NEG] == GL_CCW ) {
+          back  = GL_FRONT;
+          front = GL_BACK;
+        }
       }
     } else {
       if ( frontface_isosurf[GLPAR_FACE_WHAT_ISOSURF_NEG] == GL_CW ) {
