@@ -16,7 +16,7 @@
 
 */
 
-#include "togl.h"
+#include <togl.h>
 #include <stdio.h>
 #include <math.h>
 #include "struct.h" 
@@ -63,6 +63,7 @@ void LoadNewValue(struct Togl *togl, int var, double value1, double value2,
 		  double value3, double value4);
 double GetDefault(int var);
 double GetValue(int var);
+void LoadOldAtomicColors(void);
 
 /* --- xcDisplayFunc.c --- */
 /* extern void (*xcDisplay)(void); */
@@ -211,7 +212,7 @@ DefValues(void)
     hbonds.H_like_list = (int*) xcCalloc((size_t)2, sizeof(int));
   }
   if ( !hbonds.O_like_list ) {
-    hbonds.O_like_list = (int*) xcCalloc((size_t)5, sizeof(int));
+    hbonds.O_like_list = (int*) xcCalloc((size_t)6, sizeof(int));
   }
   hbonds.H_like_list[0] = 1;  /* Hydrogen    */
   hbonds.H_like_list[1] = 0;  /* end-of-list */
@@ -219,8 +220,9 @@ DefValues(void)
   hbonds.O_like_list[0] = 7;  /* Nitrogen    */
   hbonds.O_like_list[1] = 8;  /* Oxygen      */
   hbonds.O_like_list[2] = 9;  /* Fluorine    */
-  hbonds.O_like_list[3] = 17; /* Chlorine    */
-  hbonds.O_like_list[4] = 0;  /* end-of-list */
+  hbonds.O_like_list[3] = 16; /* Sulfur     */
+  hbonds.O_like_list[4] = 17; /* Chlorine    */
+  hbonds.O_like_list[5] = 0;  /* end-of-list */
 
   COPY_V(4, xyz.axis_color,    def_xyz_axis_color);
   COPY_V(4, xyz.xyplane_color, def_xyz_xyplane_color);
@@ -254,7 +256,7 @@ ResetVar(struct Togl *togl, int var)
 {
   int i,j;
   GLuint remake3D = REMAKE3D_NONE;
-
+    
   switch(var)
     {
     case R_ATRAD:
@@ -311,7 +313,7 @@ ResetVar(struct Togl *togl, int var)
       break;
 
     case R_FOG:
-      if ( togl == Togl_FindTogl(".mesa") ) {
+      if ( togl == mesa_togl ) {
 	VPf.fog = DEF_FOG;
       } else {
 	NEW_WIN_CONTEXT *wc;
@@ -325,7 +327,7 @@ ResetVar(struct Togl *togl, int var)
       break;
       
     case R_ANTIALIAS:
-      if ( togl == Togl_FindTogl(".mesa") ) {
+      if ( togl == mesa_togl ) {
 	VPf.antialias = DEF_ANTIALIAS;
       } else {
 	NEW_WIN_CONTEXT *wc;
@@ -606,7 +608,7 @@ LoadNewValue(struct Togl *togl, int var, double value1, double value2,
       break;      
 
     case L_FOG:
-      if ( togl == Togl_FindTogl(".mesa") ) {
+      if ( togl == mesa_togl ) {
 	VPf.fog = (GLboolean) value1;
       } else {
 	NEW_WIN_CONTEXT *wc;
@@ -620,7 +622,7 @@ LoadNewValue(struct Togl *togl, int var, double value1, double value2,
       break;
 
     case L_ANTIALIAS:
-      if ( togl == Togl_FindTogl(".mesa") ) {
+      if ( togl == mesa_togl ) {
 	VPf.antialias = (GLboolean) value1;
       } else {
 	NEW_WIN_CONTEXT *wc;
@@ -796,7 +798,7 @@ LoadNewValue(struct Togl *togl, int var, double value1, double value2,
       return;
 
     case L_BACKGROUND:
-      if ( togl == Togl_FindTogl(".mesa") ) {
+      if ( togl == mesa_togl ) {
 	bg[0] = value1;
 	bg[1] = value2;
 	bg[2] = value3;
@@ -1197,5 +1199,12 @@ GetValue(int var)
 } 
 
 
-
-
+void
+LoadOldAtomicColors(void)
+{
+  int i,j;  
+  for(i=0; i <= MAXNAT; i++)
+    for(j=0; j < 3; j++)
+      atcol[i][j] = DefAtColOld[i][j];    
+  LoadAtmCol(0);
+}
