@@ -32,7 +32,7 @@
 #include "memory.h"
 #include "xcfunc.h"
 
-#define MINTOL 1e-12
+#define MINTOL_P 1e-12
 #define FLOAT_MINTOL  3.0e-8
 #define ASSIGN_GRID2IJK(a,b) a.i = b.ix; a.j = b.iy; a.k = b.iz
 #define EQUAL_VERTICES(a,b)    ( (fabs(a.x-b.x) < FLOAT_MINTOL && fabs(a.y-b.y) < FLOAT_MINTOL && fabs(a.z-b.z) < FLOAT_MINTOL) )
@@ -298,10 +298,20 @@ MarchingCubes(float isolevel,
   sign_P            = sign;
   ver2triIN_P       = ver2triIN;
 
-  for (i=0; i<surf.numV[ilevel]; i++) {
-    /* t.k: it seems that we must revert normals if isolevel is negative */
-    if ( isolevel < 0.0 ) 
-      RevertVectorfv( (float *) &(normal[ilevel][i]) );    
+  /* t.k: there is a mass concerning the orientation of normals; try to remedy it */
+  
+  if ( normals_model == ISOSURF_NORMALS_TRIANGLE && isodata.cell_orientation == XC_LEFT ) {
+    if ( isolevel < 0.0 ) {
+      /* t.k: it seems that we must revert normals if isolevel is negative */
+      for (i=0; i<surf.numV[ilevel]; i++) 
+        RevertVectorfv( (float *) &(normal[ilevel][i]) );          
+    }
+  } else {
+    if ( isolevel > 0.0 ) {
+      /* t.k: it seems that we must revert normals if isolevel is positive */
+      for (i=0; i<surf.numV[ilevel]; i++) 
+        RevertVectorfv( (float *) &(normal[ilevel][i]) );          
+    }
   }
 }
 
@@ -729,17 +739,17 @@ XYZ VertexInterp(float isolevel, XYZ p1, XYZ p2, float valp1, float valp2)
 /*     return(p2); */
 /*   } */
 
-  if (ABS(valp1-valp2) < MINTOL) {
-    fprintf(stderr, "polygonise_vertex_interp: valp1 == valp2 occured !!!\n");
+  if (ABS(valp1-valp2) < MINTOL_P) {
+    /*fprintf(stderr, "polygonise_vertex_interp: valp1 == valp2 occurred !!!\n");*/
     p.x = 0.5 * (p2.x + p1.x);
     p.y = 0.5 * (p2.y + p1.y);
     p.z = 0.5 * (p2.z + p1.z);
     return(p);
-  } else if (ABS(isolevel-valp1) < MINTOL) {
-    fprintf(stderr, "polygonise_vertex_interp: valp1 == isolevel occured !!!\n");
+  } else if (ABS(isolevel-valp1) < MINTOL_P) {
+    /*fprintf(stderr, "polygonise_vertex_interp: valp1 == isolevel occurred !!!\n");*/
     return(p1);
-  } else if (ABS(isolevel-valp2) < MINTOL) {
-    fprintf(stderr, "polygonise_vertex_interp: valp2 == isolevel occured !!!\n");
+  } else if (ABS(isolevel-valp2) < MINTOL_P) {
+    /*fprintf(stderr, "polygonise_vertex_interp: valp2 == isolevel occurred !!!\n");*/
     return(p2);
   }
 
