@@ -270,7 +270,7 @@ SurfNmlAver(int       ntriangl,
   register int i, j3;
   XYZ norm;
 
-  fprintf(stderr,"        SurfNmlAver used,             normals address=%d\n", nml);
+  /*fprintf(stderr,"        SurfNmlAver used,             normals address=%ld\n", nml);*/
 
   /* NORMAL AVERAGING */
   for(i=0; i<nvertex; i++)
@@ -280,7 +280,7 @@ SurfNmlAver(int       ntriangl,
 
     /* for tetrahedral the sign should be allocated ! */
 
-    if ( sign = NULL ) abort();
+    if ( sign == NULL ) abort();
 
     for(i=0; i<ntriangl; i++) {
       /* next line for the sake of surface simplification */
