@@ -44,7 +44,7 @@ extern char        *element[];
 extern ForceVector FV;
 
 /* FUNCTION PROTOTYPES */
-int ReadStructFile(FILE *fp, char *file, int format, int mode);
+int ReadStructFile(FILE *fp, const char *file, int format, int mode);
 void MakeBonds(void);
 void MallocCoor(void);
 void FreeCoor(void);
@@ -55,7 +55,7 @@ static int ReadAtoms( FILE *fp , long int atompos );
 static int ReadFrames( FILE *fp , long int framepos );
 static int ReadVoronoi(FILE *fp, float poly[][WIGNERSEITZ_MAXVERTEX][3], 
 		       float norm[][WIGNERSEITZ_MAXVERTEX][3], int nvert[],
-		       float *Max, boolean *xcrl);
+		       float *Max, boolean *xcrl, int *npoly);
 void FindMaxRad(void);
 static void CorrectVectors( double vec[][4], int dim );
 static void CheckAtoms(int *flag1, int *nat1, 
@@ -113,12 +113,11 @@ extern void breakpoint(const char *text);
 
 
 int 
-ReadStructFile(FILE *fp, char *file, int format, int mode)
+ReadStructFile(FILE *fp, const char *file, int format, int mode)
 {
   register int i, j; 
-  /*double fabs();*/
-  double sumx = 0.0, sumy = 0.0, sumz = 0.0; 
-  /*int    xmaxnat, ymaxnat, zmaxnat;*/
+  double sumx = 0.0, sumy = 0.0, sumz = 0.0, vsize1 = 0.0, vsize2 = 0.0;
+  double v1[3], v2[3], v3[3];
   GLboolean latom;
 
   vec.prim[0][0] = vec.prim[1][1] = vec.prim[2][2] = vec.prim[3][3] =
@@ -182,11 +181,6 @@ ReadStructFile(FILE *fp, char *file, int format, int mode)
       fprintf(stderr,"\"%s\"\n",file);
       return XC_ERROR;
     }
-  if ( format == FORMAT_CHARMM )
-    /* insert "readCRD" here */
-    return XC_ERROR;
-  
-
 
   /* MOVING TO GEOMETRICAL-MASS-CENTER */
   for(i = 1; i <= natoms; i++)
@@ -232,7 +226,8 @@ ReadStructFile(FILE *fp, char *file, int format, int mode)
     if (ABS (yat[i]) > max.y) max.y = ABS (yat[i]);
     if (ABS (zat[i]) > max.z) max.z = ABS (zat[i]);
 
-    /* determine which elements are in structure */
+    /* determine which atomic elements are in structure */
+    
     for(j=0; j<atm.natomkind; j++) 
       if ( nat[i] == atm.atomkind[j] ) latom = 1;
     if (!latom) {
@@ -278,9 +273,10 @@ ReadStructFile(FILE *fp, char *file, int format, int mode)
   /* structure is sqrt( max.x^2 + max.y^2 + max.z^2 ) 
    */
   MVf.structsize = sqrt( max.x * max.x + max.y * max.y + max.z * max.z );
-
+  
   /* ---- MAKE BONDS ---- */
   MakeBonds();  
+
   /* ---- MAKE Hydrogen Bonds ---- */
   make_H_Bonds();
   
@@ -297,16 +293,45 @@ ReadStructFile(FILE *fp, char *file, int format, int mode)
   
   /* --- now calculate coordinates for 3Dbonds & 3Dframes --- */
   MakeCylinderCoor();
+
   /* --- if we come so far everything is OK --- */  
 
   /***********************************************************/
-  /* all data were read, but
-   * maybe we do not have crystal & some vectors that were just 
-   * read are meaningless
-   */
-  if ( xcr.lprimvec ) CorrectVectors( vec.prim, xcr.dim );
-  if ( xcr.lconvvec ) CorrectVectors( vec.conv, xcr.dim );
 
+  /* correct the structusize also according to "crystal cages"; take
+     the largest of PRIMVEC and CONVEC, so that when shifting between
+     the two CELL displays the structure will not "size-breath"
+   */
+
+  vsize1 = 0.0;
+  vsize2 = 0.0;
+  
+  if ( xcr.lprimvec ) {
+    
+    CorrectVectors( vec.prim, xcr.dim );
+    
+    for (i=0; i<3; i++) {
+      v1[i] = (xcr.nunit[0] <= 1 ? 1.0 : (double)xcr.nunit[0]) * vec.prim[0][i];
+      v2[i] = (xcr.nunit[1] <= 1 ? 1.0 : (double)xcr.nunit[1]) * vec.prim[1][i];
+      v3[i] = (xcr.nunit[2] <= 1 ? 1.0 : (double)xcr.nunit[2]) * vec.prim[2][i];
+    }
+    vsize1 = papipedMaxDiagSize ( v1, v2, v3 );
+  }
+  if ( xcr.lconvvec ) {
+    
+    CorrectVectors( vec.conv, xcr.dim );
+
+    for (i=0; i<3; i++) {
+      v1[i] = (xcr.nunit[0] <= 1 ? 1.0 : (double)xcr.nunit[0]) * vec.conv[0][i];
+      v2[i] = (xcr.nunit[1] <= 1 ? 1.0 : (double)xcr.nunit[1]) * vec.conv[1][i];
+      v3[i] = (xcr.nunit[2] <= 1 ? 1.0 : (double)xcr.nunit[2]) * vec.conv[2][i];
+    }      
+    vsize2 = papipedMaxDiagSize ( v1, v2, v3 );
+  }
+  
+  vsize1 = ( vsize1 > vsize2 ? vsize1 : vsize2 );
+  MVf.structsize = ( vsize1 > MVf.structsize ? vsize1 : MVf.structsize );
+  
   return XC_OK;
 }
 
@@ -570,34 +595,52 @@ ReadXSF(FILE *fp)
 	else if ( strncmp(line,"nunit",5) == 0 ) {
 	  n = fscanf(fp,"%d %d %d", 
 		     &xcr.nunit[0], &xcr.nunit[1], &xcr.nunit[2]);
-	  if ( n != 3 ) return XC_ERROR;
+	  if ( n != 3 ) {
+	    fprintf(stderr, "error parsing INFO.nunit ");
+	    return XC_ERROR;
+	  }
 	}
 	else if ( strncmp(line,"shape",5) == 0 ) {
-	  if ( (n = fscanf(fp,"%s", word)) != 1 ) 
+	  if ( (n = fscanf(fp,"%s", word)) != 1 ) {
+	    fprintf(stderr, "error parsing INFO.shape ");	 
 	    return XC_ERROR;
+	  }
 	  if ( strncmp(word,"para",4) == 0 ) 
-	    xcr.shape = XCR_PARAPIPEDAL;
+	    xcr.shape = XCR_PARAPIPEDAL;	  
 	  else if ( strncmp(word,"hexa",4) == 0 ) 
 	    xcr.shape = XCR_HEXAGONAL;
-	  else return XC_ERROR;
+	  else {
+	    fprintf(stderr, "error parsing INFO.shape value ");	  
+	    return XC_ERROR;
+	  }
 	}
 	else if ( strncmp(line,"unit",4) == 0 ) {
-	  if ( (n = fscanf(fp,"%s", word)) != 1 ) 
+	  if ( (n = fscanf(fp,"%s", word)) != 1 ) {
+	    fprintf(stderr, "error parsing INFO.unit ");	  
 	    return XC_ERROR;
+	  }
 	  if ( strncmp(word,"cell",4) == 0 ) 
 	    xcr.shape = XCR_CELL;
 	  else if ( strncmp(word,"tr_a",4) == 0 ) 
 	    xcr.shape = XCR_TR_ASYM;
-	  else return XC_ERROR;
+	  else {
+	    fprintf(stderr, "error parsing INFO.unit section ");	  
+	    return XC_ERROR;
+	  }
 	}
 	else if ( strncmp(line,"celltype",8) == 0 ) {
-	  if ( (n = fscanf(fp,"%s", word)) != 1 ) 
+	  if ( (n = fscanf(fp,"%s", word)) != 1 ) {
+	    fprintf(stderr, "error parsing INFO.celltype ");	  
 	    return XC_ERROR;
+	  }
 	  if ( strncmp(word,"prim",4) == 0 ) /* primitiv cell; "primcell" */
 	    xcr.celltype = XCR_PRIMCELL;
 	  else if ( strncmp(word,"conv",4) == 0 ) /* "convcell" */
 	    xcr.celltype = XCR_CONVCELL;
-	  else return XC_ERROR;
+	  else {
+	    fprintf(stderr, "error parsing INFO.celltype section ");	  
+	    return XC_ERROR;
+	  }
 	}	
 	else if ( strncmp(line,"#",1) == 0 ) {
 	  /* comment inside INFO record; read the rest of the line */
@@ -612,7 +655,10 @@ ReadXSF(FILE *fp)
 		  strncmp(line,"INFO_END",8) == 0) {
 	  ;
 	}
-	else return XC_ERROR;
+	else {
+	  fprintf(stderr, "error parsing INFO section ");	  
+	  return XC_ERROR;
+	}
       } while( strncmp(line,"END_INFO",8) != 0 &&
 	       strncmp(line,"INFO_END",8) != 0 );
     }
@@ -728,42 +774,46 @@ ReadXSF(FILE *fp)
     else if ( strncmp(line,"WIGNER-SEITZ-PRIMCELL",21) == 0 ) {
       latom = 0; 
       lframe = 0;
-      if ( (wsp.npoly = 
-	    ReadVoronoi(fp, wsp.poly, wsp.norm, wsp.nvert, 
-			&(wsp.max), &(xcr.lprimwigner))) == XC_ERROR )
+      if ( ReadVoronoi(fp, wsp.poly, wsp.norm, wsp.nvert, 
+		       &(wsp.max), &(xcr.lprimwigner), &wsp.npoly) == XC_ERROR ) {
+	fprintf(stderr, "error parsing WIGNER-SEITZ-PRIMCELL ");	  
 	return XC_ERROR;
+      }
     }
 
     /* if WIGNER-SEITZ-CONVCELL */
     else if ( strncmp(line,"WIGNER-SEITZ-CONVCELL",21) == 0 ) {
       latom = 0; 
       lframe = 0;
-      if ( (wsc.npoly = 
-	    ReadVoronoi(fp, wsc.poly, wsc.norm, wsc.nvert, 
-			&(wsc.max), &(xcr.lconvwigner))) == XC_ERROR )
+      if ( ReadVoronoi(fp, wsc.poly, wsc.norm, wsc.nvert, 
+		       &(wsc.max), &(xcr.lconvwigner), &wsc.npoly) == XC_ERROR ) {
+	fprintf(stderr, "error parsing WIGNER-SEITZ-CONVCELL ");
 	return XC_ERROR;
+      }
     }
 
     /* if BRILLOUIN-ZONE-PRIMCELL */
     else if ( strncmp(line,"BRILLOUIN-ZONE-PRIMCELL",23) == 0 ) {
       latom = 0; 
       lframe = 0;
-      if ( (bz[BZ_PRIMCELL].npoly = 
-	    ReadVoronoi(fp, bz[BZ_PRIMCELL].poly, bz[BZ_PRIMCELL].norm, 
-			bz[BZ_PRIMCELL].nvert, &(bz[BZ_PRIMCELL].max), 
-			&(xcr.lprimbz))) == XC_ERROR )
+      if ( ReadVoronoi(fp, bz[BZ_PRIMCELL].poly, bz[BZ_PRIMCELL].norm, 
+		       bz[BZ_PRIMCELL].nvert, &(bz[BZ_PRIMCELL].max), 
+		       &(xcr.lprimbz), &(bz[BZ_PRIMCELL].npoly)) == XC_ERROR ) {
+	fprintf(stderr, "error parsing BRILLOUIN-ZONE-PRIMCELL ");	  
 	return XC_ERROR;
+      }
     }
 
     /* if BRILLOUIN-ZONE-CONVCELL */
     else if ( strncmp(line,"BRILLOUIN-ZONE-CONVCELL",23) == 0 ) {
       latom = 0; 
       lframe = 0;
-      if ( (bz[BZ_CONVCELL].npoly = 
-	    ReadVoronoi(fp, bz[BZ_CONVCELL].poly, bz[BZ_CONVCELL].norm, 
-			bz[BZ_CONVCELL].nvert, &(bz[BZ_CONVCELL].max), 
-			&(xcr.lconvbz))) == XC_ERROR )
+      if ( ReadVoronoi(fp, bz[BZ_CONVCELL].poly, bz[BZ_CONVCELL].norm, 
+		       bz[BZ_CONVCELL].nvert, &(bz[BZ_CONVCELL].max), 
+		       &(xcr.lconvbz), &(bz[BZ_CONVCELL].npoly)) == XC_ERROR ) {
+	fprintf(stderr, "error parsing BRILLOUIN-ZONE-CONVCELL ");	  
 	return XC_ERROR;
+      }
     }
 
     /* if PRIMCOORD */
@@ -781,6 +831,7 @@ ReadXSF(FILE *fp)
       fprintf(stderr,"reading PRIMCOORD\n");
       if ( ReadCoor( fp, xcr.natr, 1, XCR_PRIMCELL ) == XC_ERROR ) {
 	/*xcFree((void*)line);*/
+	fprintf(stderr, "error parsing PRIMCOORD ");
 	return XC_ERROR;
       }
       lend = 1;
@@ -802,6 +853,7 @@ ReadXSF(FILE *fp)
       fprintf(stderr,"reading CONVCOORD\n");
       if ( ReadCoor( fp, xcr.natr, xcr.ncell, XCR_CONVCELL ) == XC_ERROR ) {
 	/*xcFree((void*)line);*/
+	fprintf(stderr, "error parsing CONVCOORD ");
 	return XC_ERROR;
       }
       lend = 1;
@@ -844,12 +896,18 @@ ReadXSF(FILE *fp)
       lframe = 0;
       lend = 1;
       /* read comment line */
-      if ( (c = fscanf(fp, LINE_FMT, line)) == EOF) return XC_ERROR;
+      if ( (c = fscanf(fp, LINE_FMT, line)) == EOF) {
+	fprintf(stderr, "error parsing BLOCK_DATAGRID2D section (#1) ");	  
+	return XC_ERROR;
+      }
       SetDataGridCommentLine( line );
       gridFP = MaybeOpenDataGridFile("w");
       NewGridList( DATAGRID_2D, gridFP );
       /* read DATAGRID_2D_XXX line */
-      if ( (c = fscanf(fp,"%s\n",line)) == EOF) return XC_ERROR;
+      if ( (c = fscanf(fp,"%s\n",line)) == EOF) {
+	fprintf(stderr, "error parsing BLOCK_DATAGRID_2D section (#2) ");	  
+	return XC_ERROR;
+      }
       while (strncmp(line, "END_BLOCK_DATAGRID2D", 20) != 0 &&
 	     strncmp(line, "END_BLOCK_DATAGRID_2D", 21) != 0 ) {
 	if ( strncmp(line, "DATAGRID_2D_", 12) == 0 ||
@@ -862,12 +920,24 @@ ReadXSF(FILE *fp)
 	  }
 	  /* read END_DATAGRID_2D line */
 	  breakpoint("breakpoint");
-	  if ( (c = fscanf(fp,"%s\n",line)) == EOF) return XC_ERROR;
+	  if ( (c = fscanf(fp,"%s\n",line)) == EOF) {
+	    fprintf(stderr, "error parsing BLOCK_DATAGRID_2D section (#3) ");	  
+	    return XC_ERROR;
+	  }
 	  if ( strncmp(line, "END_DATAGRID_2D", 15) != 0 &&
-	       strncmp(line, "END_DATAGRID2D", 14) != 0 ) return XC_ERROR;
-	} else return XC_ERROR;
+	       strncmp(line, "END_DATAGRID2D", 14) != 0 ) {
+	    fprintf(stderr, "expecting END_DATAGRID_2D keyword, but it wasn't found ");
+	    return XC_ERROR;
+	  }
+	} else {
+	  fprintf(stderr, "error parsing BLOCK_DATAGRID_2D section (#4) ");
+	  return XC_ERROR;
+	}
 	/* read next line */ 
-	if ( (c = fscanf(fp,"%s\n",line)) == EOF) return XC_ERROR;
+	if ( (c = fscanf(fp,"%s\n",line)) == EOF) {
+	  fprintf(stderr, "premature end of file in BLOCK_DATAGRID_2D section ");
+	  return XC_ERROR;
+	}
       }
       xcr.ldatagrid2D = 1;
     }
@@ -879,12 +949,18 @@ ReadXSF(FILE *fp)
       lframe = 0;
       lend = 1;
       /* read comment line */
-      if ( (c = fscanf(fp, LINE_FMT, line)) == EOF) return XC_ERROR;
+      if ( (c = fscanf(fp, LINE_FMT, line)) == EOF) {
+	fprintf(stderr, "premature end of file in BLOCK_DATAGRID_3D section ");
+	return XC_ERROR;
+      }
       SetDataGridCommentLine( line );
       gridFP = MaybeOpenDataGridFile("w");
       NewGridList( DATAGRID_3D, gridFP );
       /* read DATAGRID_3D_XXX line */
-      if ( (c = fscanf(fp,"%s\n",line)) == EOF) return XC_ERROR;
+      if ( (c = fscanf(fp,"%s\n",line)) == EOF) {
+	fprintf(stderr, "premature end of file in BLOCK_DATAGRID_3D section ");
+	return XC_ERROR;
+      }
       while (strncmp(line, "END_BLOCK_DATAGRID3D", 20) != 0 &&
 	     strncmp(line, "END_BLOCK_DATAGRID_3D", 21) != 0) {
 	if ( strncmp(line, "DATAGRID_3D_", 12) == 0 ||
@@ -897,12 +973,24 @@ ReadXSF(FILE *fp)
 	  }
 	  /* read END_DATAGRID_3D line */
 	  breakpoint("breakpoint");
-	  if ( (c = fscanf(fp,"%s\n",line)) == EOF) return XC_ERROR;
+	  if ( (c = fscanf(fp,"%s\n",line)) == EOF) {
+	    fprintf(stderr, "premature end of file in BLOCK_DATAGRID_3D section ");	    
+	    return XC_ERROR;
+	  }
 	  if ( strncmp(line, "END_DATAGRID_3D", 15) != 0 &&
-	       strncmp(line, "END_DATAGRID3D", 14) != 0 ) return XC_ERROR;
-	} else return XC_ERROR;
+	       strncmp(line, "END_DATAGRID3D", 14) != 0 ) {
+	    fprintf(stderr, "expecting END_DATAGRID_3D keyword, but it wasn't found ");
+	    return XC_ERROR;
+	  }
+	} else {
+	  fprintf(stderr, "error parsing BLOCK_DATAGRID_3D section ");
+	  return XC_ERROR;
+	}
 	/* read next line */ 
-	if ( (c = fscanf(fp,"%s\n",line)) == EOF) return XC_ERROR;
+	if ( (c = fscanf(fp,"%s\n",line)) == EOF) {
+	  fprintf(stderr, "premature end of file in BLOCK_DATAGRID_3D section ");
+	  return XC_ERROR;
+	}
       }
       xcr.ldatagrid3D = 1;
     }
@@ -916,12 +1004,18 @@ ReadXSF(FILE *fp)
       lframe = 0;
       lend   = 1;
       /* read comment line */
-      if ( (c = fscanf(fp,"%s\n",line)) == EOF) return XC_ERROR;
+      if ( (c = fscanf(fp,"%s\n",line)) == EOF) {
+	fprintf(stderr, "premature end of file in BLOCK_BANDGRID_3D");
+	return XC_ERROR;
+      }
       SetDataGridCommentLine( line );      
       gridFP = MaybeOpenDataGridFile("w");
       NewGridList( DATAGRID_3D, gridFP );      
       /* read DATAGRID_3D_XXX line */
-      if ( (c = fscanf(fp,"%s\n",line)) == EOF) return XC_ERROR;
+      if ( (c = fscanf(fp,"%s\n",line)) == EOF) {
+	fprintf(stderr, "premature end of file in BLOCK_BANDGRID_3D");
+	return XC_ERROR;
+      }
       while (strncmp(line, "END_BLOCK_BANDGRID3D", 15) != 0 &&
 	     strncmp(line, "END_BLOCK_BANDGRID_3D", 16) != 0) {
 	if ( strncmp(line, "BANDGRID_3D", 11) == 0 
@@ -935,12 +1029,24 @@ ReadXSF(FILE *fp)
 	  }
 	  /* read END_DATAGRID_3D line */
 	  /*breakpoint("breakpoint");*/
-	  if ( (c = fscanf(fp,"%s\n",line)) == EOF) return XC_ERROR;
+	  if ( (c = fscanf(fp,"%s\n",line)) == EOF) {
+	    fprintf(stderr, "premature end of file in BLOCK_BANDGRID_3D");
+	    return XC_ERROR;
+	  }
 	  if (strncmp(line, "END_BANDGRID_3D", 15) != 0 &&
-	      strncmp(line, "END_BANDGRID3D", 14) != 0) return XC_ERROR;
-	} else return XC_ERROR;
+	      strncmp(line, "END_BANDGRID3D", 14) != 0) {
+	    fprintf(stderr, "expecting END_BANDGRID_3D keyword, but it wasn't found ");
+	    return XC_ERROR;
+	  }
+	} else {
+	  fprintf(stderr, "error parsing END_BANDGRID_3D section ");
+	  return XC_ERROR;
+	}
 	/* read next line */ 
-	if ( (c = fscanf(fp,"%s\n",line)) == EOF) return XC_ERROR;
+	if ( (c = fscanf(fp,"%s\n",line)) == EOF) {
+	  fprintf(stderr, "premature end of file in BLOCK_BANDGRID_3D");
+	  return XC_ERROR;
+	}
       }
       xcr.lbandgrid3D = 1;
     }
@@ -1024,11 +1130,17 @@ ReadXSF(FILE *fp)
   
   /* now read atoms */
   if ( natoms > 0 )
-    if (!ReadAtoms( fp, atompos )) return XC_ERROR;
+    if (!ReadAtoms( fp, atompos )) {
+      fprintf(stderr, "error reading Atoms ");	  
+      return XC_ERROR;
+    }
 
   /* if nframes > 0 also read frames */
   if ( nframes > 0 ) 
-    if (!ReadFrames( fp, framepos )) return XC_ERROR;
+    if (!ReadFrames( fp, framepos )) {
+      fprintf(stderr, "error reading Frames ");	  
+      return XC_ERROR;
+    }
         
   /*xcFree((void*)line);*/
 
@@ -1051,7 +1163,10 @@ ReadVec(FILE *fp, double vec[][4])
     
   if ( n0 == 3 && n1 == 3 && n2 == 3 ) return XC_OK;
   
-  else return XC_ERROR;
+  else {
+    fprintf(stderr, "error reading lattice vectors ");
+    return XC_ERROR;
+  }
 }
 
 
@@ -1317,16 +1432,16 @@ ReadFrames( FILE *fp , long int framepos )
 static int
 ReadVoronoi(FILE *fp, float poly[][WIGNERSEITZ_MAXVERTEX][3], 
 	    float norm[][WIGNERSEITZ_MAXVERTEX][3], int nvert[],
-	    float *Max, boolean *xcrl)
+	    float *Max, boolean *xcrl, int *npoly)
 {
-  int npoly, eos, i, j, nv;
+  int eos, i, j, nv;
   float max = 0;
   /* double fabs(); */
   char line1[256];
 
   /* VORONOI section ends with XXXXXXXXXXXXX_END,
      so this will do */
-  npoly = 0;
+  *npoly = 0;
   eos = 0;
   while( !eos ) { 	
     fscanf( fp, "%s", line1);
@@ -1334,26 +1449,26 @@ ReadVoronoi(FILE *fp, float poly[][WIGNERSEITZ_MAXVERTEX][3],
       /* t.k */
       for(i = 0; i < nv; i++) {
 	if ( fscanf( fp, "%f %f %f %f %f %f",
-		     &poly[npoly][i][0],
-		     &poly[npoly][i][1],
-		     &poly[npoly][i][2],
-		     &norm[npoly][i][0],
-		     &norm[npoly][i][1],
-		     &norm[npoly][i][2] ) == 6 ) {
+		     &poly[*npoly][i][0],
+		     &poly[*npoly][i][1],
+		     &poly[*npoly][i][2],
+		     &norm[*npoly][i][0],
+		     &norm[*npoly][i][1],
+		     &norm[*npoly][i][2] ) == 6 ) {
 	  for(j = 0; j < 3; j++) {
-	    if ( max < (float) ABS (poly[npoly][i][j]) ) 
-	      max = (float) ABS ( poly[npoly][i][j]);
+	    if ( max < (float) ABS (poly[*npoly][i][j]) ) 
+	      max = (float) ABS ( poly[*npoly][i][j]);
 	  }
-	  normalizepvf( &norm[npoly][i][0],
-			&norm[npoly][i][1],
-			&norm[npoly][i][2] );
+	  normalizepvf( &norm[*npoly][i][0],
+			&norm[*npoly][i][1],
+			&norm[*npoly][i][2] );
 	} else {
 	  fprintf(stderr, "ERROR: Error reading VORONOI-POLYHEDRA section, while reading ");
 	  return XC_ERROR;
 	}
       }
-      nvert[npoly] = nv;
-      npoly++;
+      nvert[*npoly] = nv;
+      (*npoly)++;
     } else {    
       *Max = max;
       *xcrl = 1;
@@ -1361,7 +1476,7 @@ ReadVoronoi(FILE *fp, float poly[][WIGNERSEITZ_MAXVERTEX][3],
     }
   }
 
-  return npoly;
+  return XC_OK;
 }
 
 
@@ -1372,9 +1487,22 @@ FindMaxRad(void)
   /* which atom have maximum radius -- this information is needed for
    * determination of glOrtho
    */
+
+  /* if (0) { */
+  /*   /\* this is too complicated, because the viewport changes when radii change *\/ */
+  /*   max.r = 0.0; */
+  /*   for(i=0; i<atm.natomkind; i++) */
+  /*     if (atrad[atm.atomkind[i]] > max.r) max.r = atrad[atm.atomkind[i]];  */
+  
+  /*   /\* this is too simple *\/ */
+  /*   max.r = 1.5; */
+  /* } */
+
   max.r = 0.0;
-  for(i=0; i<atm.natomkind; i++)
-    if (atrad[atm.atomkind[i]] > max.r) max.r = atrad[atm.atomkind[i]];
+  for(i=0; i<atm.natomkind; i++) {
+    if (rvdw[atm.atomkind[i]] > max.r) max.r = rvdw[atm.atomkind[i]];   
+    if (rcov[atm.atomkind[i]] > max.r) max.r = rcov[atm.atomkind[i]];
+  }
 }
 
 
@@ -1725,7 +1853,7 @@ parsePDBHetatmRecord(char *line, int *n, double *x, double *y, double *z)
 
   sscanf(line, "%*6s%*5i%*1c%1c%1c%*3s%3s", &__atmn[0], &__atmn[1], resn);
   __atmn[2] = '\0';
-  if ( strncmp(resn, "   ", 3) == 0 ) strncpy(resn, "UNK", 3);
+  if ( strncmp(resn, "   ", 3) == 0 ) strncpy(resn, "UNK\0", 4);
 
   /*
     
