@@ -216,5 +216,6 @@ shankland3d_interpolate(int n1, int n2, int n3, int n1new, int n2new, int n3new,
   fftw_free((void*) fftw2);
   free((void*) lambda);  
 }
-
+#else
+typedef int make_iso_compilers_happy;
 #endif
