@@ -364,4 +364,6 @@ shank3d_lambda(int n1, int n2, int n3, int n1new, int n2new, int n3new, double s
   return f_aver;
 }
 
+#else
+typedef int make_iso_compilers_happy;
 #endif
