@@ -171,4 +171,6 @@ print_complex_matrix(FILE *stream, const char* name, size_t m, size_t n, fftw_co
 }
 #endif
 
+#else
+typedef int make_iso_compilers_happy;
 #endif
