@@ -356,7 +356,7 @@ typedef struct {
   int       dispLatType;   /* display type for dispLattice */
 } StructPar;
 
-StructPar VPf; /* all parameters for stucture(molecule, crystal..) display 
+StructPar VPf; /* all parameters for structure(molecule, crystal..) display 
 		* + state parameters are here */
 
 /*******************************/
@@ -593,7 +593,7 @@ ModelPar MVf;
 
 /* --------------------------- */
 /* --- some default values --- */
-#define DEF_ZOOM  1.1
+#define DEF_ZOOM  1.7
 #define DEF_SCRF  1.5
 #define DEF_BALLF 0.4
 #define DEF_RODF  0.6
@@ -803,7 +803,6 @@ typedef struct {
 #define FORMAT_XSF        1
 #define FORMAT_XYZ        2
 #define FORMAT_PDB        3
-#define FORMAT_CHARMM     4
 
 int current_file_format;
 
@@ -959,7 +958,7 @@ WIGNERSEITZ wsp, wsc;
 #define RECIP_DATAGRID_3D 4
 #define DATAGRID_MAXSUBINDEX 5000 /* do we need more that 5000 bands for Fermi surface ??? */
 
-#ifndef XC_CPP_NO_STDIO /* load DATAGRID only if stdio.h was inluded */
+#ifndef XC_CPP_NO_STDIO /* load DATAGRID only if stdio.h was included */
 struct DATAGRID {
   FILE   *fp;
   int    type;        /* type of DATAGRID, i.e. 2D or 3D */
@@ -1155,4 +1154,6 @@ typedef struct {
   char *dir;
 } realTimeMove;
 
+extern const char *printImage;
+
 #endif
