@@ -1,18 +1,18 @@
 /*
- 
- *****************************************************************************
- * Author:                                                                   *
- * ------                                                                    *
- *  Anton Kokalj                                  Email: Tone.Kokalj@ijs.si  *
- *  Department of Physical and Organic Chemistry  Phone: x 386 1 477 3523    *
- *  Jozef Stefan Institute                          Fax: x 386 1 477 3811    *
- *  Jamova 39, SI-1000 Ljubljana                                             *
- *  SLOVENIA                                                                 *
- *                                                                           *
- * Source: $XCRYSDEN_TOPDIR/C/xcBz.c
- * ------                                                                    *
- * Copyright (c) 1996-2003 by Anton Kokalj                                   *
- *****************************************************************************
+
+*****************************************************************************
+* Author:                                                                   *
+* ------                                                                    *
+*  Anton Kokalj                                  Email: Tone.Kokalj@ijs.si  *
+*  Department of Physical and Organic Chemistry  Phone: x 386 1 477 3523    *
+*  Jozef Stefan Institute                          Fax: x 386 1 477 3811    *
+*  Jamova 39, SI-1000 Ljubljana                                             *
+*  SLOVENIA                                                                 *
+*                                                                           *
+* Source: $XCRYSDEN_TOPDIR/C/xcBz.c
+* ------                                                                    *
+* Copyright (c) 1996-2003 by Anton Kokalj                                   *
+*****************************************************************************
 
 */
 
@@ -41,15 +41,12 @@ static Tk_Window canvaswin[2];
 static float canvassize[2];
 static float canvas_offset[2] = { BZ_OFFSET, BZ_OFFSET };
 
-int XC_BzCmd(ClientData clientData,Tcl_Interp *interp,
-	     int argc, char *argv[]);
+int XC_BzCmd(ClientData clientData,Tcl_Interp *interp, int argc, const char *argv[]);
 static int  BzInitBZ( int typ );
 static void BzViewPortBZ(Tcl_Interp *interp, int typ);
 static int  BzRenderBZ(Tcl_Interp *interp, int typ);
-static void BzCreateSelLine( Tcl_Interp *interp, Tcl_CmdInfo info, 
-			     char *argv[], int typ, int i );
-static void BzUpdateSelLine( Tcl_Interp *interp, Tcl_CmdInfo info,
-			     char *argv[], int typ, int i, char *tag );
+static void BzCreateSelLine( Tcl_Interp *interp, Tcl_CmdInfo info, char *argv[], int typ, int i );
+static void BzUpdateSelLine( Tcl_Interp *interp, Tcl_CmdInfo info, char *argv[], int typ, int i, char *tag );
 static void BzRotateBZ( int typ, float x, float y, float z );
 static void BzDegRotateBZ( int typ, float fiX, float fiY, float fiZ );
 static void BzGetCoor( int typ, int pID, float coor[] );
@@ -74,7 +71,7 @@ static int  BzGetMinMult( int a, int b );
  *****************************************************************************/
 int
 XC_BzCmd(ClientData clientData, Tcl_Interp *interp,
-	 int argc, char *argv[])
+	 int argc, const char *argv[])
 { 
   Tk_Window tkwin = (Tk_Window) clientData;
   int i, typ;
@@ -82,14 +79,16 @@ XC_BzCmd(ClientData clientData, Tcl_Interp *interp,
   /* at least three arguments must be present */
 
   /* debuging */
-/*    printf("COMMAND:: ",NULL); */
-/*    for(i=0; i<argc; i++) */
-/*      printf("%s ",argv[i]); */
-/*    printf("\n",NULL); */
-/*    fflush(stdout); */
+  /*    printf("COMMAND:: ",NULL); */
+  /*    for(i=0; i<argc; i++) */
+  /*      printf("%s ",argv[i]); */
+  /*    printf("\n",NULL); */
+  /*    fflush(stdout); */
 
   if ( argc < 3 ) {
-    sprintf(interp->result,"not enough arguments, must be one of xc_bz (exists|init|viewport|render|rotate|degrotate|zoom|get|select|deselect|state|iss); while executing %s %s %s ...", argv[0], argv[1], argv[2]);
+    char rss[1024];
+    snprintf(rss, sizeof(rss),"not enough arguments, must be one of xc_bz (exists|init|viewport|render|rotate|degrotate|zoom|get|select|deselect|state|iss); while executing %s %s %s ...", argv[0], argv[1], argv[2]);
+    Tcl_SetResult(interp, rss, TCL_VOLATILE);
     return TCL_ERROR;
   }
   /**********
@@ -119,18 +118,22 @@ XC_BzCmd(ClientData clientData, Tcl_Interp *interp,
 	bz[typ].linepoint_index[i][1]   = -1;
       }
       if ( !BzInitBZ(typ) ) {
-	sprintf(interp->result,"error when initializing rendering of Brillouin Zone; while executing %s %s %s ...", 
-		argv[0], argv[1], argv[2]);
+	char rss[1024];
+	snprintf(rss, sizeof(rss),"error when initializing rendering of Brillouin Zone; while executing %s %s %s ...", 
+		 argv[0], argv[1], argv[2]);
+	Tcl_SetResult(interp, rss, TCL_VOLATILE);
 	return TCL_ERROR;
       }
-      
+
       bz_state[typ].points  = 1;
       bz_state[typ].vectors = 0;
       bz_state[typ].last_vectors = 0;
     }
     else {
-      sprintf(interp->result,"unknown Brillouin Zone type \"%s\", must be \"prim\" or \"conv\"; while executing %s %s %s ...", 
-	      argv[2], argv[0], argv[1], argv[2]);
+      char rss[1024];
+      snprintf(rss, sizeof(rss),"unknown Brillouin Zone type \"%s\", must be \"prim\" or \"conv\"; while executing %s %s %s ...", 
+	       argv[2], argv[0], argv[1], argv[2]);
+      Tcl_SetResult(interp, rss, TCL_VOLATILE);
       return TCL_ERROR;
     }
     /* now create canvas */
@@ -144,11 +147,11 @@ XC_BzCmd(ClientData clientData, Tcl_Interp *interp,
 	return TCL_ERROR;
     }    
     /* if ( Tcl_VarEval(interp, "pack ", argv[3]," -fill both -expand 1", 
-		     (char *)NULL) == TCL_ERROR )
-      return TCL_ERROR;
-    if ( Tcl_VarEval(interp, "tkwait visibility ", argv[3], 
-		     (char *)NULL) == TCL_ERROR )
-		     return TCL_ERROR;	 */
+       (char *)NULL) == TCL_ERROR )
+       return TCL_ERROR;
+       if ( Tcl_VarEval(interp, "tkwait visibility ", argv[3], 
+       (char *)NULL) == TCL_ERROR )
+       return TCL_ERROR;	 */
     canvaswin[typ]  = Tk_NameToWindow( interp, argv[3], tkwin );
     sprintf(canvasname[typ], "%s", argv[3]);
     /* this is for point-selection */
@@ -166,9 +169,11 @@ XC_BzCmd(ClientData clientData, Tcl_Interp *interp,
     else if ( strcmp( argv[2], canvasname[BZ_CONVCELL] ) == 0 )
       typ = BZ_CONVCELL;
     else {
-      sprintf(interp->result,"wrong name of bz_canvas \"%s\", must be one of \"%s\", \"%s\"; while executing %s %s %s", 
-	      argv[2], canvasname[BZ_PRIMCELL], canvasname[BZ_CONVCELL],
-	      argv[0], argv[1], argv[2]);
+      char rss[1024];
+      snprintf(rss, sizeof(rss),"wrong name of bz_canvas \"%s\", must be one of \"%s\", \"%s\"; while executing %s %s %s", 
+	       argv[2], canvasname[BZ_PRIMCELL], canvasname[BZ_CONVCELL],
+	       argv[0], argv[1], argv[2]);
+      Tcl_SetResult(interp, rss, TCL_VOLATILE);
       return TCL_ERROR;
     }
     /************ 
@@ -188,18 +193,24 @@ XC_BzCmd(ClientData clientData, Tcl_Interp *interp,
       double dx, dy, dz;
       float x, y, z;
       if ( Tcl_GetDouble(interp, argv[3], &dx) == TCL_ERROR ) {
-	sprintf(interp->result, "expected double, but got \"%s\"; while executing %s %s %s %s %s %s", 
-		argv[3], argv[0], argv[1], argv[2], argv[3], argv[4], argv[5]);
+	char rss[1024];
+	snprintf(rss, sizeof(rss), "expected double, but got \"%s\"; while executing %s %s %s %s %s %s", 
+		 argv[3], argv[0], argv[1], argv[2], argv[3], argv[4], argv[5]);
+	Tcl_SetResult(interp, rss, TCL_VOLATILE);
 	return TCL_ERROR;
       }
       if ( Tcl_GetDouble(interp, argv[4], &dy) == TCL_ERROR ) {
-	sprintf(interp->result, "expected double, but got \"%s\"; while executing %s %s %s %s %s %s", 
-		argv[4], argv[0], argv[1], argv[2], argv[3], argv[4], argv[5]);
+	char rss[1024];
+	snprintf(rss, sizeof(rss), "expected double, but got \"%s\"; while executing %s %s %s %s %s %s", 
+		 argv[4], argv[0], argv[1], argv[2], argv[3], argv[4], argv[5]);
+	Tcl_SetResult(interp, rss, TCL_VOLATILE);
 	return TCL_ERROR;
       }
       if ( Tcl_GetDouble(interp, argv[5], &dz) == TCL_ERROR ) {
-	sprintf(interp->result, "expected double, but got \"%s\"; while executing %s %s %s %s %s %s", 
-		argv[5], argv[0], argv[1], argv[2], argv[3], argv[4], argv[5]);
+	char rss[1024];
+	snprintf(rss, sizeof(rss), "expected double, but got \"%s\"; while executing %s %s %s %s %s %s", 
+		 argv[5], argv[0], argv[1], argv[2], argv[3], argv[4], argv[5]);
+	Tcl_SetResult(interp, rss, TCL_VOLATILE);
 	return TCL_ERROR;
       }
       x = (float) dx;
@@ -216,18 +227,24 @@ XC_BzCmd(ClientData clientData, Tcl_Interp *interp,
       double dfiX, dfiY, dfiZ;
       float fiX, fiY, fiZ;
       if ( Tcl_GetDouble(interp, argv[3], &dfiX) == TCL_ERROR ) {
-	sprintf(interp->result, "expected double, but got \"%s\"; while executing %s %s %s %s %s %s", 
-		argv[3], argv[0], argv[1], argv[2], argv[3], argv[4], argv[5]);
+	char rss[1024];
+	snprintf(rss, sizeof(rss), "expected double, but got \"%s\"; while executing %s %s %s %s %s %s", 
+		 argv[3], argv[0], argv[1], argv[2], argv[3], argv[4], argv[5]);
+	Tcl_SetResult(interp, rss, TCL_VOLATILE);
 	return TCL_ERROR;
       }
       if ( Tcl_GetDouble(interp, argv[4], &dfiY) == TCL_ERROR ) {
-	sprintf(interp->result, "expected double, but got \"%s\"; while executing %s %s %s %s %s %s", 
-		argv[4], argv[0], argv[1], argv[2], argv[3], argv[4], argv[5]);
+	char rss[1024];
+	snprintf(rss, sizeof(rss), "expected double, but got \"%s\"; while executing %s %s %s %s %s %s", 
+		 argv[4], argv[0], argv[1], argv[2], argv[3], argv[4], argv[5]);
+	Tcl_SetResult(interp, rss, TCL_VOLATILE);
 	return TCL_ERROR;
       }
       if ( Tcl_GetDouble(interp, argv[5], &dfiZ) == TCL_ERROR ) {
-	sprintf(interp->result, "expected double, but got \"%s\"; while executing %s %s %s %s %s %s", 
-		argv[5], argv[0], argv[1], argv[2], argv[3], argv[4], argv[5]);
+	char rss[1024];
+	snprintf(rss, sizeof(rss), "expected double, but got \"%s\"; while executing %s %s %s %s %s %s", 
+		 argv[5], argv[0], argv[1], argv[2], argv[3], argv[4], argv[5]);
+	Tcl_SetResult(interp, rss, TCL_VOLATILE);
 	return TCL_ERROR;
       }
       fiX = (float) dfiX / RAD2DEG;
@@ -243,8 +260,10 @@ XC_BzCmd(ClientData clientData, Tcl_Interp *interp,
     else if ( strcmp( argv[1], "zoom") == 0 ) {
       double f;
       if ( Tcl_GetDouble(interp, argv[3], &f) == TCL_ERROR ) {
-	sprintf(interp->result, "expected double, but got \"%s\"; while executing %s %s %s %s", 
-		argv[3], argv[0], argv[1], argv[2], argv[3]);
+	char rss[1024];
+	snprintf(rss, sizeof(rss), "expected double, but got \"%s\"; while executing %s %s %s %s", 
+		 argv[3], argv[0], argv[1], argv[2], argv[3]);
+	Tcl_SetResult(interp, rss, TCL_VOLATILE);
 	return TCL_ERROR;
       }
       /* greater offset -> minor BZ */
@@ -282,8 +301,10 @@ XC_BzCmd(ClientData clientData, Tcl_Interp *interp,
 	  sprintf(result, "-1");
       }
       else {
-	sprintf(interp->result, "unknown option \"%s\", must be one of n_edgepoint, n_linepoint, n_polypoint, npoly, npoint, nselected, last_selected; while executing %s %s %s %s",
-		argv[3], argv[0], argv[1], argv[2], argv[3]);
+	char rss[1024];
+	snprintf(rss, sizeof(rss), "unknown option \"%s\", must be one of n_edgepoint, n_linepoint, n_polypoint, npoly, npoint, nselected, last_selected; while executing %s %s %s %s",
+		 argv[3], argv[0], argv[1], argv[2], argv[3]);
+	Tcl_SetResult(interp, rss, TCL_VOLATILE);
 	return TCL_ERROR;
       }
       Tcl_SetResult(interp, result, TCL_DYNAMIC);
@@ -295,12 +316,16 @@ XC_BzCmd(ClientData clientData, Tcl_Interp *interp,
       int pID;
       float *coor;
       if ( Tcl_GetInt(interp, argv[3], &pID) == TCL_ERROR ) {
-	sprintf(interp->result, "expected int, but got \"%s\"; while executing %s %s %s %s", argv[3], argv[0], argv[1], argv[2], argv[3]);
+	char rss[1024];
+	snprintf(rss, sizeof(rss), "expected int, but got \"%s\"; while executing %s %s %s %s", argv[3], argv[0], argv[1], argv[2], argv[3]);
+	Tcl_SetResult(interp, rss, TCL_VOLATILE);
 	return TCL_ERROR;
       }
       if ( pID < 0 || pID >= bz[typ].npoint) {
-	sprintf(interp->result, "selected point #\"%s\" is out of range, must be within [0,%d); while executing %s %s %s %s", 
-		argv[3], bz[typ].npoint, argv[0], argv[1], argv[2], argv[3]);
+	char rss[1024];
+	snprintf(rss, sizeof(rss), "selected point #\"%s\" is out of range, must be within [0,%d); while executing %s %s %s %s", 
+		 argv[3], bz[typ].npoint, argv[0], argv[1], argv[2], argv[3]);
+	Tcl_SetResult(interp, rss, TCL_VOLATILE);
 	return TCL_ERROR;
       }
       bz[typ].selectedID[ bz[typ].nselected ] = pID;
@@ -387,7 +412,7 @@ XC_BzCmd(ClientData clientData, Tcl_Interp *interp,
       if ( Tcl_VarEval( interp, canvasname[typ], " delete ", 
 			"selline", (char *)NULL ) == TCL_ERROR )
 	return TCL_ERROR;
-      
+
       /* now handle selected points */
       for (i=0; i<bz[typ].nselected; i++)
 	bz[typ].selected_is_rendered[i] = 0;      
@@ -395,7 +420,7 @@ XC_BzCmd(ClientData clientData, Tcl_Interp *interp,
       if ( Tcl_VarEval( interp, canvasname[typ], " delete ", 
 			"selpoint", (char *)NULL ) == TCL_ERROR )
 	return TCL_ERROR;
-      
+
       BzRenderBZ(interp, typ);
       /* update the Bz($can,nselected) tcl variable, 
 	 thatwhy we will return its value 
@@ -409,7 +434,9 @@ XC_BzCmd(ClientData clientData, Tcl_Interp *interp,
     else if ( strcmp( argv[1], "state" ) == 0 ) {
       int state;
       if ( Tcl_GetInt(interp, argv[4], &state) == TCL_ERROR ) {
-	sprintf(interp->result, "expected int, but got \"%s\"; while executing %s %s %s %s %s", argv[3], argv[0], argv[1], argv[2], argv[3], argv[4]);
+	char rss[1024];
+	snprintf(rss, sizeof(rss), "expected int, but got \"%s\"; while executing %s %s %s %s %s", argv[3], argv[0], argv[1], argv[2], argv[3], argv[4]);
+	Tcl_SetResult(interp, rss, TCL_VOLATILE);
 	return TCL_ERROR;
       }
       if ( strncmp( argv[3], "point", 5 ) == 0 ) {
@@ -421,8 +448,10 @@ XC_BzCmd(ClientData clientData, Tcl_Interp *interp,
 	/* INSERT: update bz[typ].max */
       }
       else {
-	sprintf(interp->result,"unknown option \"%s\", must be one of points, vectors; while executing %s %s %s %s %s", 
-		argv[3], argv[0], argv[1], argv[2], argv[3], argv[4]);
+	char rss[1024];
+	snprintf(rss, sizeof(rss),"unknown option \"%s\", must be one of points, vectors; while executing %s %s %s %s %s", 
+		 argv[3], argv[0], argv[1], argv[2], argv[3], argv[4]);
+	Tcl_SetResult(interp, rss, TCL_VOLATILE);
 	return TCL_ERROR;
       }
       BzDegRotateBZ( typ, 0.0, 0.0, 0.0 );
@@ -438,12 +467,14 @@ XC_BzCmd(ClientData clientData, Tcl_Interp *interp,
       Tcl_SetResult(interp, result, TCL_DYNAMIC);
     }
     else {
-      sprintf(interp->result,"unknown command \"xc_bz %s\", must be one of xc_bz (init|viewport|render|rotate|degrotate|select|deselect|deselectall|state|get|iss); while executing %s %s %s ...", argv[1],
-	      argv[0], argv[1], argv[2]);
+      char rss[1024];
+      snprintf(rss, sizeof(rss),"unknown command \"xc_bz %s\", must be one of xc_bz (init|viewport|render|rotate|degrotate|select|deselect|deselectall|state|get|iss); while executing %s %s %s ...", argv[1],
+	       argv[0], argv[1], argv[2]);
+      Tcl_SetResult(interp, rss, TCL_VOLATILE);
       return TCL_ERROR;
     }
   }
-  
+
   return TCL_OK;
 }
 
@@ -473,7 +504,7 @@ BzInitBZ( int typ )
 	bz[typ].recvec[i][j] = (float) vec.recconv[i][j];
       bz[typ].rot_recvec[i][j] = bz[typ].recvec[i][j];
     }
-  
+
   /***************************************************************************/
   /* copy polygons to rot_poly */
   for (i=0; i<bz[typ].npoly; i++)
@@ -504,7 +535,7 @@ BzInitBZ( int typ )
       sumx += bz[typ].poly[i][j][0];
       sumy += bz[typ].poly[i][j][1];
       sumz += bz[typ].poly[i][j][2];
-      
+
       /* check if the EDGEPOINT is already registered */
       for (k=0; k<bz[typ].n_edgepoint; k++) {
 	if ( IsSamePointvf( bz[typ].poly[i][j],
@@ -564,11 +595,11 @@ BzInitBZ( int typ )
     bz[typ].point[npoi][0] = sumx / (float) bz[typ].nvert[i];
     bz[typ].point[npoi][1] = sumy / (float) bz[typ].nvert[i];
     bz[typ].point[npoi][2] = sumz / (float) bz[typ].nvert[i];
-    
+
     bz[typ].rot_points[npoi][0] = sumx / (float) bz[typ].nvert[i];
     bz[typ].rot_points[npoi][1] = sumy / (float) bz[typ].nvert[i];
     bz[typ].rot_points[npoi][2] = sumz / (float) bz[typ].nvert[i];
-    
+
     bz[typ].n_polypoint++;
     bz[typ].polyindex[npoi] = i;
     printf("npoi=%d; polygon: %d\n", npoi, i);
@@ -587,13 +618,13 @@ BzInitBZ( int typ )
   /* get number of Z-points */
   bz[typ].npoint  = npoi;
   bz[typ].nZpoint = npoi;
-  
-/*    for (i=0; i<bz[typ].n_linepoint; i++) */
-/*      printf("LINE:: i=%d, lindex=%d, line_index={%d, %d}\n", */
-/*  	   i, lindex[i], */
-/*  	   bz[typ].linepoint_index[lindex[i]][0], */
-/*  	   bz[typ].linepoint_index[lindex[i]][1]); */
-/*    fflush(stdout); */
+
+  /*    for (i=0; i<bz[typ].n_linepoint; i++) */
+  /*      printf("LINE:: i=%d, lindex=%d, line_index={%d, %d}\n", */
+  /*  	   i, lindex[i], */
+  /*  	   bz[typ].linepoint_index[lindex[i]][0], */
+  /*  	   bz[typ].linepoint_index[lindex[i]][1]); */
+  /*    fflush(stdout); */
 
   return XC_OK;
 }
@@ -610,9 +641,9 @@ BzViewPortBZ(Tcl_Interp *interp, int typ)
   canvassize[typ] = w;
   if ( h < canvassize[typ] )
     canvassize[typ] = h;
-  
+
   f = 0.5 * (1.0 - canvas_offset[typ]) * canvassize[typ] / bz[typ].max;
-  
+
   /* WARNING: take care of X y-coor, 
      because y-coor in X are turned upside down */
   for (i=0; i<xcr.dim; i++) {    
@@ -645,19 +676,19 @@ static void
 BzRotateBZ( int typ, float x, float y, float z )
 {
   float fiX, fiY, fiZ;
-  
+
   /* 4.0 is just some emperical factor to maximize performance of
    * mouse rotation so, that it will follow mouse pointer 
    */
   if ( x != 0 ) fiY = atan( 4.0 * x / canvassize[typ] );    
   else fiY = 0.0;
-  
+
   if ( y != 0 ) fiX = atan( 4.0 * y / canvassize[typ] );
   else fiX = 0.0;
-  
+
   if ( z != 0 ) fiZ = atan( 4.0 * z / canvassize[typ] );
   else fiZ = 0.0;
-  
+
   BzDegRotateBZ( typ, fiX, fiY, fiZ );
 }
 
@@ -684,7 +715,7 @@ BzDegRotateBZ( int typ, float fiX, float fiY, float fiZ )
     { 0.0, 0.0, 1.0},
   };
   float rotxy[3][3], rotxyz[3][3], oldrot[3][3];
-  
+
   cosfiX = cos(fiX);
   sinfiX = sin(fiX);
   cosfiY = cos(fiY);
@@ -701,12 +732,12 @@ BzDegRotateBZ( int typ, float fiX, float fiY, float fiZ )
   roty[0][2] = sinfiY;
   roty[2][0] = -sinfiY;
   roty[2][2] = cosfiY;
-  
+
   rotz[0][0] = cosfiZ;
   rotz[0][1] = -sinfiZ;
   rotz[1][0] = sinfiZ;
   rotz[1][1] = cosfiZ;
-  
+
   /* now multiply the matrices */
   MatCopy33f(bz[typ].rotmat, oldrot);
   MatToZero33f(rotxy);
@@ -719,17 +750,17 @@ BzDegRotateBZ( int typ, float fiX, float fiY, float fiZ )
   /* now update the reciprocal vectors */
   for (i=0; i<xcr.dim; i++)
     MatVecMult33f(bz[typ].rotmat, bz[typ].recvec[i], bz[typ].rot_recvec[i]);
-  
+
   /* now update the polygons */
   for (i=0; i<bz[typ].npoly; i++)
     for (j=0; j<bz[typ].nvert[i]; j++)
       MatVecMult33f(bz[typ].rotmat, bz[typ].poly[i][j], 
 		    bz[typ].rot_poly[i][j]);
-  
+
   /* now update the points */
   for (i=0; i<bz[typ].npoint; i++)
     MatVecMult33f(bz[typ].rotmat, bz[typ].point[i], bz[typ].rot_points[i] );
-  
+
   /* now update the selected lines */
   for (i=0; i<bz[typ].n_sline; i++) {
     MatVecMult33f(bz[typ].rotmat,
@@ -746,12 +777,12 @@ static void
 BzGetCoor( int typ, int pID, float v[] ) 
 {
   double (*vc)[4];
-  
+
   if ( typ == BZ_PRIMCELL )
     vc = (double (*)[4]) vec.prim;
   else
     vc = (double (*)[4]) vec.conv;
-  
+
   v[0] = 0.0;
   v[1] = 0.0;
   v[2] = 0.0;
@@ -794,20 +825,20 @@ BzRenderBZ(Tcl_Interp *interp, int typ)
   float pointZ[1000];
   int   iorder[1000];
   char *argv[BZRENDERBZ_ARGC], *tag, *cmd, *color;
-  
+
   for(i=0; i<BZRENDERBZ_ARGC; i++)
     argv[i] = (char *) malloc( sizeof(char) * 64 );
 
   cmd = canvasname[typ];  
   strcpy(argv[0], cmd);
-  
+
   Tcl_ResetResult(interp);
   if ( !Tcl_GetCommandInfo(interp, cmd, &info) ) {
     Tcl_AppendResult(interp, "Unknown command \"", cmd, "\"", NULL);
     return TCL_ERROR;
   }
   /*Tcl_ResetResult( interp );*/
-  
+
   tag    = (char *) malloc( sizeof(char) * 20);
   /*
     pointZ = (float *) malloc( sizeof(float) * (bz[typ].nZpoint + 1 + xcr.dim));
@@ -830,7 +861,7 @@ BzRenderBZ(Tcl_Interp *interp, int typ)
   /* Z-orientate */
   npoi = bz[typ].nZpoint + 2 * xcr.dim;
   hpsort_index1_f( npoi , pointZ, iorder );
-  
+
   ipoly = 0;
   if ( !bz[typ].isrendered ) {
     printf("CREATE ITEMS\n");
@@ -856,20 +887,20 @@ BzRenderBZ(Tcl_Interp *interp, int typ)
 		       bz[typ].vp_poly[ip][j][0], bz[typ].vp_poly[ip][j][1]);
 	  WriteArgv( argv, &argc, "ff", 
 		     bz[typ].vp_poly[ip][0][0], bz[typ].vp_poly[ip][0][1]);
-	  
+
 	  sprintf(tag, "polygon p%d", ip);
-	  
+
 	  ps    = BZ_THIN_POINT_SIZE;
 	  if ( (float) (ipoly + 1) / bz[typ].npoly >= 0.49 ) {
 	    ps    = BZ_BOLD_POINT_SIZE;
 	  }
 	  ipoly++;
-	  
+
 	  WriteArgv( argv, &argc, "sssfss", "-fill", "#000000",
 		     "-width", ps, "-tags", tag);
 	  Tcl_ResetResult( interp );
-	  (*info.proc)(info.clientData, interp, argc, argv);	
-	  printf("LINE:: polyID:: %s p%d\n",interp->result,ip);
+	  (*info.proc)(info.clientData, interp, argc, (const char**) argv);	
+	  //printf("LINE:: polyID:: %s p%d\n",interp->result,ip);
 
 	  if ( xcr.dim == 3) {
 	    /* now render POLYPOINT */
@@ -883,15 +914,15 @@ BzRenderBZ(Tcl_Interp *interp, int typ)
 		       bz[typ].vp_points[ii][1],
 		       bz[typ].vp_points[ii][0],
 		       bz[typ].vp_points[ii][1] + ps);
-	    
+
 	    printf("OBJECT DETAILS: polypoint, argc=%d\n", argc);
-	    
+
 	    sprintf(tag, "point pt%d", ii);
-	    
+
 	    WriteArgv( argv, &argc, "ssssss", "-fill", "#000000", "-width", 
 		       "1", "-tags", tag);
 	    xcdebug("before info.proc");
-	    (*info.proc)(info.clientData, interp, argc, argv);
+	    (*info.proc)(info.clientData, interp, argc, (const char **) argv);
 	    xcdebug("after info.proc");
 	  }
 	} else {
@@ -902,7 +933,7 @@ BzRenderBZ(Tcl_Interp *interp, int typ)
 	    /* for xcr.dim == 1 the only BZ_LINEPOINT is BZ_CENTERPOINT */
 	    argc = 1;
 	    WriteArgv( argv, &argc, "ss", "create", "oval");
-	    
+
 	    ps = BZ_THIN_POINT_SIZE;
 	    color = "#000000";
 	    if ( (float) i / bz[typ].npoint >= 0.49 )
@@ -913,20 +944,20 @@ BzRenderBZ(Tcl_Interp *interp, int typ)
 	      ps = BZ_CENTERPOINT_SIZE;
 	      color = "#ff0000";
 	    }
-	    
+
 	    WriteArgv( argv, &argc, "ffff", 
 		       bz[typ].vp_points[ii][0] - ps,
 		       bz[typ].vp_points[ii][1] - ps,
 		       bz[typ].vp_points[ii][0] + ps,
 		       bz[typ].vp_points[ii][1] + ps);
-	    
+
 	    printf("OBJECT DETAILS: point\n, argc=%d\n", argc);
-	    
+
 	    sprintf(tag, "point pt%d", ii );
 	    WriteArgv( argv, &argc, "ssssssss", "-fill", color, 
 		       "-outline", color, "-width", "1", "-tags", tag);
 	    xcdebug("before info.proc");
-	    (*info.proc)(info.clientData, interp, argc, argv);	
+	    (*info.proc)(info.clientData, interp, argc, (const char**) argv);	
 	    xcdebug("after info.proc");		    
 	  }
 	}
@@ -948,28 +979,28 @@ BzRenderBZ(Tcl_Interp *interp, int typ)
 	  vp_points[0] = -100.0;
 	  vp_points[1] = -100.0;
 	}
-	
-/*  	printf("LOOP --> i=%d, ii=%d, typ ==%d\n",  */
-/*  	       i, ii, bz[typ].pointtype[ii]); */
-/*  	fflush(stdout); */
-	
+
+	/*  	printf("LOOP --> i=%d, ii=%d, typ ==%d\n",  */
+	/*  	       i, ii, bz[typ].pointtype[ii]); */
+	/*  	fflush(stdout); */
+
 	if ( bz[typ].pointtype[ii] == BZ_POLYPOINT ) {
 	  /* first update POLYGON coordinates, then update points */
 	  ip = bz[typ].polyindex[ii];
 	  argc = 1;
 	  sprintf(tag, "p%d", ip);
 	  WriteArgv( argv, &argc, "ss", "coords", tag);
-	  
-/*  	  printf("ii=%d; polygon number: %d\n",ii, ip); */
-/*  	  fflush(stdout); */
+
+	  /*  	  printf("ii=%d; polygon number: %d\n",ii, ip); */
+	  /*  	  fflush(stdout); */
 
 	  for(j=0; j<bz[typ].nvert[ip]; j++)
 	    WriteArgv( argv, &argc, "ff",      
 		       bz[typ].vp_poly[ip][j][0], bz[typ].vp_poly[ip][j][1]);
 	  WriteArgv( argv, &argc, "ff",      
 		     bz[typ].vp_poly[ip][0][0], bz[typ].vp_poly[ip][0][1]);
-	  (*info.proc)(info.clientData, interp, argc, argv);
-	  
+	  (*info.proc)(info.clientData, interp, argc, (const char**) argv);
+
 	  ps  = BZ_THIN_POINT_SIZE;
 	  ps1 = BZ_THIN_POLYGON_WIDTH;	  
 	  if ( (float) (ipoly + 1) / bz[typ].npoly > 0.5 ) {
@@ -977,17 +1008,17 @@ BzRenderBZ(Tcl_Interp *interp, int typ)
 	    ps1 = BZ_BOLD_POLYGON_WIDTH;
 	  }
 	  ipoly++;
-	  
+
 	  /* update the width & outline of polygons */
 	  argc = 1;
 	  WriteArgv( argv, &argc, "sssf", "itemconfigure", tag, 
 		     "-width",  ps1);
-	  (*info.proc)(info.clientData, interp, argc, argv);	
-	  
+	  (*info.proc)(info.clientData, interp, argc, (const char**) argv);	
+
 	  /* change the stack order */
 	  argc = 1;
 	  WriteArgv( argv, &argc, "sss", "raise", tag, "all");
-	  (*info.proc)(info.clientData, interp, argc, argv);
+	  (*info.proc)(info.clientData, interp, argc, (const char**) argv);
 
 	  if ( xcr.dim == 3 ) {
 	    /* update POLYPOINT */
@@ -998,12 +1029,12 @@ BzRenderBZ(Tcl_Interp *interp, int typ)
 		       vp_points[0],      vp_points[1] - ps,
 		       vp_points[0] + ps, vp_points[1],
 		       vp_points[0],      vp_points[1] + ps);
-	    (*info.proc)(info.clientData, interp, argc, argv);
-	    
+	    (*info.proc)(info.clientData, interp, argc, (const char**) argv);
+
 	    /* change the stack order */
 	    argc = 1;
 	    WriteArgv( argv, &argc, "sss", "raise", tag, "all");
-	    (*info.proc)(info.clientData, interp, argc, argv);
+	    (*info.proc)(info.clientData, interp, argc, (const char**) argv);
 	  }
 	} else {
 	  /* 
@@ -1024,19 +1055,19 @@ BzRenderBZ(Tcl_Interp *interp, int typ)
 	      color = "#ff0000";
 	      ps = BZ_CENTERPOINT_SIZE;
 	    }
-	    
+
 	    argc = 1;
 	    sprintf(tag, "pt%d", ii);
 	    WriteArgv( argv, &argc, "ssffff", "coords", tag,
 		       vp_points[0] - ps, vp_points[1] - ps,
 		       vp_points[0] + ps, vp_points[1] + ps);
-	    (*info.proc)(info.clientData, interp, argc, argv);
-	  
+	    (*info.proc)(info.clientData, interp, argc, (const char**) argv);
+
 	    /* change the stack order */
 	    argc = 1;
 	    sprintf(tag, "pt%d", ii);
 	    WriteArgv( argv, &argc, "sss", "raise", tag, "all");
-	    (*info.proc)(info.clientData, interp, argc, argv);
+	    (*info.proc)(info.clientData, interp, argc, (const char**) argv);
 	  }
 	}
       } else if ( iorder[i+1] > bz[typ].npoint && 
@@ -1080,7 +1111,7 @@ BzRenderBZ(Tcl_Interp *interp, int typ)
 	      sprintf(tag, "vector v1_%d", j);
 	      WriteArgv( argv, &argc, "sssfss", "-fill", "#0000ff", 
 			 "-width", ps, "-tags", tag);
-	      (*info.proc)(info.clientData, interp, argc, argv);	    
+	      (*info.proc)(info.clientData, interp, argc, (const char**) argv);	    
 	    } else {
 	      j = iorder[i+1] - (bz[typ].nZpoint + xcr.dim + 1);
 	      /* 2nd part of vector */
@@ -1094,13 +1125,13 @@ BzRenderBZ(Tcl_Interp *interp, int typ)
 	      WriteArgv( argv, &argc, "ssffff", "create", "line",
 			 bz[typ].vp_recvec[j+3][0], bz[typ].vp_recvec[j+3][1],
 			 bz[typ].vp_recvec[j+6][0], bz[typ].vp_recvec[j+6][1]);
-		
+
 	      sprintf(tag, "vector v2_%d", j);
 	      WriteArgv( argv, &argc, "sssssssfss", "-fill", "#0000ff", 
 			 "-arrow", "last", "-arrowshape", arrow,
 			 "-width", ps, "-tags", tag);
-	      (*info.proc)(info.clientData, interp, argc, argv);
-	      
+	      (*info.proc)(info.clientData, interp, argc, (const char**) argv);
+
 	      /*
 	       * create label of recvectors
 	       */
@@ -1114,7 +1145,7 @@ BzRenderBZ(Tcl_Interp *interp, int typ)
 	      else text = "c*";	/* if (j == 2) */
 	      WriteArgv( argv, &argc, "ssssssss", "-fill", "#0000ff", 
 			 "-anchor", "ne", "-text", text, "-tags", tag);
-	      (*info.proc)(info.clientData, interp, argc, argv);
+	      (*info.proc)(info.clientData, interp, argc, (const char**) argv);
 	    }	    
 	  } else {
 	    /*********************
@@ -1129,7 +1160,7 @@ BzRenderBZ(Tcl_Interp *interp, int typ)
 	      WriteArgv( argv, &argc, "ssffff", "coords", tag,
 			 bz[typ].vp_recvec[j][0], bz[typ].vp_recvec[j][1],
 			 bz[typ].vp_recvec[j+3][0], bz[typ].vp_recvec[j+3][1]);
-	      (*info.proc)(info.clientData, interp, argc, argv);
+	      (*info.proc)(info.clientData, interp, argc, (const char**) argv);
 	      /* reconfigure recvectors */
 	      argc = 1;
 	      sprintf(tag, "v1_%d", j);
@@ -1138,14 +1169,14 @@ BzRenderBZ(Tcl_Interp *interp, int typ)
 		ps = 1.0;
 	      WriteArgv( argv, &argc, "sssf", "itemconfigure", tag, 
 			 "-width", ps); 
-	      (*info.proc)(info.clientData, interp, argc, argv);
+	      (*info.proc)(info.clientData, interp, argc, (const char**) argv);
 	      /*
 	       * get the right stack order for 1st part
 	       */
 	      argc = 1;
 	      sprintf(tag, "v1_%d", j);
 	      WriteArgv( argv, &argc, "sss", "raise", tag, "all" );
-	      (*info.proc)(info.clientData, interp, argc, argv);	       
+	      (*info.proc)(info.clientData, interp, argc, (const char**) argv);	       
 	    } else {
 	      j = iorder[i+1] - (bz[typ].nZpoint + xcr.dim + 1);
 	      /* update 2nd part of RECVECTORS */
@@ -1154,7 +1185,7 @@ BzRenderBZ(Tcl_Interp *interp, int typ)
 	      WriteArgv( argv, &argc, "ssffff", "coords", tag,
 			 bz[typ].vp_recvec[j+3][0], bz[typ].vp_recvec[j+3][1],
 			 bz[typ].vp_recvec[j+6][0], bz[typ].vp_recvec[j+6][1]);
-	      (*info.proc)(info.clientData, interp, argc, argv);
+	      (*info.proc)(info.clientData, interp, argc, (const char**) argv);
 	      /* reconfigure recvectors */
 	      argc = 1;
 	      ps = 2.0;
@@ -1167,14 +1198,14 @@ BzRenderBZ(Tcl_Interp *interp, int typ)
 	      sprintf(tag, "v2_%d", j);
 	      WriteArgv( argv, &argc, "sssssf", "itemconfigure", tag, 
 			 "-arrowshape", arrow, "-width", ps);
-	      (*info.proc)(info.clientData, interp, argc, argv);
-	      
+	      (*info.proc)(info.clientData, interp, argc, (const char**) argv);
+
 	      /*
 	       * get the right stack order for 2nd part
 	       */
 	      argc = 1;
 	      WriteArgv( argv, &argc, "sss", "raise", tag, "all" );
-	      (*info.proc)(info.clientData, interp, argc, argv);
+	      (*info.proc)(info.clientData, interp, argc, (const char**) argv);
 
 	      /*
 	       * update label of recvector
@@ -1184,25 +1215,25 @@ BzRenderBZ(Tcl_Interp *interp, int typ)
 	      WriteArgv( argv, &argc, "ssff", "coords", tag,
 			 bz[typ].vp_recvec[j+6][0] - 5, 
 			 bz[typ].vp_recvec[j+6][1]);
-	      (*info.proc)(info.clientData, interp, argc, argv);
-	      
+	      (*info.proc)(info.clientData, interp, argc, (const char**) argv);
+
 	      /*
 		printf("RECVEC:: iorder i=%d, ii=%d, v(z)=%f, p(z)=%f\n",
 		i,ii,
 		bz[typ].rot_recvec[i][2], bz[typ].rot_points[ii][2]);
 	      */
-	      	      
+
 	      /*
 		printf("RECVEC:: iorder i=%d, ii=%d, v(z)=%f, p(z)=%f\n",
 		i, ii,
 		bz[typ].rot_recvec[i][2], bz[typ].rot_points[ii][2]);
 		fflush(stdout);
 	      */
-	      
+
 	      argc = 1;
 	      sprintf(tag, "t%d", j);
 	      WriteArgv( argv, &argc, "sss", "raise", tag, "all" );
-	      (*info.proc)(info.clientData, interp, argc, argv);	      
+	      (*info.proc)(info.clientData, interp, argc, (const char**) argv);	      
 	    }
 	  }
 	}
@@ -1231,16 +1262,16 @@ BzRenderBZ(Tcl_Interp *interp, int typ)
       ps = BZ_BOLD_POINT_SIZE;
       if ( bz[typ].pointtype[ii] == BZ_CENTERPOINT )
 	ps = BZ_CENTERPOINT_SIZE;
-      
+
       color = "#00ff66";
       sprintf(tag, "selpoint spt%d", i);
-      
+
       WriteArgv( argv, &argc, "ffffssssssss",
 		 bz[typ].vp_points[ii][0] - ps, bz[typ].vp_points[ii][1] - ps,
 		 bz[typ].vp_points[ii][0] + ps, bz[typ].vp_points[ii][1] + ps,
 		 "-fill", color, "-outline", color, 
 		 "-width", "1", "-tags", tag);	
-      (*info.proc)(info.clientData, interp, argc, argv);
+      (*info.proc)(info.clientData, interp, argc, (const char**) argv);
       bz[typ].selected_is_rendered[i] = 1;
     } else {
       ps = BZ_BOLD_POINT_SIZE;
@@ -1252,12 +1283,12 @@ BzRenderBZ(Tcl_Interp *interp, int typ)
 		 bz[typ].vp_points[ii][1] - ps,
 		 bz[typ].vp_points[ii][0] + ps,
 		 bz[typ].vp_points[ii][1] + ps);
-      (*info.proc)(info.clientData, interp, argc, argv);
-      
+      (*info.proc)(info.clientData, interp, argc, (const char**) argv);
+
       /* change the stack order */
       argc = 1;
       WriteArgv( argv, &argc, "sss", "raise", tag, "all");
-      (*info.proc)(info.clientData, interp, argc, argv);
+      (*info.proc)(info.clientData, interp, argc, (const char**) argv);
     }
   }
 
@@ -1276,7 +1307,7 @@ BzRenderBZ(Tcl_Interp *interp, int typ)
 		 (bz[typ].slinetype[i] & BZ_EDGEPOINT) ) ) {
       int pID, pID0, pID1;
       float sum0 = 0.0, sum1 = 0.0;
-      
+
       pID0 = bz[typ].sline_index[i][0];
       pID1 = bz[typ].sline_index[i][1];
       /* if xcr.dim < 3, the second pID will be negative */
@@ -1287,24 +1318,24 @@ BzRenderBZ(Tcl_Interp *interp, int typ)
 	  sum0 += bz[typ].rot_poly[pID0][j][2];
 	for(j=0; j<bz[typ].nvert[pID1]; j++)
 	  sum1 += bz[typ].rot_poly[pID1][j][2];
-	
+
 	sum0 /= (float) bz[typ].nvert[pID0];
 	sum1 /= (float) bz[typ].nvert[pID1];
-	
+
 	pID = pID0;
 	if ( sum1 > sum0 )
 	  pID = pID1;    
-	
+
 	printf("LINE:: pID=%d, pID1=%d, pID2=%d; %f %f\n",
 	       pID, pID0, pID1, sum0, sum1);
 	fflush(stdout);
       }
       sprintf(tag, "p%d", pID);
-      
+
       BzUpdateSelLine( interp, info, argv, typ, i, tag );
     }
   }
-  
+
   bz[typ].isrendered = 1;
   bz_state[typ].last_points  = bz_state[typ].points;
   bz_state[typ].last_vectors = bz_state[typ].vectors;
@@ -1315,28 +1346,28 @@ BzRenderBZ(Tcl_Interp *interp, int typ)
     free((FREE_ARG) argv[i] );
 
   xcdebug ("end of BzRenderBZ #1");
-  
+
   return TCL_OK;
 }
-  
-  
+
+
 static void
 BzCreateSelLine( Tcl_Interp *interp, Tcl_CmdInfo info, 
 		 char *argv[], int typ, int i)
 {
   char tag[80], aps[3];
   int  argc = 1;
-  
+
   sprintf(aps, "%d", BZ_BOLD_POLYGON_WIDTH);
   sprintf(tag, "selline sln%d", i);
-  
+
   WriteArgv( argv, &argc, "ssffffssssssssss", "create", "line", 
 	     bz[typ].vp_sline[i][0], bz[typ].vp_sline[i][1],
 	     bz[typ].vp_sline[i][2], bz[typ].vp_sline[i][3],
 	     "-fill", "#00ff66", "-arrow", "last",
 	     "-arrowshape", "14 15 4", "-width", aps, "-tags", tag);
-  (*info.proc)(info.clientData, interp, argc, argv);
-  
+  (*info.proc)(info.clientData, interp, argc, (const char**) argv);
+
   bz[typ].sline_is_rendered[i] = 1;
 }
 
@@ -1351,14 +1382,14 @@ BzUpdateSelLine( Tcl_Interp *interp, Tcl_CmdInfo info,
   WriteArgv( argv, &argc, "ssffff", "coords", tg,
 	     bz[typ].vp_sline[i][0], bz[typ].vp_sline[i][1],
 	     bz[typ].vp_sline[i][2], bz[typ].vp_sline[i][3]);
-  (*info.proc)(info.clientData, interp, argc, argv);
-  
+  (*info.proc)(info.clientData, interp, argc, (const char**) argv);
+
   /* change the stack order */
   argc = 1;
   WriteArgv( argv, &argc, "sss", "raise", tg, tag);
   printf("LINE:: tag == %s\n", tag);
   fflush(stdout);
-  (*info.proc)(info.clientData, interp, argc, argv);
+  (*info.proc)(info.clientData, interp, argc, (const char**) argv);
 }
 
 
@@ -1370,7 +1401,7 @@ BzGetISS( int typ )
   register int iss;
   register double f, point;
   register double tol = (double)(BZ_ISS - 1)/(double)BZ_ISS - (double)(BZ_ISS - 2)/(double)(BZ_ISS - 1);
-  register int k, l, i, j, n;
+  register int k, l, i, n;
   register double min;
 
   n = 3 * BZ_MAXPOINTS;
@@ -1403,7 +1434,7 @@ BzGetISS( int typ )
 		    min  = f;
 		    imin = i;
 		  }
-	  
+
 		  if ( f < tol ) {
 		    imen[n + l] = i;
 		    break;
@@ -1448,7 +1479,7 @@ BzGetISS( int typ )
 
   /* now find the minimum common multiplier */
   iss = imen[0];
-  
+
   n = 3 * bz[typ].nselected;
   for (i=1; i<n; i++)
     {
@@ -1486,6 +1517,6 @@ BzGetMinMult( int a, int b )
       c = i;
       break;
     }
-  
+
   return a * c;
 }
