@@ -20,7 +20,7 @@
 
 */
 
-#include "togl.h" 
+#include <togl.h> 
 #include <stdio.h> 
 #include <math.h> 
 #include <stdlib.h>
@@ -112,7 +112,7 @@ extern GLuint tempEnable3Dlist;
 GLuint xcGenLists( GLsizei i );
 void (*xcDisplay)(struct Togl *togl) = 0x0; 
 void xcDisplayFunc( void (*Func)(struct Togl *togl) ); 
-void xcToglDisplayFunc( struct Togl *togl ); 
+int xcToglDisplayFunc(ClientData clientData, Tcl_Interp *interp, int objc, Tcl_Obj *const *objv);
 void xcDummyDisplay( struct Togl *togl ); 
 void xcGenDispList(void); 
 void xcWireFrame2D(struct Togl *togl); 
@@ -165,7 +165,7 @@ static void HandleDisplay(struct Togl *togl);
 static void draw_scene(void);
 static void CameraHome(void);
 static void Normalise(XYZ *p);
-static XYZ CalcNormal(XYZ p, XYZ p1, XYZ p2);
+/*static XYZ CalcNormal(XYZ p, XYZ p1, XYZ p2);*/
 
 /* --- extern function prototypes ---  */
 extern int MakeSticks1(int i,
@@ -241,16 +241,29 @@ xcDisplayFunc( void (*Func)(struct Togl *togl) )
 
 /*****************************************************************************/
 /*void cryDisplayFunc( void (*DispFunc)(struct Togl *togl), struct Togl *togl );*/ 
-void  
-xcToglDisplayFunc(struct Togl *togl ) 
-{ 
-  if ( togl == Togl_FindTogl(".mesa") ) { 
+int
+xcToglDisplayFunc(ClientData clientData, Tcl_Interp *interp,
+                  int objc, Tcl_Obj *const *objv)
+{
+  Togl *togl;
+  /*static int toglIsInteractive = 0;*/
+
+  if (objc != 2) {
+    Tcl_WrongNumArgs(interp, 1, objv, "pathName");
+    return TCL_ERROR;
+  }
+  if (Togl_GetToglFromObj(interp, objv[1], &togl) != TCL_OK) {
+    return TCL_ERROR;
+  }
+  
+  if ( togl == mesa_togl ) {
     if (xcDisplay) (*xcDisplay)(togl); 
   } else { 
     NEW_WIN_CONTEXT *wc = FindWinContextByTogl( togl ); 
     /*cryDisplayFunc( wc->xcDisplay, togl );*/ 
     if (wc->xcDisplay) wc->xcDisplay( togl ); 
-  } 
+  }
+  return TCL_OK;
 } 
 /* 
 void cryDisplayFunc( void (*DispFunc)(struct Togl *togl), struct Togl *togl ) 
@@ -449,16 +462,16 @@ xcPointLine2D(struct Togl *togl)
 
 
 void xcBall2D( int iatom ) {
-  GLint     nstep, i, nat; 
+  GLint     nstep, i, atmn;
   GLdouble  sine, cosine;
   GLdouble  sizeArray[3];
   GLuint    displayList[2];
 
-  nat   = (coor + iatom)->nat; 
+  atmn   = (coor + iatom)->nat; 
   nstep = 3 * CalcTessFactor();
   if ( nstep < 8 )  nstep = 8; 
 
-  sizeArray[0]   = rball[nat];
+  sizeArray[0]   = rball[atmn];
   sizeArray[1]   = (GLdouble) nstep; 
   sizeArray[2]   = (GLdouble) VPf.OUTlinewidth;
   displayList[0] = findList1 (BALL, sizeArray, 3);
@@ -469,8 +482,8 @@ void xcBall2D( int iatom ) {
 	       GL_COMPILE_AND_EXECUTE ); 
       glBegin(GL_POLYGON);
       for(i=0; i < nstep; i++) {
-	cosine = rball[nat] * cos((GLdouble) i * 2.0 * PI / (GLdouble) nstep);
-	sine   = rball[nat] * sin((GLdouble) i * 2.0 * PI / (GLdouble) nstep);
+	cosine = rball[atmn] * cos((GLdouble) i * 2.0 * PI / (GLdouble) nstep);
+	sine   = rball[atmn] * sin((GLdouble) i * 2.0 * PI / (GLdouble) nstep);
 	glVertex2d( cosine, sine );
       }
       glEnd();
@@ -481,8 +494,8 @@ void xcBall2D( int iatom ) {
       glColor3f (0.0, 0.0, 0.0); 
       glBegin(GL_LINE_LOOP); 
       for(i=0; i < nstep; i++) { 
-	cosine = rball[nat] * cos((GLdouble) i * 2.0 * PI / (GLdouble) nstep); 
-	sine   = rball[nat] * sin((GLdouble) i * 2.0 * PI / (GLdouble) nstep); 
+	cosine = rball[atmn] * cos((GLdouble) i * 2.0 * PI / (GLdouble) nstep); 
+	sine   = rball[atmn] * sin((GLdouble) i * 2.0 * PI / (GLdouble) nstep); 
 	glVertex2d( cosine, sine ); 
       } 
       glEnd(); 
@@ -494,12 +507,11 @@ void xcBall2D( int iatom ) {
   }
 }
 void xcSmallBall2D( int iatom ) {
-  GLint     nstep, i, nat; 
+  GLint     nstep, i; 
   GLdouble  sine, cosine;
   GLdouble  sizeArray[3];
   GLuint    displayList[2];
 
-  nat   = (coor + iatom)->nat; 
   nstep = 3 * CalcTessFactor();
   if ( nstep < 8 )  nstep = 8; 
 
@@ -540,16 +552,16 @@ void xcSmallBall2D( int iatom ) {
   }
 }
 void xcBigBall2D( int iatom ) {
-  GLint     nstep, i, nat; 
+  GLint     nstep, i, atmn; 
   GLdouble  sine, cosine;
   GLdouble  sizeArray[3];
   GLuint    displayList[2];
 
-  nat   = (coor + iatom)->nat; 
+  atmn   = (coor + iatom)->nat; 
   nstep = 6 * CalcTessFactor();
   if ( nstep < 8 )  nstep = 8; 
 
-  sizeArray[0]   = atrad[nat]; /* size of hydrogen atom */
+  sizeArray[0]   = atrad[atmn]; /* size of hydrogen atom */
   sizeArray[1]   = (GLdouble) nstep; 
   sizeArray[2]   = (GLdouble) VPf.OUTlinewidth;
   displayList[0] = findList1 (BALL, sizeArray, 3);
@@ -561,8 +573,8 @@ void xcBigBall2D( int iatom ) {
 	       GL_COMPILE_AND_EXECUTE ); 
       glBegin(GL_POLYGON);
       for(i=0; i < nstep; i++) {
-	cosine = atrad[nat] * cos((GLdouble) i * 2.0 * PI / (GLdouble) nstep);
-	sine   = atrad[nat] * sin((GLdouble) i * 2.0 * PI / (GLdouble) nstep);
+	cosine = atrad[atmn] * cos((GLdouble) i * 2.0 * PI / (GLdouble) nstep);
+	sine   = atrad[atmn] * sin((GLdouble) i * 2.0 * PI / (GLdouble) nstep);
 	glVertex2d( cosine, sine );
       }
       glEnd();
@@ -573,8 +585,8 @@ void xcBigBall2D( int iatom ) {
       glColor3f (0.0, 0.0, 0.0); 
       glBegin(GL_LINE_LOOP); 
       for(i=0; i < nstep; i++) { 
-	cosine = atrad[nat] * cos((GLdouble) i * 2.0 * PI / (GLdouble) nstep); 
-	sine   = atrad[nat] * sin((GLdouble) i * 2.0 * PI / (GLdouble) nstep); 
+	cosine = atrad[atmn] * cos((GLdouble) i * 2.0 * PI / (GLdouble) nstep); 
+	sine   = atrad[atmn] * sin((GLdouble) i * 2.0 * PI / (GLdouble) nstep); 
 	glVertex2d( cosine, sine ); 
       } 
       glEnd(); 
@@ -627,7 +639,6 @@ xcBallStick12D(struct Togl *togl)
 		  &x1, &y1, &z1,   &x2, &y2, &z2, 
 		  &x3, &y3, &z3,   &x4, &y4, &z4);
       glBegin(GL_POLYGON);
-        /* glColor3fv( atcol[(coor + *(iwksp + i))->nat] ); */
         if ( VPf.unibond) glColor3fv(unibondCol);
         else glColor3fv( atm.col[(coor + *(iwksp + i))->sqn] ); 
 	glVertex3d( x1, y1, z1);
@@ -2023,16 +2034,26 @@ xcMakeProjection2D(const char *mode)
   GLdouble size;
     
   FindMaxRad();
-  if ( strcmp(mode,"WF") == 0 || strcmp(mode,"PL") == 0 )
-    /* 1.1 is just some additional offset */
-    size = (MVf.structsize + VPf.PLradius / VPf.VPfactor) * 1.1; 
-  else if ( mode[0] == 'B' || strcmp(mode,"PB") == 0 ) {
-    size = (MVf.structsize + max.r * VPf.ballf) * 1.1;
-  }
-  else if ( strcmp(mode,"SF") == 0 ) {
-    size = (MVf.structsize + max.r * VPf.atradf) * 1.1;
-  }
-  
+  /* 
+     this is too much complicated and the drawback is that the size of 
+     displayed structure changes when chaning mode --> simplify !
+  */
+
+  /* if ( strcmp(mode,"WF") == 0 || strcmp(mode,"PL") == 0 ) */
+  /*   /\* 1.1 is just some additional offset *\/ */
+  /*   size = (MVf.structsize + VPf.PLradius / VPf.VPfactor) * 1.1;  */
+  /* else if ( mode[0] == 'B' || strcmp(mode,"PB") == 0 ) { */
+  /*   size = (MVf.structsize + max.r * VPf.ballf) * 1.1; */
+  /* } */
+  /* else if ( strcmp(mode,"SF") == 0 ) { */
+  /*   size = (MVf.structsize + max.r * VPf.atradf) * 1.1; */
+  /* } */
+
+  /* this is much simpler */
+  /*size = MVf.structsize * (size + max.r) * 1.1;*/
+  /*size = MVf.structsize * (1.0 + max.r) * 1.1;*/
+  size = (MVf.structsize + 2.0*max.r) * 1.05;
+
   _xcMakeProjection(size);
 }
 
@@ -2052,12 +2073,22 @@ xcMakeProjection3D(const char *mode)
 /* 		      GL_LIGHT7 }; */
 
   FindMaxRad();
-  size = MVf.structsize;
-  if ( strcmp(mode,"sticks") == 0 || strcmp(mode,"balls") == 0 )
-    size = (size + max.r * VPf.ballf) * 1.1;
-  else if ( strcmp(mode,"space") == 0 )
-    size = (size + max.r) * 1.1;
+ /* 
+     this is too much complicated and the drawback is that the size of 
+     displayed structure changes when chaning mode --> simplify !
+  */
+  
+  /* size = MVf.structsize; */
+  /* if ( strcmp(mode,"sticks") == 0 || strcmp(mode,"balls") == 0 ) */
+  /*   size = (size + max.r * VPf.ballf) * 1.1; */
+  /* else if ( strcmp(mode,"space") == 0 ) */
+  /*   size = (size + max.r) * 1.1; */
 
+  /* this is much simpler */
+  /*size = MVf.structsize * (size + max.r) * 1.1;*/
+  /*size = MVf.structsize * (1.0 + max.r) * 1.1;*/
+  size = (MVf.structsize + 2.0*max.r) * 1.05;
+  
   _xcMakeProjection(size);
 }
  
@@ -2071,6 +2102,7 @@ static void _xcMakeProjection(GLdouble size) {
   static double old_fulls_vs_structs = 1.0;
 
   structsize = size;
+  
   /* if isoXXXXX is rendered, than it may be greater than the structure,
    * take this into account
    */
@@ -2121,7 +2153,7 @@ static void _xcMakeProjection(GLdouble size) {
   }
 
   /* assign glOrtho dimensions to OrhoProj ort */
-  ort.size = size;
+  ort.size = (size > 1.0 ? size : 1.0);
 
   /* MaybeClipAndMakeProjection(); */
   xcViewPort();
@@ -2613,27 +2645,27 @@ Normalise(XYZ *p)
   p1,p2 on the surface. The normal points in the direction
   of p1 crossproduct p2
 */
-static XYZ 
-CalcNormal(XYZ p,XYZ p1,XYZ p2)
-{
-  XYZ n,pa,pb;
+/* static XYZ  */
+/* CalcNormal(XYZ p,XYZ p1,XYZ p2) */
+/* { */
+/*   XYZ n,pa,pb; */
 
-  pa.x = p1.x - p.x;
-  pa.y = p1.y - p.y;
-  pa.z = p1.z - p.z;
-  pb.x = p2.x - p.x;
-  pb.y = p2.y - p.y;
-  pb.z = p2.z - p.z;
-  Normalise(&pa);
-  Normalise(&pb);
+/*   pa.x = p1.x - p.x; */
+/*   pa.y = p1.y - p.y; */
+/*   pa.z = p1.z - p.z; */
+/*   pb.x = p2.x - p.x; */
+/*   pb.y = p2.y - p.y; */
+/*   pb.z = p2.z - p.z; */
+/*   Normalise(&pa); */
+/*   Normalise(&pb); */
 
-  n.x = pa.y * pb.z - pa.z * pb.y;
-  n.y = pa.z * pb.x - pa.x * pb.z;
-  n.z = pa.x * pb.y - pa.y * pb.x;
-  Normalise(&n);
+/*   n.x = pa.y * pb.z - pa.z * pb.y; */
+/*   n.y = pa.z * pb.x - pa.x * pb.z; */
+/*   n.z = pa.x * pb.y - pa.y * pb.x; */
+/*   Normalise(&n); */
 
-  return(n);
-}
+/*   return(n); */
+/* } */
 
 
 
