@@ -16,7 +16,7 @@
 
 */
 
-#include "togl.h"
+#include <togl.h>
 #include <stdio.h>
 #include <string.h>
 #include "struct.h"
