@@ -1,22 +1,22 @@
 /*
- 
- *****************************************************************************
- * Author:                                                                   *
- * ------                                                                    *
- *  Anton Kokalj                                  Email: Tone.Kokalj@ijs.si  *
- *  Department of Physical and Organic Chemistry  Phone: x 386 1 477 3523    *
- *  Jozef Stefan Institute                          Fax: x 386 1 477 3811    *
- *  Jamova 39, SI-1000 Ljubljana                                             *
- *  SLOVENIA                                                                 *
- *                                                                           *
- * Source: $XCRYSDEN_TOPDIR/C/xcIsoSpaceSel.c
- * ------                                                                    *
- * Copyright (c) 1996-2003 by Anton Kokalj                                   *
- *****************************************************************************
+
+*****************************************************************************
+* Author:                                                                   *
+* ------                                                                    *
+*  Anton Kokalj                                  Email: Tone.Kokalj@ijs.si  *
+*  Department of Physical and Organic Chemistry  Phone: x 386 1 477 3523    *
+*  Jozef Stefan Institute                          Fax: x 386 1 477 3811    *
+*  Jamova 39, SI-1000 Ljubljana                                             *
+*  SLOVENIA                                                                 *
+*                                                                           *
+* Source: $XCRYSDEN_TOPDIR/C/xcIsoSpaceSel.c
+* ------                                                                    *
+* Copyright (c) 1996-2003 by Anton Kokalj                                   *
+*****************************************************************************
 
 */
 
-#include "togl.h"
+#include <togl.h>
 #include <tk.h>
 #include <GL/gl.h>
 #include <string.h>
@@ -37,7 +37,7 @@ static double cage_orig[3];
 extern int normalizepvfv(float *vec);
 
 static int Paralle2D( GetComOption points, GetComOption mar, 
-		       boolean rectangular );
+		      boolean rectangular );
 static int Center2D( GetComOption center, GetComOption nml, 
 		     float size, float rot );
 static void GetFractCoor(double ivec[][4], double frcoor[4][3]);
@@ -83,14 +83,14 @@ static void GetFractCoor(double ivec[][4], double frcoor[4][3]);
  */
 int
 XC_IsoSpaceSelCmd(ClientData clientData, Tcl_Interp *interp,
-		  int argc, char *argv[])
+		  int argc, const char *argv[])
 { 
   struct Togl *togl;
   register int i, j;
   double size = 1.0, rot = 0.0, (*cvec)[4];
   static float rotate = 0.0;
   char *result = Tcl_Alloc( sizeof(char) * 512); /* maximum lenght of result 
-						   string is 512 characters */
+						    string is 512 characters */
 
   boolean  rectangular  = 0;
   boolean  paralle2D_is = 0;
@@ -110,14 +110,16 @@ XC_IsoSpaceSelCmd(ClientData clientData, Tcl_Interp *interp,
 
   /* HERE */
   if ( argc < 3) {
-    interp->result = "Usage:   xc_isospacesel <toglName> init\n or\n paralle2D -points {x1 y1 z1  x2 y2 z2  x3 y3 z3} -margins {ab cd ad bc} -rectangular 0|1\n or\n center2D  -center {x y z} -normal {x y z} -size size -rotate rot\n or\n clear";
-      return TCL_ERROR;
+    Tcl_SetResult(interp, "Usage:   xc_isospacesel <toglName> init\n or\n paralle2D -points {x1 y1 z1  x2 y2 z2  x3 y3 z3} -margins {ab cd ad bc} -rectangular 0|1\n or\n center2D  -center {x y z} -normal {x y z} -size size -rotate rot\n or\n clear", TCL_STATIC);
+    return TCL_ERROR;
   }
 
   /* find togl associated with toglName */
-  if ( ( togl = Togl_FindTogl(argv[1]) ) == NULL ) {
-    sprintf(interp->result, 
-	    "couldn't find %s togl widget", argv[1]);
+  if ( Togl_GetToglFromName(interp, argv[1], &togl) == TCL_ERROR ) {
+    char rss[1024];
+    snprintf(rss, sizeof(rss), 
+	     "couldn't find %s togl widget", argv[1]);
+    Tcl_SetResult(interp, rss, TCL_VOLATILE);
     return TCL_ERROR;
   }
 
@@ -133,7 +135,9 @@ XC_IsoSpaceSelCmd(ClientData clientData, Tcl_Interp *interp,
 	   syntax: -points {x1 y1 z1   x2 y2 z2   x3 y3 z3   x4 y4 z4}
 	*/
 	if ( !xcSplitList( XC_GET_FLOAT12, interp, &argv[i+1], &points ) ) {
-	  sprintf(interp->result, "parse error; when parsing -points {%s}; should be -points {x1 y1 z1   x2 y2 z2   x3 y3 z3   x4 y4 z4}", argv[i+1]);
+	  char rss[1024];
+	  snprintf(rss, sizeof(rss), "parse error; when parsing -points {%s}; should be -points {x1 y1 z1   x2 y2 z2   x3 y3 z3   x4 y4 z4}", argv[i+1]);
+	  Tcl_SetResult(interp, rss, TCL_VOLATILE);
 	  return TCL_ERROR;
 	}
       }
@@ -142,7 +146,9 @@ XC_IsoSpaceSelCmd(ClientData clientData, Tcl_Interp *interp,
 	  syntax: -margins {ab cd ad bc}
 	*/
 	if ( !xcSplitList( XC_GET_FLOAT4, interp, &argv[i+1], &margins ) ) {
-	  sprintf(interp->result, "parse error; when parsing -margins {%s}; should be -margins {ab cd ad bc}", argv[i+1]);
+	  char rss[1024];
+	  snprintf(rss, sizeof(rss), "parse error; when parsing -margins {%s}; should be -margins {ab cd ad bc}", argv[i+1]);
+	  Tcl_SetResult(interp, rss, TCL_VOLATILE);
 	  return TCL_ERROR;	
 	} 
       }
@@ -151,12 +157,16 @@ XC_IsoSpaceSelCmd(ClientData clientData, Tcl_Interp *interp,
 	  syntax: -rectangular 0|1
 	*/
 	if ( Tcl_GetInt( interp, argv[i+1], &rectangular ) == TCL_ERROR ) {
-	  sprintf(interp->result, "wanted integer, but got %s", argv[i+1]);
+	  char rss[1024];
+	  snprintf(rss, sizeof(rss), "wanted integer, but got %s", argv[i+1]);
+	  Tcl_SetResult(interp, rss, TCL_VOLATILE);
 	  return TCL_ERROR;		  
 	} 
       }
       else {
-	sprintf(interp->result, "unknown options %s for xc_isospacesel <mesaWin> paralle2D, should be one of -points, -margins or -rectangular", argv[i]);
+	char rss[1024];
+	snprintf(rss, sizeof(rss), "unknown options %s for xc_isospacesel <mesaWin> paralle2D, should be one of -points, -margins or -rectangular", argv[i]);
+	Tcl_SetResult(interp, rss, TCL_VOLATILE);
 	return TCL_ERROR;
       }
     }
@@ -169,7 +179,9 @@ XC_IsoSpaceSelCmd(ClientData clientData, Tcl_Interp *interp,
 	  syntax: -center {x y z}
 	*/
 	if ( !xcSplitList( XC_GET_XYZ, interp, &argv[i+1], &center ) ) {
-	  sprintf(interp->result, "parse error; when parsing -center {%s}; should be -center {x y z}", argv[i+1]);
+	  char rss[1024];
+	  snprintf(rss, sizeof(rss), "parse error; when parsing -center {%s}; should be -center {x y z}", argv[i+1]);
+	  Tcl_SetResult(interp, rss, TCL_VOLATILE);
 	  return TCL_ERROR;
 	}	
       }
@@ -178,24 +190,32 @@ XC_IsoSpaceSelCmd(ClientData clientData, Tcl_Interp *interp,
 	  syntax: -normal {x y z}
 	*/
 	if ( !xcSplitList( XC_GET_XYZ, interp, &argv[i+1], &normal ) ) {
-	  sprintf(interp->result, "parse error; when parsing -normal {%s}; should be -normal {x y z}", argv[i+1]);
+	  char rss[1024];
+	  snprintf(rss, sizeof(rss), "parse error; when parsing -normal {%s}; should be -normal {x y z}", argv[i+1]);
+	  Tcl_SetResult(interp, rss, TCL_VOLATILE);
 	  return TCL_ERROR;
 	}		
       }
       else if ( strcmp(argv[i], "-size") == 0 ) {
 	if ( Tcl_GetDouble( interp, argv[i+1], &size ) == TCL_ERROR ) {
-	  sprintf(interp->result, "wanted double, but got %s", argv[i+1]);
+	  char rss[1024];
+	  snprintf(rss, sizeof(rss), "wanted double, but got %s", argv[i+1]);
+	  Tcl_SetResult(interp, rss, TCL_VOLATILE);
 	  return TCL_ERROR;		  
 	}
       }
       else if ( strncmp(argv[i], "-rot", 4) == 0 ) {
 	if ( Tcl_GetDouble( interp, argv[i+1], &rot ) == TCL_ERROR ) {
-	  sprintf(interp->result, "wanted double, but got %s", argv[i+1]);
+	  char rss[1024];
+	  snprintf(rss, sizeof(rss), "wanted double, but got %s", argv[i+1]);
+	  Tcl_SetResult(interp, rss, TCL_VOLATILE);
 	  return TCL_ERROR;
 	}
       }
       else {
-	sprintf(interp->result, "unknown option %s for xc_isospacesel <mesaWin> center2D, should be one of -center, -normal, -size or -rotate", argv[i]);
+	char rss[1024];
+	snprintf(rss, sizeof(rss), "unknown option %s for xc_isospacesel <mesaWin> center2D, should be one of -center, -normal, -size or -rotate", argv[i]);
+	Tcl_SetResult(interp, rss, TCL_VOLATILE);
 	return TCL_ERROR;
       }
     }
@@ -210,14 +230,18 @@ XC_IsoSpaceSelCmd(ClientData clientData, Tcl_Interp *interp,
 	else if ( strcmp(argv[i+1], "conv") == 0 ) {
 	  cvec = vec.conv;
 	} else {
-	  sprintf(interp->result, 
-		  "unknown cell type %s, must be prim or conv", argv[i+1]);
+	  char rss[1024];
+	  snprintf(rss, sizeof(rss), 
+		   "unknown cell type %s, must be prim or conv", argv[i+1]);
+	  Tcl_SetResult(interp, rss, TCL_VOLATILE);
 	  return TCL_ERROR;
 	}
       }
       else if ( strcmp(argv[i], "-margins") == 0 ) {
 	if ( !xcSplitList( XC_GET_FLOAT6, interp, &argv[i+1], &margins ) ) {
-	  sprintf(interp->result, "parse error; when parsing -margins {%s}; should be -margins {a b c a* b* c*}", argv[i+1]);
+	  char rss[1024];
+	  snprintf(rss, sizeof(rss), "parse error; when parsing -margins {%s}; should be -margins {a b c a* b* c*}", argv[i+1]);
+	  Tcl_SetResult(interp, rss, TCL_VOLATILE);
 	  return TCL_ERROR;
 	}	
       }
@@ -228,7 +252,9 @@ XC_IsoSpaceSelCmd(ClientData clientData, Tcl_Interp *interp,
     /* use vec.recprim or vec.recconv */    
     /* so far argv[3] should be -vtype */
     if ( argc != 5 ) {
-      sprintf(interp->result, "Usage: xc_isospacesel <toglName> fractcoor -vtype prim|conv");
+      char rss[1024];
+      snprintf(rss, sizeof(rss), "Usage: xc_isospacesel <toglName> fractcoor -vtype prim|conv");
+      Tcl_SetResult(interp, rss, TCL_VOLATILE);
       return TCL_ERROR;
     }
     if ( strcmp(argv[4], "prim") == 0 ) {
@@ -238,7 +264,9 @@ XC_IsoSpaceSelCmd(ClientData clientData, Tcl_Interp *interp,
       /* according to conventional vectors */
       GetFractCoor(vec.recconv, frcoor);
     } else {
-      sprintf(interp->result, "unknown vector type %s, must be prim or conv", argv[4]);
+      char rss[1024];
+      snprintf(rss, sizeof(rss), "unknown vector type %s, must be prim or conv", argv[4]);
+      Tcl_SetResult(interp, rss, TCL_VOLATILE);
       return TCL_ERROR;
     }
     /* get the results */
@@ -256,18 +284,19 @@ XC_IsoSpaceSelCmd(ClientData clientData, Tcl_Interp *interp,
     VPf.isospacesel3D = GL_FALSE;
   }
   else {
-    sprintf(interp->result, "unknown type \"%s\" of xc_isospacesel <mesaWin> command, should be one of init, paralle2D, center2D or clear", argv[2]);
+    char rss[1024];
+    snprintf(rss, sizeof(rss), "unknown type \"%s\" of xc_isospacesel <mesaWin> command, should be one of init, paralle2D, center2D or clear", argv[2]);
+    Tcl_SetResult(interp, rss, TCL_VOLATILE);
     return TCL_ERROR;
   }
-  
+
 
   if (paralle2D_is) {
     /* 
        paralle2D mode
     */
     if (!Paralle2D( points, margins, rectangular )) {
-      interp->result = 
-	"atomic positions You have selected are linearly dependent";
+      Tcl_SetResult(interp, "Usage: xc_iso isoplane <type> <colorBase> <scalefunc> <what> ?<islide>?", TCL_STATIC);
       return TCL_ERROR;
     }
     VPf.isospacesel2D = GL_TRUE;
@@ -279,8 +308,7 @@ XC_IsoSpaceSelCmd(ClientData clientData, Tcl_Interp *interp,
     */
     rotate += rot;
     if (!Center2D( center, normal, size, rotate )) {
-      interp->result = 
-	"zero vector was submitted for normal, when executing xc_isospacesel <mesaWin> center2D -normal {x y z}";
+      Tcl_SetResult(interp, "zero vector was submitted for normal, when executing xc_isospacesel <mesaWin> center2D -normal {x y z}", TCL_STATIC);	
       return TCL_ERROR;
     }
     VPf.isospacesel2D = GL_TRUE;
@@ -320,7 +348,7 @@ XC_IsoSpaceSelCmd(ClientData clientData, Tcl_Interp *interp,
 	cage_orig[i] = -margins.vec[i];
       mat[0][0] =  margins.vec[0] + margins.vec[3];
     }
-    
+
     SetUnitCellCage( mat, &cage );
     MVf.isospaceselsize = 
       DetermineParapipedSized(mat[0], mat[1], mat[2], cage_orig);
@@ -489,8 +517,8 @@ Paralle2D( GetComOption points, GetComOption mar, boolean rectangular )
   }
   return XC_OK;
 }
-    
-     
+
+
 static int
 Center2D( GetComOption center, GetComOption nml, float size, float rot )
 {
@@ -502,7 +530,7 @@ Center2D( GetComOption center, GetComOption nml, float size, float rot )
   if ( fabs(nml.vec[0]) < 1.0e-3 &&
        fabs(nml.vec[1]) < 1.0e-3 &&
        fabs(nml.vec[2]) < 1.0e-3 ) return XC_ERROR; /* zero-lenght normal */
-  
+
   if ( (nml.vec[0] * nml.vec[1] * nml.vec[2]) < 1.0e-4 ) {
     v[0] = 0.0;
     v[1] = 0.0;
@@ -518,13 +546,13 @@ Center2D( GetComOption center, GetComOption nml, float size, float rot )
     v[1] = 1.0;
     v[2] = - (nml.vec[0]*v[0] + nml.vec[1]*v[1]) / nml.vec[2];
   }
-  
+
   VecProduct3f( v, nml.vec, vnml );
   normalizepvfv( v );
   normalizepvfv( vnml );
   if ( fabs(v[0]*vnml[0]+v[1]*vnml[1]+v[2]*vnml[2]) > 1.e-6 )
     xcError("VecProduct3f is false!!!");
-  
+
   /* let the size be half of square edge, not square diagonal */
   size *= 2.0 / sqrt(3.0);
   for (i=0; i<3; i++) {
@@ -563,7 +591,7 @@ IsoSpaceSel_Parallelogram(void)
   GLboolean switch_shademodel = GL_FALSE;
   GLboolean switch_lightmodel = GL_FALSE;
   GLboolean switch_cullface   = GL_FALSE;
- 
+
   /*glPushAttrib();*/
 
   /* TRANSPARENCY */
@@ -571,21 +599,21 @@ IsoSpaceSel_Parallelogram(void)
   glEnable( GL_BLEND );
   glDepthMask( GL_FALSE );
   glBlendFunc( blend_cellcage.sfunc, blend_cellcage.dfunc );
-  
+
   /* SHADEMODEL */
   glGetIntegerv( GL_SHADE_MODEL, &shade_model );
   if ( shade_model != GL_FLAT ) { 
     switch_shademodel = GL_TRUE;
     glShadeModel( GL_FLAT );
   } 
-  
+
   /* LIGHTMODEL */
   glGetBooleanv( GL_LIGHT_MODEL_TWO_SIDE, &two_side );
   if ( !two_side ) {
     switch_lightmodel = GL_TRUE;
     glLightModeli( GL_LIGHT_MODEL_TWO_SIDE, GL_TRUE );
   }
- 
+
   /* CULL FACE */
   glGetBooleanv( GL_CULL_FACE, &cull_face );
   if ( cull_face ) {
@@ -596,18 +624,18 @@ IsoSpaceSel_Parallelogram(void)
   LoadCageOrVecMaterial( GLPAR_ISOPARALLE );
 
   glPushMatrix();
-    glTranslated( -mx, -my, -mz );
-    xcParallelogram( XCPRIM_SOLID_AND_BORDER, poi, poi_nml );
+  glTranslated( -mx, -my, -mz );
+  xcParallelogram( XCPRIM_SOLID_AND_BORDER, poi, poi_nml );
   glPopMatrix();
 
   /* get back the previous GL state */
   glDisable(GL_BLEND); 
   glDepthMask(GL_TRUE);  
- 
+
   if ( switch_shademodel ) {
     glShadeModel( GL_SMOOTH );
   }
-  
+
   if ( switch_lightmodel ) {
     glLightModeli( GL_LIGHT_MODEL_TWO_SIDE, GL_FALSE );
   }
@@ -629,27 +657,27 @@ IsoSpaceSel_3D(void)
   GLboolean switch_shademodel = GL_FALSE;
   GLboolean switch_lightmodel = GL_FALSE;
   GLboolean switch_cullface   = GL_FALSE;
- 
+
   /* TRANSPARENCY */
   LoadBlendfunc_And_Frontface();
   glEnable( GL_BLEND );
   glDepthMask( GL_FALSE );
   glBlendFunc( blend_cellcage.sfunc, blend_cellcage.dfunc );
-  
+
   /* SHADEMODEL */
   glGetIntegerv( GL_SHADE_MODEL, &shade_model );
   if ( shade_model != GL_FLAT ) { 
     switch_shademodel = GL_TRUE;
     glShadeModel( GL_FLAT );
   } 
-  
+
   /* LIGHTMODEL */
   glGetBooleanv( GL_LIGHT_MODEL_TWO_SIDE, &two_side );
   if ( !two_side ) {
     switch_lightmodel = GL_TRUE;
     glLightModeli( GL_LIGHT_MODEL_TWO_SIDE, GL_TRUE );
   }
- 
+
   /* CULL FACE */
   glGetBooleanv( GL_CULL_FACE, &cull_face );
   if ( cull_face ) {
@@ -660,20 +688,20 @@ IsoSpaceSel_3D(void)
   LoadCageOrVecMaterial( GLPAR_ISOPARALLE );
 
   glPushMatrix();
-    glTranslated( -mx + cage_orig[0], -my + cage_orig[1], -mz + cage_orig[2]);
-    glLineWidth( 2.0 );
-    xcWireCage( cage );
-    xcSolidCage( cage );
+  glTranslated( -mx + cage_orig[0], -my + cage_orig[1], -mz + cage_orig[2]);
+  glLineWidth( 2.0 );
+  xcWireCage( cage );
+  xcSolidCage( cage );
   glPopMatrix();
 
   /* get back the previous GL state */
   glDisable(GL_BLEND); 
   glDepthMask(GL_TRUE);  
- 
+
   if ( switch_shademodel ) {
     glShadeModel( GL_SMOOTH );
   }
-  
+
   if ( switch_lightmodel ) {
     glLightModeli( GL_LIGHT_MODEL_TWO_SIDE, GL_FALSE );
   }
