@@ -1,23 +1,23 @@
 /*
- 
- *****************************************************************************
- * Author:                                                                   *
- * ------                                                                    *
- *  Anton Kokalj                                  Email: Tone.Kokalj@ijs.si  *
- *  Department of Physical and Organic Chemistry  Phone: x 386 1 477 3523    *
- *  Jozef Stefan Institute                          Fax: x 386 1 477 3811    *
- *  Jamova 39, SI-1000 Ljubljana                                             *
- *  SLOVENIA                                                                 *
- *                                                                           *
- * Source: $XCRYSDEN_TOPDIR/C/xcSelect.c
- * ------                                                                    *
- * Copyright (c) 1996-2003 by Anton Kokalj                                   *
- *****************************************************************************
+
+*****************************************************************************
+* Author:                                                                   *
+* ------                                                                    *
+*  Anton Kokalj                                  Email: Tone.Kokalj@ijs.si  *
+*  Department of Physical and Organic Chemistry  Phone: x 386 1 477 3523    *
+*  Jozef Stefan Institute                          Fax: x 386 1 477 3811    *
+*  Jamova 39, SI-1000 Ljubljana                                             *
+*  SLOVENIA                                                                 *
+*                                                                           *
+* Source: $XCRYSDEN_TOPDIR/C/xcSelect.c
+* ------                                                                    *
+* Copyright (c) 1996-2003 by Anton Kokalj                                   *
+*****************************************************************************
 
 */
 
 extern void xcdebug(const char *text);
-#include "togl.h"
+#include <togl.h>
 #include <string.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -54,22 +54,22 @@ typedef struct {
   int sqn;    /* SQN of selected atom */
 } SelAtom;
 SelAtom asel[MAXSEL + 1];       /* asel is counted from 1..MAXSEL */
-  
+
 typedef struct {
   int nat;
   float xat;
   float yat;
 } AtomsCoor;  
 AtomsCoor *acrd; /* here we don't have zat, because of 'hpsort_index1' 
-			 * function, which
-			 * don't allow usage of struct-variables and also 
-			 * for selections only xat & yat are important
-			 */
+		  * function, which
+		  * don't allow usage of struct-variables and also 
+		  * for selections only xat & yat are important
+		  */
 double *acrd_z;   /* in above struct, we don't have "Z-orientation"
-			   variable, this is one */
+		     variable, this is one */
 
 int old_nobjects; /* it tells how many objects were there before
-			    selection process begins */
+		     selection process begins */
 int *zindex; /* here will go an Z-orientation order of atoms */
 
 float tol;  /* X and Y tolerance for selections */
@@ -92,7 +92,7 @@ SELECT_DEBUG sel_debug;
 /*****************************************************************************/
 /* --- function prototypes --- */
 int XC_SelectCmd(ClientData clientData, Tcl_Interp *interp, 
-		 int argc, char *argv[]);
+		 int argc, const char *argv[]);
 static float dist2(float x, float y);
 static void xcUpdateCoorf( double mat[][4], float *x, float *y, double *z);
 void (*old_xcDisplay)(struct Togl *togl) = 0x0;
@@ -101,8 +101,8 @@ static void MapToSelDispFunc(void);
 int xcSelectSqn(int x, int y);
 static void xcSelectAtom(int sqn, char *atomdata);
 /*
-static void xcMakeSelBallList(int sqn);
-static void xcMakeNewSelBallList( GLdouble *sizeArray , int natom );
+  static void xcMakeSelBallList(int sqn);
+  static void xcMakeNewSelBallList( GLdouble *sizeArray , int natom );
 */
 static void  xcSelectLine(int sqn1, int sqn2);
 void GetSelCylinderPar(double x21, double y21, double z21, 
@@ -114,7 +114,7 @@ void xcBallStick2Sel(struct Togl *togl);
 void xcRenderSelAtoms3D(void);
 void xcRenderSelBonds3D(void);
 int XC_DeselectCmd(ClientData clientData, Tcl_Interp *interp,
-		   int argc, char *argv[]);
+		   int argc, const char *argv[]);
 static void PushOneCoor(int i, int ii);
 /*static void xcUpdateSelLists(int id);*/
 /*static void SelectDebug(struct Togl *togl);*/
@@ -173,20 +173,22 @@ extern void Screen2Model_Coords(int xs, int ys, float *xm, float *ym);
  */	
 int 
 XC_SelectCmd(ClientData clientData, Tcl_Interp *interp,
-	     int argc, char *argv[])
+	     int argc, const char *argv[])
 {
   struct Togl *togl;
   int x,y; /* mesaWin coord of Button-1 */
 
   if (argc < 3) {
-    interp->result = "Usage: xc_select <toglName> sqn|atom|line|clean|flush|finish ?value1? ?value2?";
+    Tcl_SetResult(interp, "Usage: xc_select <toglName> sqn|atom|line|clean|flush|finish ?value1? ?value2?", TCL_STATIC);
     return TCL_ERROR;
   }
 
   /* find togl associated with toglName */
-  if ( ( togl = Togl_FindTogl(argv[1]) ) == NULL ) {
-    sprintf(interp->result, 
-	    "couldn't find %s togl widget", argv[1]);
+  if ( Togl_GetToglFromName(interp, argv[1], &togl) == TCL_ERROR ) {
+    char rss[1024];
+    snprintf(rss, sizeof(rss), 
+	     "couldn't find %s togl widget", argv[1]);
+    Tcl_SetResult(interp, rss, TCL_VOLATILE);
     return TCL_ERROR;
   }
 
@@ -233,21 +235,25 @@ XC_SelectCmd(ClientData clientData, Tcl_Interp *interp,
     char *csqn = Tcl_Alloc( sizeof(char) * 10 );
     /* argc must be 5 */
     if ( argc != 5 ) {
-      interp->result = "wrong usage of \"xc_select <toglName> sqn\" command, must be \"xc_select <toglName> sqn <x> <y>\"";
+      Tcl_SetResult(interp, "wrong usage of \"xc_select <toglName> sqn\" command, must be \"xc_select <toglName> sqn <x> <y>\"", TCL_STATIC);
       return TCL_ERROR;
     }
     /* agrv[3],argv[4] must be integers */
     if ( Tcl_GetInt(interp,argv[3],&x) == TCL_ERROR ) {
-      sprintf(interp->result,"got invalid value for <x>, while executing %s %s %s %s %s\n",argv[0],argv[1],argv[2],argv[3],argv[4]);
+      char rss[1024];
+      snprintf(rss, sizeof(rss),"got invalid value for <x>, while executing %s %s %s %s %s\n",argv[0],argv[1],argv[2],argv[3],argv[4]);
+      Tcl_SetResult(interp, rss, TCL_VOLATILE);
       return TCL_ERROR;
     }
     if ( Tcl_GetInt(interp,argv[4],&y) == TCL_ERROR ) {
-      sprintf(interp->result,"got invalid value for <y>, while executing %s %s %s %s %s\n",argv[0],argv[1],argv[2],argv[3],argv[4]);
+      char rss[1024];
+      snprintf(rss, sizeof(rss),"got invalid value for <y>, while executing %s %s %s %s %s\n",argv[0],argv[1],argv[2],argv[3],argv[4]);
+      Tcl_SetResult(interp, rss, TCL_VOLATILE);
       return TCL_ERROR;
     }  
     /* if there were no "xc_selct begin" than ERROR */
     if ( !VPf.selection ) {
-      interp->result = "calling \"xc_select sqn\" command, before initialising selection process with \"xc_select begin\"";
+      Tcl_SetResult(interp, "calling \"xc_select sqn\" command, before initialising selection process with \"xc_select begin\"", TCL_STATIC);
       return TCL_ERROR;
     }
     /* now find sequential number of atom, if no atom find, retun 0 */
@@ -266,75 +272,87 @@ XC_SelectCmd(ClientData clientData, Tcl_Interp *interp,
     int sqn;
     char *atomdata = Tcl_Alloc(sizeof(char) * 80 );
     if ( argc != 4 ) {
-      interp->result = "wrong usage of \"xc_select <toglName> atom\" command, must be \"xc_select <toglName> atom <sqn>\"";
+      Tcl_SetResult(interp, "wrong usage of \"xc_select <toglName> atom\" command, must be \"xc_select <toglName> atom <sqn>\"", TCL_STATIC);
       return TCL_ERROR;
     }
     /* agrv[3] must be integer */
     if ( Tcl_GetInt(interp,argv[3],&sqn) == TCL_ERROR ) {
-      sprintf(interp->result,"got invalid value for <sqn>, while executing %s %s %s %s\n",argv[0],argv[1],argv[2],argv[3]);
+      char rss[1024];
+      snprintf(rss, sizeof(rss),"got invalid value for <sqn>, while executing %s %s %s %s\n",argv[0],argv[1],argv[2],argv[3]);
+      Tcl_SetResult(interp, rss, TCL_VOLATILE);
       return TCL_ERROR;
     }
     /* sqn must be in [1,natoms], else nothing good */
     if ( sqn < 1 || sqn > natoms ) {
-      sprintf(interp->result,"got invalid value for <sqn>, while executing %s %s %s %s; must be from 1 to %d",argv[0],argv[1],argv[2],argv[3],natoms);
+      char rss[1024];
+      snprintf(rss, sizeof(rss),"got invalid value for <sqn>, while executing %s %s %s %s; must be from 1 to %d",argv[0],argv[1],argv[2],argv[3],natoms);
+      Tcl_SetResult(interp, rss, TCL_VOLATILE);
       return TCL_ERROR;
     }
     /* if there were no "xc_selct begin" than ERROR */
     if ( !VPf.selection ) {
-      interp->result = "calling \"xc_select atom\" command, before initialising selection process with \"xc_select begin\"";
+      Tcl_SetResult(interp, "calling \"xc_select atom\" command, before initialising selection process with \"xc_select begin\"", TCL_STATIC);
       return TCL_ERROR;
     }
 
     xcSelectAtom(sqn, atomdata);
     Tcl_SetResult(interp,atomdata,TCL_DYNAMIC);
   }
-  
+
   /***************************************************************************/
   /* implementation of "XC_SELECT <toglName> LINE <sqn1> <sqn2> */
   else if ( strcmp(argv[2],"line") == 0 ) {
     int sqn1, sqn2;
     if ( argc != 5 ) {
-      interp->result = "wrong usage of \"xc_select <toglName> line\" command, must be \"xc_select <toglName> line <sqn1> <sqn2>\"";
+      Tcl_SetResult(interp, "wrong usage of \"xc_select <toglName> line\" command, must be \"xc_select <toglName> line <sqn1> <sqn2>\"", TCL_STATIC);
       return TCL_ERROR;
     }
     /* agrv[3],argv[4] must be integers */
     if ( Tcl_GetInt(interp,argv[3],&sqn1) == TCL_ERROR ) {
-      sprintf(interp->result,"got invalid value for <sqn1>, while executing %s %s %s %s %s\n",argv[0],argv[1],argv[2],argv[3],argv[4]);
+      char rss[1024];
+      snprintf(rss, sizeof(rss),"got invalid value for <sqn1>, while executing %s %s %s %s %s\n",argv[0],argv[1],argv[2],argv[3],argv[4]);
+      Tcl_SetResult(interp, rss, TCL_VOLATILE);
       return TCL_ERROR;
     }
     if ( Tcl_GetInt(interp,argv[4],&sqn2) == TCL_ERROR ) {
-      sprintf(interp->result,"got invalid value for <sqn2>, while executing %s %s %s %s %s\n",argv[0],argv[1],argv[2],argv[3],argv[4]);
+      char rss[1024];
+      snprintf(rss, sizeof(rss),"got invalid value for <sqn2>, while executing %s %s %s %s %s\n",argv[0],argv[1],argv[2],argv[3],argv[4]);
+      Tcl_SetResult(interp, rss, TCL_VOLATILE);
       return TCL_ERROR;
     }
     /* sqn1,sqn2 must be in [1,natoms], else nothing good */
     if ( (sqn1 < 1 && sqn1 > natoms) || (sqn2 < 1 && sqn2 > natoms) ) {
-      sprintf(interp->result,"got invalid value for <sqn1> or <sqn2>, while executing %s %s %s %s %s; must be from 1 to %d",argv[0],argv[1],argv[2],argv[3],argv[4],natoms);
+      char rss[1024];
+      snprintf(rss, sizeof(rss),"got invalid value for <sqn1> or <sqn2>, while executing %s %s %s %s %s; must be from 1 to %d",argv[0],argv[1],argv[2],argv[3],argv[4],natoms);
+      Tcl_SetResult(interp, rss, TCL_VOLATILE);
       return TCL_ERROR;
     }
     if ( sqn1 == sqn2 ) {
-      sprintf(interp->result,"<sqn1> and <sqn2> are the same; while executing %s %s %s %s %s",argv[0],argv[1],argv[2],argv[3],argv[4]);
+      char rss[1024];
+      snprintf(rss, sizeof(rss),"<sqn1> and <sqn2> are the same; while executing %s %s %s %s %s",argv[0],argv[1],argv[2],argv[3],argv[4]);
+      Tcl_SetResult(interp, rss, TCL_VOLATILE);
       return TCL_ERROR;
     }
     /* when calling XC_SELECT LINE, at least two atoms must be selected !!!! */
     if ( nsel < 2 ) {
-      interp->result = "at least two atoms must be selected, before calling \"xc_select line <sqn1> <sqn2>\"";
+      Tcl_SetResult(interp, "at least two atoms must be selected, before calling \"xc_select line <sqn1> <sqn2>\"", TCL_STATIC);
       return TCL_ERROR;
     }
     /* if there were no "xc_selct begin" than ERROR */
     if ( !VPf.selection ) {
-      interp->result = "calling \"xc_select line\" command, before initialising selection process with \"xc_select begin\"";
+      Tcl_SetResult(interp, "calling \"xc_select line\" command, before initialising selection process with \"xc_select begin\"", TCL_STATIC);
       return TCL_ERROR;
     }
 
     xcSelectLine(sqn1, sqn2);
   }
-  
+
   /***************************************************************************/
   /* implementaion of "XC_SELECT <toglName> CLEAN"; to clean */
   else if ( strcmp(argv[2],"clean") == 0 ) {  
     /* if there were no "xc_select <toglName> begin" than ERROR */
     if ( !VPf.selection ) {
-      interp->result = "calling \"xc_select clean\" command, before initialising selection process with \"xc_select begin\"";
+      Tcl_SetResult(interp, "calling \"xc_select clean\" command, before initialising selection process with \"xc_select begin\"", TCL_STATIC);
       return TCL_ERROR;
     }    
 
@@ -357,7 +375,7 @@ XC_SelectCmd(ClientData clientData, Tcl_Interp *interp,
     /* now update display */
     Togl_PostRedisplay(togl);
   }
-  
+
   /***************************************************************************/
   /* XC_SELECT FLUSH */
   else if ( strcmp(argv[2],"flush") == 0 ) {
@@ -375,7 +393,9 @@ XC_SelectCmd(ClientData clientData, Tcl_Interp *interp,
   /***************************************************************************/
   /* unknown option */
   else {
-    sprintf(interp->result,"unknown option \"%s\" for \"xc_select\" command, must be one of begin, sqn, atom, line, clean, flush, finish",argv[2]);
+    char rss[1024];
+    snprintf(rss, sizeof(rss),"unknown option \"%s\" for \"xc_select\" command, must be one of begin, sqn, atom, line, clean, flush, finish",argv[2]);
+    Tcl_SetResult(interp, rss, TCL_VOLATILE);
     return TCL_ERROR;
   }
 
@@ -446,9 +466,9 @@ MapToSelDispFunc(void)
       tol = (float) PIXTOL / VPf.scrAnX;
     }
     else if ( xcDisplay == xcPointLine2D ||
-	     xcDisplay == xcPointLineL2D ||
-	     xcDisplay == xcPointLineF2D ||
-	     xcDisplay == xcPointLineFL2D ) {
+	      xcDisplay == xcPointLineL2D ||
+	      xcDisplay == xcPointLineF2D ||
+	      xcDisplay == xcPointLineFL2D ) {
       isWF = 0;
       xcDisplayFunc(xcPointLineSel);    
       tol = (float) PIXTOL / VPf.scrAnX;      
@@ -517,7 +537,7 @@ xcSelectSqn(int x, int y)
     }
   /* now orientate according to Z */
   hpsort_index1(natoms, acrd_z, zindex);
-  
+
   /* now try to find an atom, if there is no atom, just return 0 */
   for(i=natoms; i>=1; i--)
     {
@@ -544,7 +564,7 @@ xcSelectSqn(int x, int y)
 
 	}
       }
-      
+
       dis = dist2( xx - (acrd + zindex[i])->xat, 
 		   yy - (acrd + zindex[i])->yat );
       if ( dis <= tol_ ) {
@@ -557,7 +577,7 @@ xcSelectSqn(int x, int y)
   /* if we come here we didn't find an atom */
   return 0;
 }
-	
+
 
 /*****************************************************************************/
 /* this function select an atom and return it's data
@@ -566,7 +586,7 @@ static void xcSelectAtom(int sqn, char *atomdata)
 {  
   int i;
   /*char *atomdata = (char *) malloc(sizeof(char) * 80);*/
-  
+
   nsel++; /* number of selected atoms is increased */
 
   /* put information of selected atom to 'asel' structure */
@@ -610,7 +630,7 @@ static void xcSelectAtom(int sqn, char *atomdata)
 
 
 /*
-static void xcMakeSelBallList(int sqn) {
+  static void xcMakeSelBallList(int sqn) {
   GLint     nstep, i, nat; 
   GLdouble  sine, cosine;
   GLdouble  sizeArray[3];
@@ -627,33 +647,33 @@ static void xcMakeSelBallList(int sqn) {
   displayList[1] = findList1 (OUTLINEBALL, sizeArray, 3);
 
   if ( displayList[0] == 0 ) {  
-    glNewList( makeModelPtr1 (BALL, sizeArray, 3),
-	       GL_COMPILE_AND_EXECUTE ); 
-      glBegin(GL_POLYGON);
-      for(i=0; i < nstep; i++) {
-	cosine = rball[nat] * cos((GLdouble) i * 2.0 * PI / (GLdouble) nstep);
-	sine   = rball[nat] * sin((GLdouble) i * 2.0 * PI / (GLdouble) nstep);
-	glVertex2d( cosine, sine );
-      }
-      glEnd();
-    glEndList();
+  glNewList( makeModelPtr1 (BALL, sizeArray, 3),
+  GL_COMPILE_AND_EXECUTE ); 
+  glBegin(GL_POLYGON);
+  for(i=0; i < nstep; i++) {
+  cosine = rball[nat] * cos((GLdouble) i * 2.0 * PI / (GLdouble) nstep);
+  sine   = rball[nat] * sin((GLdouble) i * 2.0 * PI / (GLdouble) nstep);
+  glVertex2d( cosine, sine );
+  }
+  glEnd();
+  glEndList();
 
-    glNewList( makeModelPtr1 (OUTLINEBALL, sizeArray, 3),
-	       GL_COMPILE_AND_EXECUTE );			      
-      glColor3f (0.0, 0.0, 0.0); 
-      glBegin(GL_LINE_LOOP); 
-      for(i=0; i < nstep; i++) { 
-	cosine = rball[nat] * cos((GLdouble) i * 2.0 * PI / (GLdouble) nstep); 
-	sine   = rball[nat] * sin((GLdouble) i * 2.0 * PI / (GLdouble) nstep); 
-	glVertex2d( cosine, sine ); 
-      } 
-      glEnd(); 
-    glEndList();
+  glNewList( makeModelPtr1 (OUTLINEBALL, sizeArray, 3),
+  GL_COMPILE_AND_EXECUTE );			      
+  glColor3f (0.0, 0.0, 0.0); 
+  glBegin(GL_LINE_LOOP); 
+  for(i=0; i < nstep; i++) { 
+  cosine = rball[nat] * cos((GLdouble) i * 2.0 * PI / (GLdouble) nstep); 
+  sine   = rball[nat] * sin((GLdouble) i * 2.0 * PI / (GLdouble) nstep); 
+  glVertex2d( cosine, sine ); 
+  } 
+  glEnd(); 
+  glEndList();
   } else {
-    glCallList (displayList[0]);
-    glCallList (displayList[1]);
+  glCallList (displayList[0]);
+  glCallList (displayList[1]);
+  }
   }
-}
 */
 /* / */
 
@@ -683,7 +703,7 @@ static void xcMakeSelBallList(int sqn) {
 /*   GLint nstep, i; */
 /*   int nab = (coor + natom)->nat; */
 /*   GLdouble sine, cosine, dstep; */
-  
+
 /*   nstep = (GLint) (3 * APPR_SCREENSIZE / (VPf.tessFactor * ort.size)); */
 
 /*   if ( nstep < 8 ) nstep = 8; */
@@ -762,7 +782,7 @@ xcSelectLine(int sqn1, int sqn2)
       (coor + i)->y2 = yat[sqn2];
       (coor + i)->z2 = zat[sqn2];
     }
-              
+
     xcUpdateCoor( vec.crdmajor, &(coor + i)->x1, &(coor + i)->y1, 
 		  &(coor + i)->z1 );
     xcUpdateCoor( vec.crdmajor, &(coor + i)->x2, &(coor + i)->y2, 
@@ -814,7 +834,7 @@ GetSelCylinderPar(double x21, double y21, double z21,
   *fibond = RAD2DEG * acos(z21);
 }
 
-    
+
 /*****************************************************************************/
 /*                      Selection Display Functions                          */
 /*****************************************************************************/
@@ -824,7 +844,7 @@ void
 xcPointLineSel(struct Togl *togl)
 {
   int i;
-    
+
   glClear(GL_COLOR_BUFFER_BIT);
   glLoadIdentity();
   if (VPf.perspective) 
@@ -838,14 +858,14 @@ xcPointLineSel(struct Togl *togl)
       {
 	glLineWidth( (GLfloat) VPf.PLlinewidth );  
 	glBegin(GL_LINES);
-           if ( VPf.unibond) glColor3fv(unibondCol);
-	   else glColor3fv( atm.col[(coor + *(iwksp + i))->sqn] );
-	   glVertex3d( (coor + *(iwksp + i))->x1, 
-		       (coor + *(iwksp + i))->y1, 
-		       (coor + *(iwksp + i))->z1 );
-	   glVertex3d( (coor + *(iwksp + i))->x2, 
-		       (coor + *(iwksp + i))->y2, 
-		       (coor + *(iwksp + i))->z2 );
+	if ( VPf.unibond) glColor3fv(unibondCol);
+	else glColor3fv( atm.col[(coor + *(iwksp + i))->sqn] );
+	glVertex3d( (coor + *(iwksp + i))->x1, 
+		    (coor + *(iwksp + i))->y1, 
+		    (coor + *(iwksp + i))->z1 );
+	glVertex3d( (coor + *(iwksp + i))->x2, 
+		    (coor + *(iwksp + i))->y2, 
+		    (coor + *(iwksp + i))->z2 );
 	glEnd();
       }
     if ( (coor + *(iwksp + i))->flag == ATOM )
@@ -861,7 +881,7 @@ xcPointLineSel(struct Togl *togl)
 	  glCallList( PointList );	
 	  glPopMatrix();	
 	}
-		
+
 	/* display labels only if VPf.lablesOn  */
 	if ( VPf.labelsOn ) {
 	  makeAtomLabel2D ( *(iwksp + i), rf.wp2, rf.hp2 );
@@ -877,18 +897,18 @@ xcPointLineSel(struct Togl *togl)
 	  }
 	  glLineWidth( (GLfloat) VPf.framewidth );  
 	  glBegin(GL_LINES);
-	    glColor3fv( framecol );
-	    glVertex3d( (coor + *(iwksp + i))->x1, 
-			(coor + *(iwksp + i))->y1, 
-			(coor + *(iwksp + i))->z1 );
-	    glVertex3d( (coor + *(iwksp + i))->x2, 
-			(coor + *(iwksp + i))->y2, 
-			(coor + *(iwksp + i))->z2 );
+	  glColor3fv( framecol );
+	  glVertex3d( (coor + *(iwksp + i))->x1, 
+		      (coor + *(iwksp + i))->y1, 
+		      (coor + *(iwksp + i))->z1 );
+	  glVertex3d( (coor + *(iwksp + i))->x2, 
+		      (coor + *(iwksp + i))->y2, 
+		      (coor + *(iwksp + i))->z2 );
 	  glEnd(); 
 	  glDisable(GL_LINE_STIPPLE);
 	}
     }
-    
+
     if ( (coor + *(iwksp + i))->flag == SELATOM )
       {
 	glColor3fv( atcol[SELCOL] );
@@ -907,12 +927,12 @@ xcPointLineSel(struct Togl *togl)
 	glLineWidth( SELLINE_WIDTH ); 
 	glColor3fv( atcol[SELCOL] );	  
 	glBegin(GL_LINES);
-	  glVertex3d( (coor + *(iwksp + i))->x1, 
-		      (coor + *(iwksp + i))->y1, 
-		      (coor + *(iwksp + i))->z1 );
-	  glVertex3d( (coor + *(iwksp + i))->x2, 
-		      (coor + *(iwksp + i))->y2, 
-		      (coor + *(iwksp + i))->z2 );
+	glVertex3d( (coor + *(iwksp + i))->x1, 
+		    (coor + *(iwksp + i))->y1, 
+		    (coor + *(iwksp + i))->z1 );
+	glVertex3d( (coor + *(iwksp + i))->x2, 
+		    (coor + *(iwksp + i))->y2, 
+		    (coor + *(iwksp + i))->z2 );
 	glEnd(); 
 	glDisable(GL_LINE_STIPPLE);
       }
@@ -921,12 +941,12 @@ xcPointLineSel(struct Togl *togl)
 	glLineWidth( SELLINE_WIDTH ); 
 	glColor3fv( atcol[SELCOL] );	  
 	glBegin(GL_LINES);
-	  glVertex3d( (coor + *(iwksp + i))->x1, 
-		      (coor + *(iwksp + i))->y1, 
-		      (coor + *(iwksp + i))->z1 );
-	  glVertex3d( (coor + *(iwksp + i))->x2, 
-		      (coor + *(iwksp + i))->y2, 
-		      (coor + *(iwksp + i))->z2 );
+	glVertex3d( (coor + *(iwksp + i))->x1, 
+		    (coor + *(iwksp + i))->y1, 
+		    (coor + *(iwksp + i))->z1 );
+	glVertex3d( (coor + *(iwksp + i))->x2, 
+		    (coor + *(iwksp + i))->y2, 
+		    (coor + *(iwksp + i))->z2 );
 	glEnd(); 
       }
     }
@@ -962,7 +982,7 @@ xcBallStick1Sel(struct Togl *togl)
   glLineWidth( VPf.OUTlinewidth );
   glEnable( GL_CULL_FACE );
   glCullFace( GL_BACK );
- 
+
   for(i = 1; i <= tmp_nobjects; i++) 
     {
       if ( (coor + *(iwksp + i))->flag == BOND )
@@ -971,22 +991,22 @@ xcBallStick1Sel(struct Togl *togl)
 		      &x1, &y1, &z1,   &x2, &y2, &z2, 
 		      &x3, &y3, &z3,   &x4, &y4, &z4);
 	  glColor3f( 0.0, 0.0, 0.0 );	    
-	
+
 	  if ( VPf.unibond) glColor3fv(unibondCol);
 	  else glColor3fv( atm.col[(coor + *(iwksp + i))->sqn] );
 	  glBegin(GL_POLYGON);
-	    glVertex3d( x1, y1, z1);
-	    glVertex3d( x2, y2, z2);
-	    glVertex3d( x3, y3, z3);
-	    glVertex3d( x4, y4, z4);
+	  glVertex3d( x1, y1, z1);
+	  glVertex3d( x2, y2, z2);
+	  glVertex3d( x3, y3, z3);
+	  glVertex3d( x4, y4, z4);
 	  glEnd();
 
 	  glBegin(GL_LINE_LOOP);
-	    glColor3f( 0.0, 0.0, 0.0 );
-	    glVertex3d( x1, y1, z1);
-	    glVertex3d( x2, y2, z2);
-	    glVertex3d( x3, y3, z3);
-	    glVertex3d( x4, y4, z4);
+	  glColor3f( 0.0, 0.0, 0.0 );
+	  glVertex3d( x1, y1, z1);
+	  glVertex3d( x2, y2, z2);
+	  glVertex3d( x3, y3, z3);
+	  glVertex3d( x4, y4, z4);
 	  glEnd();	      
 	}
       else if ( (coor + *(iwksp + i))->flag == ATOM ) 
@@ -1020,7 +1040,7 @@ xcBallStick1Sel(struct Togl *togl)
 	    makeAtomLabel2D ( *(iwksp + i), CENTERED_LABEL, CENTERED_LABEL);
 	  }            
 	}
-	
+
       /* display frames only if VPf.framesOn */
       if ( VPf.framesOn ) {
 	if ( (coor + *(iwksp + i))->flag == FRAME )
@@ -1031,18 +1051,18 @@ xcBallStick1Sel(struct Togl *togl)
 	    }
 	    glLineWidth( (GLfloat) VPf.framewidth );  
 	    glBegin(GL_LINES);
-	      glColor3fv( framecol );
-	      glVertex3d( (coor + *(iwksp + i))->x1, 
-			  (coor + *(iwksp + i))->y1, 
-			  (coor + *(iwksp + i))->z1 );
-	      glVertex3d( (coor + *(iwksp + i))->x2, 
-			  (coor + *(iwksp + i))->y2, 
-			  (coor + *(iwksp + i))->z2 );
+	    glColor3fv( framecol );
+	    glVertex3d( (coor + *(iwksp + i))->x1, 
+			(coor + *(iwksp + i))->y1, 
+			(coor + *(iwksp + i))->z1 );
+	    glVertex3d( (coor + *(iwksp + i))->x2, 
+			(coor + *(iwksp + i))->y2, 
+			(coor + *(iwksp + i))->z2 );
 	    glEnd();
 	    glDisable(GL_LINE_STIPPLE);
 	  }
       }
-    
+
       if ( (coor + *(iwksp + i))->flag == SELBOND )
 	{
 	  MakeSticks1(*(iwksp + i), 
@@ -1050,18 +1070,18 @@ xcBallStick1Sel(struct Togl *togl)
 		      &x3, &y3, &z3,   &x4, &y4, &z4);
 	  glColor3fv( atcol[SELCOL] );
 	  glBegin(GL_POLYGON);
-	    glVertex3d( x1, y1, z1);
-	    glVertex3d( x2, y2, z2);
-	    glVertex3d( x3, y3, z3);
-	    glVertex3d( x4, y4, z4);
+	  glVertex3d( x1, y1, z1);
+	  glVertex3d( x2, y2, z2);
+	  glVertex3d( x3, y3, z3);
+	  glVertex3d( x4, y4, z4);
 	  glEnd();
 
 	  glBegin(GL_LINE_LOOP);
-	    glColor3f( 0.0, 0.0, 0.0 );
-	    glVertex3d( x1, y1, z1);
-	    glVertex3d( x2, y2, z2);
-	    glVertex3d( x3, y3, z3);
-	    glVertex3d( x4, y4, z4);
+	  glColor3f( 0.0, 0.0, 0.0 );
+	  glVertex3d( x1, y1, z1);
+	  glVertex3d( x2, y2, z2);
+	  glVertex3d( x3, y3, z3);
+	  glVertex3d( x4, y4, z4);
 	  glEnd();  
 	}
 
@@ -1072,18 +1092,18 @@ xcBallStick1Sel(struct Togl *togl)
 	  glLineWidth( SELLINE_WIDTH ); 
 	  glColor3fv( atcol[SELCOL] );	  
 	  glBegin(GL_LINES);
-	    glVertex3d( (coor + *(iwksp + i))->x1, 
-			(coor + *(iwksp + i))->y1, 
-			(coor + *(iwksp + i))->z1 );
-	    glVertex3d( (coor + *(iwksp + i))->x2, 
-			(coor + *(iwksp + i))->y2, 
-			(coor + *(iwksp + i))->z2 );
+	  glVertex3d( (coor + *(iwksp + i))->x1, 
+		      (coor + *(iwksp + i))->y1, 
+		      (coor + *(iwksp + i))->z1 );
+	  glVertex3d( (coor + *(iwksp + i))->x2, 
+		      (coor + *(iwksp + i))->y2, 
+		      (coor + *(iwksp + i))->z2 );
 	  glEnd(); 
 	  glDisable(GL_LINE_STIPPLE);
 	}
     }
   glDisable( GL_CULL_FACE );
-  
+
   /* chack if coordinate sistem should be displayed */
   if ( VPf.xyzOn ) xcDisplayXYZ();
 
@@ -1151,7 +1171,7 @@ xcBallStick2Sel(struct Togl *togl)
 	    makeAtomLabel2D ( *(iwksp + i), CENTERED_LABEL, CENTERED_LABEL);
 	  } 
 	}
-      
+
       /* display frames only if VPf.framesOn */
       if ( VPf.framesOn ) {
 	if ( (coor + *(iwksp + i))->flag == FRAME )
@@ -1162,13 +1182,13 @@ xcBallStick2Sel(struct Togl *togl)
 	    }
 	    glLineWidth( (GLfloat) VPf.framewidth );  
 	    glBegin(GL_LINES);
-	      glColor3fv( framecol );
-	      glVertex3d( (coor + *(iwksp + i))->x1, 
-			  (coor + *(iwksp + i))->y1,
-			  (coor + *(iwksp + i))->z1 );
-	      glVertex3d( (coor + *(iwksp + i))->x2, 
-			  (coor + *(iwksp + i))->y2,
-			  (coor + *(iwksp + i))->z2 );
+	    glColor3fv( framecol );
+	    glVertex3d( (coor + *(iwksp + i))->x1, 
+			(coor + *(iwksp + i))->y1,
+			(coor + *(iwksp + i))->z1 );
+	    glVertex3d( (coor + *(iwksp + i))->x2, 
+			(coor + *(iwksp + i))->y2,
+			(coor + *(iwksp + i))->z2 );
 	    glEnd();
 	    glDisable(GL_LINE_STIPPLE);
 	  }
@@ -1179,7 +1199,7 @@ xcBallStick2Sel(struct Togl *togl)
 	  glLineWidth( VPf.OUTlinewidth );
 	  MakeSticks2(*(iwksp + i), 0, BALL);
 	}
-      
+
       if ( (coor + *(iwksp + i))->flag == SELLINE ) 
 	{
 	  glLineStipple( 2, SELLINE_PAT );
@@ -1187,18 +1207,18 @@ xcBallStick2Sel(struct Togl *togl)
 	  glLineWidth( SELLINE_WIDTH ); 
 	  glColor3fv( atcol[SELCOL] );	  
 	  glBegin(GL_LINES);
-	    glVertex3d( (coor + *(iwksp + i))->x1, 
-			(coor + *(iwksp + i))->y1, 
-			(coor + *(iwksp + i))->z1 );
-	    glVertex3d( (coor + *(iwksp + i))->x2, 
-			(coor + *(iwksp + i))->y2, 
-			(coor + *(iwksp + i))->z2 );
+	  glVertex3d( (coor + *(iwksp + i))->x1, 
+		      (coor + *(iwksp + i))->y1, 
+		      (coor + *(iwksp + i))->z1 );
+	  glVertex3d( (coor + *(iwksp + i))->x2, 
+		      (coor + *(iwksp + i))->y2, 
+		      (coor + *(iwksp + i))->z2 );
 	  glEnd(); 
 	  glDisable(GL_LINE_STIPPLE);
 	}
     }
   glDisable( GL_CULL_FACE );
-  
+
   /* chack if coordinate sistem should be displayed */
   if ( VPf.xyzOn ) xcDisplayXYZ();
 
@@ -1222,12 +1242,12 @@ xcRenderSelAtoms3D(void) {
 
   for (i=1; i<=nsel; i++) {
     ind = asel[i].sqn;
-  if(is.spacefillmode) r = atrad[*(nat + ind)];
-  else if(is.ballmode) r = rball[*(nat + ind)];
-  else r =  1.5 * rrod;
+    if(is.spacefillmode) r = atrad[*(nat + ind)];
+    else if(is.ballmode) r = rball[*(nat + ind)];
+    else r =  1.5 * rrod;
     glPushMatrix();
-      glTranslated( xat[ind], yat[ind], zat[ind] );
-      xcSolidSphere( 1.009 * r );
+    glTranslated( xat[ind], yat[ind], zat[ind] );
+    xcSolidSphere( 1.009 * r );
     glPopMatrix(); 
   }
 }
@@ -1253,18 +1273,18 @@ xcRenderSelBonds3D(void) {
       GetSelCylinderPar(xat[i2]-xat[i1], yat[i2]-yat[i1], zat[i2]-zat[i1],
 			&xrvb, &yrvb, &zrvb, &fibond, &bondl);
       glPushMatrix();
-        glTranslated( *(xat + i1), *(yat + i1), *(zat + i1) );
-	glRotated( fibond, xrvb, yrvb, zrvb );
-	xcSolidBond( 1.2 * rrod, bondl, BOND_ATOM_TO_ATOM );
-	glPopMatrix();
+      glTranslated( *(xat + i1), *(yat + i1), *(zat + i1) );
+      glRotated( fibond, xrvb, yrvb, zrvb );
+      xcSolidBond( 1.2 * rrod, bondl, BOND_ATOM_TO_ATOM );
+      glPopMatrix();
     } else {
       glCallList(tempDisable3Dlist);
       glEnable(GL_LINE_STIPPLE);
       glColor3fv( framecol );
       glLineWidth( SELLINE_WIDTH );
       glBegin(GL_LINES);
-        glVertex3d( *(xat + i1), *(yat + i1), *(zat + i1) );
-	glVertex3d( *(xat + i2), *(yat + i2), *(zat + i2) );
+      glVertex3d( *(xat + i1), *(yat + i1), *(zat + i1) );
+      glVertex3d( *(xat + i2), *(yat + i2), *(zat + i2) );
       glEnd();
       glDisable(GL_LINE_STIPPLE);   
       glCallList(tempEnable3Dlist);
@@ -1284,21 +1304,23 @@ xcRenderSelBonds3D(void) {
  */	
 int 
 XC_DeselectCmd(ClientData clientData, Tcl_Interp *interp,
-	       int argc, char *argv[])
+	       int argc, const char *argv[])
 {
   struct Togl *togl;
   int sqn; /* mesaWin coord of Button-1 */
   int i, id, ii, j, jj;
 
   if (argc < 3) {
-    interp->result = "Usage: xc_deselect <toglName> atom|line ?sqn?";
+    Tcl_SetResult(interp, "Usage: xc_deselect <toglName> atom|line ?sqn?", TCL_STATIC);
     return TCL_ERROR;
   }
 
   /* find togl associated with toglName */
-  if ( ( togl = Togl_FindTogl(argv[1]) ) == NULL ) {
-    sprintf(interp->result, 
-	    "couldn't find %s togl widget", argv[1]);
+  if ( Togl_GetToglFromName(interp, argv[1], &togl) == TCL_ERROR ) {
+    char rss[1024];
+    snprintf(rss, sizeof(rss), 
+	     "couldn't find %s togl widget", argv[1]);
+    Tcl_SetResult(interp, rss, TCL_VOLATILE);
     return TCL_ERROR;
   }
 
@@ -1311,15 +1333,17 @@ XC_DeselectCmd(ClientData clientData, Tcl_Interp *interp,
    */
   if ( strcmp(argv[2],"atom") == 0 ) {
     if (argc != 4) {
-      interp->result = "Usage: xc_deselect <toglName> atom <sqn>";
+      Tcl_SetResult(interp, "Usage: xc_deselect <toglName> atom <sqn>", TCL_STATIC);
       return TCL_ERROR;
     }
     /* agrv[3] must be integer */
     if ( Tcl_GetInt(interp,argv[3],&sqn) == TCL_ERROR ) {
-      sprintf(interp->result,"got invalid value for <sqn>, while executing %s %s %s %s\n",argv[0],argv[1],argv[2],argv[3]);
+      char rss[1024];
+      snprintf(rss, sizeof(rss),"got invalid value for <sqn>, while executing %s %s %s %s\n",argv[0],argv[1],argv[2],argv[3]);
+      Tcl_SetResult(interp, rss, TCL_VOLATILE);
       return TCL_ERROR;
     }
-    
+
     /* first find an atom for deselection */
     id = -1;
     for(i=1; i<=nsel; i++) {
@@ -1346,7 +1370,7 @@ XC_DeselectCmd(ClientData clientData, Tcl_Interp *interp,
      * that was never selected
      */
     if ( id == -1 ) {
-      interp->result = "attempt to deselect an atom, that was never selected";
+      Tcl_SetResult(interp, "attempt to deselect an atom, that was never selected", TCL_STATIC);
       return TCL_ERROR;
     }
     /* now I must delete sqn ATOM from "coor" and than rewrite the rest 
@@ -1381,47 +1405,49 @@ XC_DeselectCmd(ClientData clientData, Tcl_Interp *interp,
    */
   else if ( strcmp(argv[2],"line") == 0 ) {
     if (argc != 3) {
-      interp->result = "Usage: xc_deselect <toglName> line";
+      Tcl_SetResult(interp, "Usage: xc_deselect <toglName> line", TCL_STATIC);
       return TCL_ERROR;
     }
-      
+
     if ( dimType == XC_2D ) {
       for(i=old_nobjects; i<=tmp_nobjects; i++) 
 	printf("i=%d, flag=%d\n",i,(coor + i)->flag);
       for(i=old_nobjects; i<=tmp_nobjects; i++) {
 	printf("i=%d, flag=%d\n",i,(coor + i)->flag);
-	  if ( (coor + i)->flag == SELLINE || (coor + i)->flag == SELBOND ) {
-	    for(j=i; j<tmp_nobjects; j++) { 
-	      /* if j+1-objects is SELATOM, then all asel->id's elements
-	         that have greater id than j must be decreased for one */
-	      if ( (coor + j + 1)->flag == SELATOM )
-		for(jj=1; jj<=nsel; jj++)
-		  if ((asel + jj)->id > j) (asel + jj)->id -= 1;
-	      /* now also Push coor for one down */
-	      PushOneCoor(j,j + 1);	
-	    }    
-	    --i;
-	    --tmp_nobjects;	      
-	  }
+	if ( (coor + i)->flag == SELLINE || (coor + i)->flag == SELBOND ) {
+	  for(j=i; j<tmp_nobjects; j++) { 
+	    /* if j+1-objects is SELATOM, then all asel->id's elements
+	       that have greater id than j must be decreased for one */
+	    if ( (coor + j + 1)->flag == SELATOM )
+	      for(jj=1; jj<=nsel; jj++)
+		if ((asel + jj)->id > j) (asel + jj)->id -= 1;
+	    /* now also Push coor for one down */
+	    PushOneCoor(j,j + 1);	
+	  }    
+	  --i;
+	  --tmp_nobjects;	      
+	}
       }
       hpsort_index1(tmp_nobjects, zorient, iwksp);
     }
     else if ( dimType == XC_3D ) {
       xcdebug("delete LINES 3D\n");
-/*       for(i=0; i<MAXSEL-1; i++) a */
-/* 	if ( glIsList(LineSelList[i]) ) glDeleteLists(LineSelList[i],1); */
+      /*       for(i=0; i<MAXSEL-1; i++) a */
+      /* 	if ( glIsList(LineSelList[i]) ) glDeleteLists(LineSelList[i],1); */
       nline=0;
     }
   }
 
   else {
-    sprintf(interp->result,"unknown option \"%s\" for \"xc_deselect\" command, must be one of atom, line",argv[2]);
+    char rss[1024];
+    snprintf(rss, sizeof(rss),"unknown option \"%s\" for \"xc_deselect\" command, must be one of atom, line",argv[2]);
+    Tcl_SetResult(interp, rss, TCL_VOLATILE);
     return TCL_ERROR;
   }
 
   /* this is just for now */
   /* (*xcDisplay)(); */
-   
+
   return TCL_OK;
 }
 
@@ -1471,22 +1497,22 @@ PushOneCoor(int i, int ii)
 /*       glTranslated( -*(xat + sqn), -*(yat + sqn), -*(zat + sqn) ); */
 /*     glEndList(); */
 /*   } */
-  
+
 /*   /\*  (*xcDisplay)(); *\/ */
 /* } */
 
 /*
-static void
-SelectDebug(struct Togl *togl) 
-{
+  static void
+  SelectDebug(struct Togl *togl) 
+  {
   glColor3f(1.0, 1.0, 0.0);
   if ( dimType == XC_3D ) 
-    glMaterialfv( GL_FRONT, GL_AMBIENT_AND_DIFFUSE, atcol[0] );
+  glMaterialfv( GL_FRONT, GL_AMBIENT_AND_DIFFUSE, atcol[0] );
   glPointSize(20.0);
   glBegin(GL_POINTS);
   glVertex2f(0.0, 0.0);
   glVertex2f(sel_debug.xx, sel_debug.yy);    
   glEnd();
   Togl_SwapBuffers(togl);
-}
+  }
 */
