@@ -2,9 +2,9 @@
 c     ***************************************************
 c
       IMPLICIT REAL*8 (A-H,O-Z)
-      INCLUDE 'param.inc'
+cc      INCLUDE 'param.inc'
 c
-      dimension ener(NEVL)
+      dimension ener(*)
       character  aline*80
       character  ram_fi*80
 c-----------------------------------------------------------------------
@@ -38,3 +38,4 @@ c        5  eigenvalues have been read
          return
       endif
       end
+
