@@ -85,9 +85,9 @@ C     SOP...................SYM. OPERATORS (MATRICES)
 C     ***********************************************
 C     TRANSFORMATION of PRIMITIV CELL to CONVENTIONAL
 C     ***********************************************
-C     ============
-C     DEFINITIONS:
-C     ============
+C     ===================
+C     IGROUP DEFINITIONS:
+C     ===================
 C     GROUP NUMBER USED IN ftn34
 C     N.  symbol   N.of atoms   Variable
 C     1.....P   -->    1           PC
@@ -905,7 +905,7 @@ C     DETERMINE HOW MENY ATOMS WILL BE IN CONV. CELL
 
       SUBROUTINE GETCCOOR(A33,B33,BROW,X,Y,Z,XC,YC,ZC,NA,NATR)
       include 'param.inc'
-      REAL*8 B33(3,4),A33(3,3),RA(3,3),COOR(3),X(NATR),Y(NATR),Z(NATR),
+      REAL*8 B33(3,*),A33(3,3),RA(3,3),COOR(3),X(NATR),Y(NATR),Z(NATR),
      *     XC(NAC,4),YC(NAC,4),ZC(NAC,4),RX(3)
       INTEGER BROW
 
