@@ -40,7 +40,7 @@ proc ViewMol {top {file {}} } {
 
     # make a global widget arrangement, that is menu, mesawin, control & mea
 
-    PlaceGlobWin 0 [expr round(650 * $fac1)] [expr round(650 * $fac1)]
+    PlaceGlobWin 0 [expr round(670 * $fac1)] [expr round(670 * $fac1)]
     #if { [winfo exists .title] } { 
     #wm deiconify .
     #}
@@ -63,10 +63,10 @@ proc ViewMol {top {file {}} } {
     bind $top <Configure> { ResizeGlobWin }
 
     bind .mesa <Double-Button-1>  { maximizeDisplay on }
-    bind .mesa <B1-Motion>        { bindCB {.mesa xc_B1motion %x %y }}
-    bind .mesa <B2-Motion>        { bindCB {.mesa xc_B2motion %x %y }}
-    bind .mesa <B1-ButtonRelease> { bindCB {.mesa xc_Brelease B1}; MouseZoomBrelease %W }
-    bind .mesa <B2-ButtonRelease> { bindCB {.mesa xc_Brelease B2}; ResetCursor; }
+    bind .mesa <B1-Motion>        { bindCB {xc_B1motion .mesa %x %y }}
+    bind .mesa <B2-Motion>        { bindCB {xc_B2motion .mesa %x %y }}
+    bind .mesa <B1-ButtonRelease> { bindCB {xc_Brelease .mesa B1}; MouseZoomBrelease %W }
+    bind .mesa <B2-ButtonRelease> { bindCB {xc_Brelease .mesa B2}; ResetCursor; }
     bind .mesa <Button-3>         { popupMenu %W %X %Y }
     bind .mesa <Shift-B1-Motion>         { MouseZoom %W %X %Y }
     bind .mesa <Shift-B1-ButtonRelease>  { MouseZoomBrelease %W }
@@ -150,7 +150,8 @@ proc ViewMol {top {file {}} } {
 
     set rs [RadioButCmd $f31 "Lighting:" light Lighting top left 1 1 5 "On" "Off"]
     foreach r [lrange $rs 1 end] {
-    	$r config -indicatoron 0 -font $xcFonts(small)
+    	#$r config -indicatoron 0 -font $xcFonts(small)
+	$r config -indicatoron 0
 	pack configure $r -padx 1 -pady 3 -ipadx 5 -ipady 1 -fill x -expand 1
     }
 
@@ -227,7 +228,7 @@ proc ViewMol {top {file {}} } {
 		       -variable style3D(stereo) -indicatoron 0 \
 		       -selectcolor \#4444ff -anchor center \
 		       -command [list Style3D draw stereo]] 
-  
+    
     set separator_1 [frame $modl.s1 -width 2 -relief raised -bd 1]
     set separator_2 [frame $modl.s2 -width 2 -relief raised -bd 1]
     set separator_3 [frame $modl.s3 -width 2 -relief raised -bd 1]
@@ -250,17 +251,24 @@ proc ViewMol {top {file {}} } {
 		      -selectcolor \#4444ff -anchor center \
 		      -command [list CellMode 1]]
 
-
+    # reload button
+    set separator_4 [frame $modl.s4 -width 2 -relief raised -bd 1]
+    set b_reload [button $modl.reload -text "Reload" -command reloadCmd]
+    
     set b_pack_option {-side left -fill y -padx 0 -pady 0 -ipadx 0 -ipady 0}
-    set s_pack_option {-side left -fill y -padx 3 -pady 0 -ipadx 0 -ipady 0}
+    set s_pack_option {-side left -fill y -padx 2 -pady 0 -ipadx 0 -ipady 0}
 	    
     eval pack $separator_1 $s_pack_option
     eval pack $rep_unit $rep_asym $b_pack_option
     eval pack $separator_2 $s_pack_option
-    eval pack $r_solid $r_wire $r_anaglyph $r_stereo $b_pack_option 
+    eval pack $r_solid $r_wire $r_anaglyph $b_pack_option ; #$r_stereo 
     eval pack $separator_3 $s_pack_option
     eval pack $r_smooth $r_flat $b_pack_option
-
+    
+    eval pack $separator_4 $s_pack_option
+    eval pack $b_reload $b_pack_option -pady 2
+    reloadButton $b_reload
+    
     global xcFonts
     foreach {wid text} {
 	solid    "solid molecular draw-style"
@@ -271,14 +279,17 @@ proc ViewMol {top {file {}} } {
 	flat     "flat molecular shading"
 	unit     "nicely-cut unit cell"
 	asym     "translational asymmetric unit"
+	xsf2     "update XSF2 structure"
     } {
-	set path $modl.$wid		
-	DynamicHelp::register $path balloon $text
+	set path $modl.$wid
+	if { [winfo exists $path] } {
+	    DynamicHelp::register $path balloon $text
+	}
     }
 
     pack $meaF -side left -fill y
     pack $modl -ipadx 5 -expand 1 -fill both -side left
-    pack $atmi $flbd $flba $flbdi -side left -padx 0 -expand 1 -fill y
+    pack $atmi $flbd $flba $flbdi -side left -padx 0 -ipadx 0 -expand 1 -fill y
 
     #pack $atmi $flbd $flba $flbdi \
     #	    $styl $sty $shdl $shd -side left -padx 0 
@@ -301,7 +312,7 @@ proc ViewMol {top {file {}} } {
 
     if { $file != {} } {
 	# open file and display it !!!
-	OpenStruct .mesa $file
+	OpenXSFStruct .mesa $file
     }
 
     # disable all neccessary widgets
@@ -310,10 +321,7 @@ proc ViewMol {top {file {}} } {
     #
     # delete WELCOME window
     #
-    if {[winfo exists .title]} { 
-	#after 500
-	destroy .title 
-    }
+    destroyWelcome
 
     # load the attributes from the definition file ...
     defLoadAttributes
@@ -469,30 +477,39 @@ proc PlaceGlobWin {type w h} {
 	if { ( $tcl_platform(platform) eq "windows" ) || ($tcl_platform(os) eq "Darwin" ) } {
             set stereo false
         }
+        global toglOpt
+        # N.B. -stereo is set to none at the moment        
 	set mesaWid [togl .mesa \
 			 -width          400 \
 			 -height         400 \
 			 -ident          .mesa \
-			 -rgba           true  \
-			 -redsize        1     \
-			 -greensize      1     \
-			 -bluesize       1     \
-			 -double         true  \
-			 -depth          true  \
-			 -depthsize      1     \
-			 -accum          true  \
-			 -accumredsize   1     \
-			 -accumgreensize 1     \
-			 -accumbluesize  1     \
-			 -accumalphasize 1     \
-			 -alpha          false \
-			 -alphasize      1     \
-			 -stencil        false \
-			 -stencilsize    1     \
-			 -auxbuffers     0     \
-			 -overlay        false \
-			 -stereo         $stereo \
-			 -time           100   ]
+			 -rgba           $toglOpt(rgba)          \
+			 -redsize        $toglOpt(redsize)       \
+			 -greensize      $toglOpt(greensize)     \
+			 -bluesize       $toglOpt(bluesize)      \
+			 -double         $toglOpt(double)        \
+			 -depth          $toglOpt(depth)         \
+			 -depthsize      $toglOpt(depthsize)     \
+			 -accum          $toglOpt(accum)         \
+			 -accumredsize   $toglOpt(accumredsize)  \
+			 -accumgreensize $toglOpt(accumgreensize) \
+			 -accumbluesize  $toglOpt(accumbluesize)  \
+			 -accumalphasize $toglOpt(accumalphasize) \
+			 -alpha          $toglOpt(alpha)         \
+			 -alphasize      $toglOpt(alphasize)     \
+			 -stencil        $toglOpt(stencil)       \
+			 -stencilsize    $toglOpt(stencilsize)   \
+			 -auxbuffers     $toglOpt(auxbuffers)    \
+			 -overlay        $toglOpt(overlay)       \
+			 -stereo         $toglOpt(stereo)        \
+			 -time           $toglOpt(time)          \
+                         -create  togl_create \
+                         -display togl_display \
+                         -reshape togl_reshape \
+                         -destroy togl_destroy \
+                         -timer   togl_timer ]
+
+        puts stderr "Viewer: mesaWid = $mesaWid"
 	
 	set conWid   [frame .ctrl  -relief flat   -bd 0 -class Viewer]
 	set meaWid   [frame .mea   -relief flat   -bd 0 -class Viewer]
@@ -522,14 +539,14 @@ proc PlaceGlobWin {type w h} {
 	    
 	    #set stereo [xc_stereo]	
 	    set stereo [lindex [.mesa configure -stereo] end]
-	    if { $stereo } {
+	    if { $stereo != "none" } {
 		#puts stderr "\n*** the hardware supports the stereo ***\n"
 		set stereo_visual true
 	    } else {
 		#puts stderr "\n*** the hardware does not support the stereo ***\n"
 		set stereo_visual false
 	    }
-	}    	    
+	}
     } elseif { $type == "fullscreen-off" } {
 	place .menu -x $menuX -y $menuY \
 		-width $menuW -height $menuH -anchor nw
@@ -672,7 +689,6 @@ proc ViewMolFrame1 {f} {
 	set viewer(bind,script,$name) $script
     }
 
-
     ######################
     # SCALE for translationStep
     set f3 [frame $f.3 -bd 2 -relief groove]
@@ -685,7 +701,8 @@ proc ViewMolFrame1 {f} {
     set trlab   [label $f3.lab -text "Translation\nStep:" -justify right]
     set trentry [entry $f3.entry -relief sunken \
 		     -textvariable translationStep \
-		     -width [expr round(5 * $fac2)]]
+		     -width [expr round(5 * $fac2)] \
+                     -validate key -validatecommand {doubleOnly %P}]
     pack $sc -side bottom
     pack $trlab $trentry -side left -expand 1 -padx 0 -pady 0
     pack $zoom1 $zoom2 -side left -expand 1 
@@ -779,8 +796,9 @@ proc ViewMolFrame2 {f} {
 	    -width [expr round(10 * $fac2)]]
     set rotlab [label $f4.lab -text "Rotation\nStep:" -justify right]
     set rotentry [entry $f4.entry -relief sunken \
-	    -textvariable rotstep \
-	    -width [expr round(5 * $fac2)]]
+                      -textvariable rotstep \
+                      -width [expr round(5 * $fac2)] \
+                      -validate key -validatecommand {doubleOnly %P}]
     pack $sc -side bottom 
     pack $rotlab $rotentry -side left -expand 1 -padx 0 -pady 0
     pack $f1 $f2 $f3 -side top -fill x -expand 1 -pady 1
@@ -790,12 +808,12 @@ proc ViewMolFrame2 {f} {
     set f5 [frame $f.5 -bd 0 -relief flat]
     set b  [expr round(26 * $fac2)]
     foreach {row col bt im com text} [list \
-	    0 0 $f5.xy rotXY {.mesa xc_rotate xy 0.0} "orient to XY plane" \
-	    0 1 $f5.yz rotYZ {.mesa xc_rotate yz 0.0} "orient to YZ plane" \
-	    0 2 $f5.xz rotXZ {.mesa xc_rotate xz 0.0} "orient to XZ plane" \
-	    1 0 $f5.ac rotAC {.mesa xc_rotate ac 0.0} "orient to AC plane" \
-	    1 1 $f5.ab rotAB {.mesa xc_rotate ab 0.0} "orient to AB plane" \
-	    1 2 $f5.bc rotBC {.mesa xc_rotate bc 0.0} "orient to BC plane" ] {
+	    0 0 $f5.xy rotXY {xc_rotate .mesa xy 0.0} "orient to XY plane" \
+	    0 1 $f5.yz rotYZ {xc_rotate .mesa yz 0.0} "orient to YZ plane" \
+	    0 2 $f5.xz rotXZ {xc_rotate .mesa xz 0.0} "orient to XZ plane" \
+	    1 0 $f5.ac rotAC {xc_rotate .mesa ac 0.0} "orient to AC plane" \
+	    1 1 $f5.ab rotAB {xc_rotate .mesa ab 0.0} "orient to AB plane" \
+	    1 2 $f5.bc rotBC {xc_rotate .mesa bc 0.0} "orient to BC plane" ] {
 	button $bt -image $im -command $com -width $b -height $b -anchor center
 	grid $bt -row $row -column $col -padx 1 -pady 1
 	DynamicHelp::register $bt balloon $text
@@ -815,7 +833,8 @@ proc ViewMolFrame2 {f} {
 			     "Discrete" "Click-and-hold" "Click-and-click"]
     set viewer(rot_zoom_button_mode_rbs) [lrange $rot_zoom_mode_w 1 end]
     foreach r $viewer(rot_zoom_button_mode_rbs) {
-    	$r config -indicatoron 0 -font $xcFonts(small)
+	$r config -indicatoron 0
+    	#$r config -indicatoron 0 -font $xcFonts(small)
     	pack configure $r -padx 1 -pady 1 -ipadx 5 -ipady 1 -fill x -expand 1
     }
     Viewer:rotZoomButtonMode
@@ -836,7 +855,7 @@ proc Rotate {b dir} {
 	set B1down 1
 	
 	while { $B1down } {
-	    .mesa xc_rotate $dir $rotstep
+	    xc_rotate .mesa $dir $rotstep
 	    update 	
 	}        
 
@@ -844,7 +863,7 @@ proc Rotate {b dir} {
 	return -code break
 
     } elseif { $viewer(rot_zoom_button_mode) == "Discrete" } {
-	.mesa xc_rotate $dir $rotstep
+	xc_rotate .mesa $dir $rotstep
 	update 
 
     } elseif { $viewer(rot_zoom_button_mode) == "Click-and-click" } {
@@ -856,7 +875,7 @@ proc Rotate {b dir} {
 	    
 	    set B1down 1	    
 	    while { $B1down } {
-		.mesa xc_rotate $dir $rotstep
+		xc_rotate .mesa $dir $rotstep
 		update 	
 	    }        
 
@@ -883,7 +902,7 @@ proc Transl {b dir} {
 	set B1down 1
 	
 	while { $B1down } {
-	    .mesa xc_translate $dir $translationStep
+	    xc_translate .mesa $dir $translationStep
 	    update 	
 	}
 
@@ -891,7 +910,7 @@ proc Transl {b dir} {
 	return -code break
 
     } elseif { $viewer(rot_zoom_button_mode) == "Discrete" } {
-	.mesa xc_translate $dir $translationStep
+	xc_translate .mesa $dir $translationStep
 	update
 
     } elseif { $viewer(rot_zoom_button_mode) == "Click-and-click" } {
@@ -903,7 +922,7 @@ proc Transl {b dir} {
 	    
 	    set B1down 1	    
 	    while { $B1down } {
-		.mesa xc_translate $dir $translationStep
+		xc_translate .mesa $dir $translationStep
 		update 	
 	    }        
 	    
@@ -943,7 +962,7 @@ proc MouseZoom {W x y} {
     global mouseZoom
 
     # register Shift-B1-Motion event
-    $W xc_ShiftB1motion
+    xc_ShiftB1motion $W 
 
     if { ! [info exists mouseZoom($W,oldX)] } {
 	set mouseZoom($W,oldX) $x
@@ -958,7 +977,7 @@ proc MouseZoom {W x y} {
     set fy   [expr {double($mouseZoom($W,oldY) - $y)/double($h/2.0)}]    
     set sign [expr { $fy > 0 ? "+" : "-"}]
 
-    $W cry_toglzoom $fy
+    cry_toglzoom $W $fy
 
     set mouseZoom($W,oldX) $x
     set mouseZoom($W,oldY) $y
@@ -966,7 +985,7 @@ proc MouseZoom {W x y} {
 proc MouseZoomBrelease {W} {
     global mouseZoom
     # unregister Shift-B1-Motion event
-    $W xc_Brelease Shift-B1
+    xc_Brelease $W Shift-B1
 
     if { [info exists mouseZoom($W,oldX)] } { unset mouseZoom($W,oldX) }
     if { [info exists mouseZoom($W,oldY)] } { unset mouseZoom($W,oldY) }
@@ -976,7 +995,7 @@ proc MouseZoomBrelease {W} {
 proc MouseWheelZoom {W dir} {
 
     set fy 0.075
-    $W cry_toglzoom ${dir}${fy}
+    cry_toglzoom $W ${dir}${fy}
 }
 
 
@@ -1077,9 +1096,10 @@ proc maximizeDisplay {{action on}} {
 	    place configure .mesa -x 0 -y 0 -width $w -height $h -anchor nw
 	    
 	    set maximizeDisplay(.mesa_bind_script) [bind .mesa <Button-3>]
+            
 	    bind .mesa <Button-3> { maximizeDisplay:popupMenu %W %X %Y }
 	    bind .mesa <Double-Button-1> { 
-		bindCB {.mesa xc_Brelease B1}
+		bindCB {xc_Brelease .mesa B1}
 		maximizeDisplay off 
 	    }
 	    bind . <Control-l> { maximizeDisplay off }
@@ -1100,9 +1120,9 @@ proc maximizeDisplay {{action on}} {
 
 	    PlaceGlobWin fullscreen-off [winfo width .] [winfo height .]
 
-	    bind .mesa <Button-3> { bindCB $maximizeDisplay(.mesa_bind_script) }
+	    bind .mesa <Button-3> "bindCB [list $maximizeDisplay(.mesa_bind_script)]"
 	    bind .mesa <Double-Button-1> { 
-		bindCB {.mesa xc_Brelease B1}
+		bindCB {xc_Brelease .mesa B1}
 		maximizeDisplay on 
 	    }
 	    bind . <Configure> {ResizeGlobWin}
@@ -1212,3 +1232,11 @@ proc Viewer:rotZoomButtonMode {{value {}}} {
 	}
     }
 }
+
+# used for entry validation; it does not allow empty string
+proc doubleOnly {str} {
+    if { $str == {} } {
+        return false
+    }
+    return [string is double $str]
+}
