@@ -145,7 +145,7 @@ proc SelPlane {t} {
     set grab 0
     if { [grab current] == "$t" } {
 	set grab 1
-	grab release $t
+	catch { grab release $t }
     }
     puts stdout "GRAB IS> [grab status $t]"
     PreSel .sel_plane .mesa "Select a Plane" \
@@ -156,7 +156,10 @@ proc SelPlane {t} {
     set K [lindex $SelPlane(plane) 1]
     set L [lindex $SelPlane(plane) 2]
     puts stdout "HKL> $H $K $L"
-    if { $grab } { grab $t }
+
+    if { $grab } { 
+	catch { grab $t }
+    }
 }    
 
 
@@ -256,7 +259,6 @@ proc CutCluster {} {
 proc SelClusCoor {w} {
     global done
 
-    #grab release $w
     if { [winfo exists .how2sel] } { return }
     set t [xcToplevel .how2sel "Choose" "Choose" . 581 74]
     set l1 [label $t.l1 -text "How to select centre of cluster:"]
@@ -269,9 +271,8 @@ proc SelClusCoor {w} {
 	    -expand 1 -fill x    
 
     tkwait visibility $t
-    #grab $t
+
     tkwait variable done
-    #grab $w
 }
 
 
@@ -393,8 +394,8 @@ proc NeighAnal {var} {
 	return
     } elseif { $var == "Yes" } {
 	set cutCL(NNA) 1
-	#grab release .cutclus	
-	if [winfo exists .neigh] { return }
+
+	if { [winfo exists .neigh] }  { return }
 	set top [toplevel .neigh]
 	xcPlace . .neigh 720 200
 	wm title $top "Radius of Sphere"
@@ -418,13 +419,12 @@ proc NeighAnal {var} {
 	pack $ok $can -side left -padx 5 -pady 5 -ipadx 3 -ipady 3 -expand 1
 	
 	tkwait visibility $top
-	grab $top
+	catch { grab $top }
     
 	tkwait variable done
-	grab release $top
-	#grab .cutclus
+	catch { grab release $top }
+
 	destroy $top	
-	#grab .cutclus
     }
 }
 
@@ -456,7 +456,7 @@ proc CoorNum {var} {
 	set cutCL(NCN) 0
 	return
     } elseif { $var == "Yes" } {
-	#grab release .cutclus
+
 	if [winfo exists .coorn] { return }
 	set top [toplevel .coorn]
 	xcPlace . .coorn 720 250
@@ -482,7 +482,6 @@ proc CoorNum {var} {
 	pack $ok -side top -padx 5 -pady 5 -ipadx 3 -ipady 3 -expand 1
 	
 	tkwait visibility $top
-	#grab $top
     }
 }
 
@@ -505,7 +504,7 @@ proc GetCoorNum {} {
     toplevel .getcoorn
     wm title .getcoorn "Custom Coordination Numbers"
     xcPlace . .getcoorn 580 190
-    grab .getcoorn
+    catch { grab .getcoorn }
     
     # bottom frame where OK button will be
     set fb [frame .getcoorn.fb]
@@ -569,7 +568,7 @@ proc GetCoorNum {} {
     
     tkwait variable done
 
-    grab release .getcoorn
+    catch { grab release .getcoorn }
     destroy .getcoorn
 }
 
