@@ -413,91 +413,98 @@ proc GetFontAtribute {font window arg} {
 }
 
 
-#
-# xcTkFontName2XLFD --
-#
-# Tries to map TkFontName to XLFD X11 font name, if it does not
-# succeed, then returns an empty string.
-#
-
-proc xcTkFontName2XLFD {font} {
-    global tcl_platform
-
-    if { $tcl_platform(platform) == "windows" } {
-    	set fontAttr [font actual $font]
-    	set font     [font create]
-    	eval {font configure $font} $fontAttr
-    	return $font
-    }
-
-    # *** below is for X11 only::
-
-    # --------------------------------------------------
-    # construct the font in the following form:
-    # --------------------------------------------------
-    # -foundry-family-weight-slant-setwidth-addstyle-pixel-point-resx-resy-spacing-width-charset-encoding    
-    # ------------------------------------------------------------------------
-
-    # --------------------------------------------------
-    # Tk allowed fields
-    # --------------------------------------------------
-    #          -family name
-    #          -size size
-    #          -weight weight
-    #          -slant slant
-    #          -underline boolean
-    #          -overstrike boolean
-
-    foreach opt {family size weight slant} {
-	upvar 1 $opt var
-	set var  [font actual $font -$opt]
-	set $opt $var
-	
-	# weight: 
-	#         normal = normal | regular | medium | book | light
-	#         bold   = bold | extrabold | demi | demibold
-	#
-	# slant: 
-	#         italic = i | o
-	
-	if { $opt == "weight" } {
-	    if { $var == "normal" } {
-		set weightList { medium normal regular book light }
-	    } else {
-		set weightList { bold extrabold demi demibold }
-	    }
-	}
-	if { $opt == "slant" } {
-	    if { $var == "italic" } {
-		set slantList { i o }
-	    } else {
-		set slantList { r }
-	    }
-	}
-    }     
-
-    # a hack for Mac OS X, which doesn't like negative sizes
-
-    global tcl_plaform
-    if { $tcl_platform(os) == "Darwin" } {
-	if { [string is integer $size] && $size < 0 } {
-	    set size [expr $size * (-1)]
-	}
-    }
-
-    foreach weight $weightList {
-	foreach slant $slantList {
-	    # example::   "-*-bookman-*      -*     -*-*-64   -*-*-*-*-*-*-*"
-	    set XLFD_name "-*-$family-$weight-$slant-*-*-$size-*-*-*-*-*-*-*"
-	    if { [.mesa xc_queryfont $XLFD_name] > 0 } {
-		return $XLFD_name
-	    }
-	}
-    }
-
-    # couldn't map tk-font-name --> XLFD name, return an empty string
-    return ""
-}
+# #
+# # xcTkFontName2XLFD --
+# #
+# # Tries to map TkFontName to XLFD X11 font name, if it does not
+# # succeed, then returns an empty string.
+# #
+# 
+# proc xcTkFontName2XLFD {font} {
+#     global tcl_platform
+# 
+#     if { $tcl_platform(platform) == "windows" } {
+#     	set fontAttr [font actual $font]
+#     	set font     [font create]
+#     	eval {font configure $font} $fontAttr
+#     	return $font
+#     }
+# 
+#     #puts stderr "*** xcTkFontName2XLFD : font = $font"
+#     #puts stderr "*** xcTkFontName2XLFD : font actual font = [font actual $font]"
+#     
+#     # *** below is for X11 only::
+# 
+#     # --------------------------------------------------
+#     # construct the font in the following form:
+#     # --------------------------------------------------
+#     # -foundry-family-weight-slant-setwidth-addstyle-pixel-point-resx-resy-spacing-width-charset-encoding    
+#     # ------------------------------------------------------------------------
+# 
+#     # --------------------------------------------------
+#     # Tk allowed fields
+#     # --------------------------------------------------
+#     #          -family name
+#     #          -size size
+#     #          -weight weight
+#     #          -slant slant
+#     #          -underline boolean
+#     #          -overstrike boolean
+# 
+#     foreach opt {family size weight slant} {
+# 	upvar 1 $opt var
+# 	set var  [font actual $font -$opt]
+# 	set $opt $var
+# 	
+# 	# weight: 
+# 	#         normal = normal | regular | medium | book | light
+# 	#         bold   = bold | extrabold | demi | demibold
+# 	#
+# 	# slant: 
+# 	#         italic = i | o
+# 	
+# 	# if { $opt == "weight" } {
+# 	#     if { $var == "normal" } {
+# 	# 	set weightList { medium normal regular book light }
+# 	#     } else {
+# 	# 	set weightList { bold extrabold demi demibold }
+# 	#     }
+# 	# }
+# 	# if { $opt == "slant" } {
+# 	#     if { $var == "italic" } {
+# 	# 	set slantList { i o }
+# 	#     } else {
+# 	# 	set slantList { r }
+# 	#     }
+# 	# }
+#     }     
+#     set XLFD_name "-*-$family-$weight-$slant-*-*-$size-*-*-*-*-*-*-*"
+#     #puts stderr "*** xcTkFontName2XLFD : XLFD_name = $XLFD_name"
+#     
+#     return $XLFD_name
+# 
+#     # a hack for Mac OS X, which doesn't like negative sizes
+#     
+#     #global tcl_plaform
+#     #if { $tcl_platform(os) == "Darwin" } {
+#     #    if { [string is integer $size] && $size < 0 } {
+#     #        set size [expr $size * (-1)]
+#     #    }
+#     #}
+#     #
+#     #foreach weight $weightList {
+#     #    foreach slant $slantList {
+#     #        # example::   "-*-bookman-*      -*     -*-*-64   -*-*-*-*-*-*-*"
+#     #        set XLFD_name "-*-$family-$weight-$slant-*-*-$size-*-*-*-*-*-*-*"
+#     #        if { [xc_queryfont .mesa $XLFD_name] > 0 } {
+#     #    	return $XLFD_name
+#     #        }
+#     #    }
+#     #}
+# 
+#     # couldn't map tk-font-name --> XLFD name, return tk-font-name
+#     #return $font
+# }
 
 
 
@@ -578,10 +585,21 @@ proc winGeom { w } {
 
 ##############################################################################
 # this proc read dimension & group (family) number out of GENGEOM file
+proc GetDimGroupXSF {dim group xsfFile} {
+    upvar $dim   dm
+    upvar $group gr
+    set fileID [open $xsfFile r]
+    GetDimGroup dm gr $fileID
+    close $fileID
+}
 proc GetDimGroup {dim group fileID} {
     upvar $dim   dm
     upvar $group gr
 
+    # <t.k.>: Thu Jul 13 15:13:57 CEST 2017
+    set dm 0
+    set gr 1
+    # </t.k.>
     set n 0
     set output [split [read $fileID] \n]
     foreach line $output {
@@ -693,14 +711,7 @@ proc GetWidgetConfig {widget_com option} {
 ##############################################################################
 # return the filehead out of filename (file.poss --> file)
 proc FileHead file {
-    set filehead [split $file .]
-    set nfield   [llength $filehead]
-    set last     [expr $nfield - 2]
-    if { $last < 0 } { set last 0 }	
-    set filehead [lrange $filehead 0 $last]
-    regsub -all { } $filehead \. filehead
-
-    return $filehead
+    return [file rootname $file]
 }
 
 
@@ -921,6 +932,7 @@ proc xcOnPower {a n} {
 proc SetWatchCursor {} {
     global xcCursor
     foreach t [winfo children .] {
+	catch { puts stderr "SetWatchCursor: $t" }
 	if {"[info commands $t]" != {} } {
 	    $t config -cursor $xcCursor(watch)
 	}
@@ -1027,15 +1039,7 @@ proc capitalize word {
 # return the filehead (filename without extension)
 #
 proc filehead {filename} {
-
-    set filehead [split $filename .]
-    set nfield   [llength $filehead]
-    if { $nfield > 1 } {
-	set filehead [lrange $filehead 0 [expr $nfield - 2]] 
-    }
-    regsub -all { } $filehead \. filehead
-
-    return $filehead
+    return [file rootname $filename]
 }
 
 
@@ -1067,19 +1071,23 @@ proc ReadFile {filename {arg {}}} {
 
 proc GetAbsoluteFileName file {
     global system
+
+    # try this:
+    return [file normalize [file join $system(PWD) $file]]
+    
     # if filename starts with / or ~ the absolute file name is assumed,
     # otherwise absolute filename should be: $system(PWD)/$file
 
-    if { $file == "." } {
-	set file $system(PWD)
-    }
-    set file [string trimright $file /]
-    set c0 [string index $file 0]
-    if { $c0 == "/" || $c0 == "~" } {
-	return $file
-    } else {
-	return [file join $system(PWD) $file]
-    }
+    #if { $file == "." } {
+    #    set file $system(PWD)
+    #}
+    #set file [string trimright $file /]
+    #set c0 [string index $file 0]
+    #if { $c0 == "/" || $c0 == "~" } {
+    #    return $file
+    #} else {
+    #    return [file normalize [file join $system(PWD) $file]]
+    #}
 }
 
 #-----------------------------------------
@@ -1194,25 +1202,29 @@ proc gunzipFile {file} {
     ####################
 
     set name [file tail $file]
-    cd $system(SCRDIR)
+    
+    if { [file extension $name] == ".gz" } {
+        
+        set here [pwd]
+        cd $system(SCRDIR)
 
-    if { [string match *.gz $name] } {
-	# maybe file is already locate in $system(SCRDIR)
-	
+	# maybe file is already located in $system(SCRDIR); if not copy it there
 	if { [file dirname $file] != $system(SCRDIR) && $file != $name } {
 	    file copy -force $file $name
 	}
 
-	catch {exec -- gzip -d $name}
-	set gunzipName [string trimright $name .gz]
+	catch {exec -- gzip -df $name}
+	set gunzipName [file rootname $name]
 	if { ![file exists $gunzipName] } {
 	    tk_dialog [WidgetName] "ERROR" \
 		"ERROR: error when gunzip-ing file $file" warning 0 OK
 	    uplevel 1 { return }
 	}
 	set gunzipName $system(SCRDIR)/$gunzipName
-    }
 
+        cd $here
+    }
+    
     return $gunzipName
 }
 
@@ -1227,6 +1239,7 @@ proc destroyWelcome {} {
 
 proc ErrorDialogInfo {text {errMsg {}}} {
     destroyWelcome
+    #error $text
     set id [tk_dialog [WidgetName] ERROR "ERROR: $text." error 0 OK ErrorInfo]
     if { $id == 1 } {
 	tkwait window [xcDisplayVarText $errMsg "Error Info"]
@@ -1260,12 +1273,17 @@ proc xcCatchExecRedirectStdErr {args} {
 proc xcCatchExecReturn {args} {
     destroyWelcome
     xcDebug -stderr "Executing: $args"
+
+    SetWatchCursor
     if { [catch {eval exec $args} errMsg] } {
 	ErrorDialogInfo "while executing\nexec $args" $errMsg
+        ResetCursor
 	uplevel 1 {
 	    return 1
 	}
     }
+    ResetCursor
+
     return 0
 }
 
@@ -1284,10 +1302,7 @@ proc xcCatchExecReturnRedirectStdErr {args} {
 }
 
 proc ErrorDialog {text {errMsg {}}} {
-    if { [winfo exists .title] } {
-	# destroy WELCOME window
-	destroy .title
-    }
+    destroyWelcome
     set text "ERROR: $text."
     if { $errMsg != "" } {
 	append text "\n\nError Mesage:\n$errMsg"
@@ -1336,7 +1351,9 @@ proc xcCatchEval {cmd {errorMsg {}}} {
     if { [catch {eval $cmd} _errorMsg] } {
 	if { $errorMsg == "" } {
 	    set errorMsg $_errorMsg
-	}
+	} else {
+            append errorMsg "\n$_errorMsg"
+        }
 	ErrorDialog "An ERROR occured while executing:\n$cmd\n\nERROR MESSAGE: $errorMsg"
     }
 }
@@ -1592,7 +1609,7 @@ proc fileCopy {src dst} {
     
     if { [info exists file] } {
 	global system
-	return [file copy -force $system(PWD)/$file $dst]
+	return [file copy -force [file join $system(PWD) $file] $dst]
     } else {
 	return [file copy -force $src $dst]
     }
@@ -1673,7 +1690,7 @@ proc getAllDescendantWid_ {wlist} {
 }
 
 
-# set a variable only if it does not exists
+# set a variable only if it does not exist
 proc ifset {varName value} {
     upvar 1 $varName var
 
