@@ -32,7 +32,7 @@ proc Bz_MakeToplevel {{what {}}} {
     load_kLabels
     set Bz(lattice_type) [igroup2BravaisLattice $periodic(igroup)]
     #xcDebug -stderr "tk: LATTICE-TYPE: $Bz(lattice_type)"
-    kLabels_Note
+    #kLabels_Note
     #---
 
     set Bz(what)   $what
@@ -150,6 +150,13 @@ proc Bz_RenderBZ {type} {
 	    {-width 15c -height 15c -bg "#ffffff"}]
     pack $can -side top -fill both -expand 1 -in $fl.df
 
+    # clear previous k-point coordinates
+    
+    if { [info exists  Bz($can,coor1)] } {
+        array unset Bz $can,coor*
+    }
+    
+
     ### some buttons for rotations
     set f [frame $can.f]
     $can create window 1 1 \
@@ -158,7 +165,7 @@ proc Bz_RenderBZ {type} {
 
     set text "Primitive Brillouin Zone"
     if { $type == "conv" } {
-	set text "Conventional Brillouin Zone"
+	set text "Conventional Brillouin Zone (use only for curiosity)"
     }
     $can create text 7.5c 0.2c \
 	    -text $text \
@@ -355,7 +362,7 @@ proc Bz_RenderBZ {type} {
     set Bz(text2) "label"
     set ce2 [entry $cf1.e2 -textvariable Bz(text2) \
 	    -bg $bg \
-	    -width 4 \
+	    -width 7 \
 	    -relief sunken -bd 1 \
 	    -font $Bz(efont)]
     pack $cf1 -side top -padx 2
@@ -392,7 +399,7 @@ proc Bz_RenderBZ {type} {
 		-state disabled]
 	set Bz($can,coor_entry$i) $ce1 
 	set ce2 [entry $cf.e2 -textvariable Bz($can,label$i) \
-		-width 4 \
+		-width 7 \
 		-relief sunken -bd 1 \
 		-font $Bz(efont) \
 		-state normal]
@@ -503,6 +510,7 @@ proc Bz_ButtonPressed {can x y} {
 		     #
 		     # assigning the coordinate of selected k-point
 		     #
+                     set Bz($can,coor$Bz($can,nselected)) ""
     		     foreach item [lrange $list 1 end] {
     			 append Bz($can,coor$Bz($can,nselected)) \
 				 [format {% 1.5f} $item]
