@@ -62,7 +62,7 @@ proc check_package_crystal {} {
 	}
 
 	#
-	# CRYSTAL-95/98/03/06/09/14
+	# CRYSTAL-95/98/03/06/09/14/...
 	#
 	set crystal_module $system(c95_integrals)
 	set input "test\nMOLECULE\n1\n1\n1 0.0 0.0 0.0\nSTOP\nEND"
@@ -73,7 +73,7 @@ proc check_package_crystal {} {
 	set OK 1
 	if { ! [file exists $system(c95_integrals)] } {
 	    set OK 0
-	    ErrorDialog "File \"$crystal_module\" does not exists";
+	    ErrorDialog "File \"$crystal_module\" does not exist";
 	}
 	if { $OK && ! [file executable $system(c95_integrals)] } {
 	    set OK 0
@@ -87,7 +87,7 @@ proc check_package_crystal {} {
 	    
 	    if { $_status } {
 		ErrorDialog \
-		    "Couldn't run CRYSTAL package.\n\nError Message: $_errMsg"
+		    "Couldn't run CRYSTAL package.\n\nPlease check its definition in ~/.xcrysden/custom-definition file.\n\nError Message: $_errMsg"
 		set system(c95_version) none
 	    }
 	    
@@ -116,11 +116,20 @@ proc check_package_crystal {} {
 			    set system(c95_version) "14"
 			    break
 			}
-		    }		    
+			"*    CRYSTAL17    *" {
+                            puts stderr "Package CRYSTAL: version-17 found"
+                            puts stderr "        (BEWARE: adopting version-14 instead,"
+                            puts stderr "                 support for version-17 may not be fully functional)"
+			    set system(c95_version) "14"
+			    break
+			}
+		    }	    
 		}
 	    }
 	    if { ! [info exists system(c95_version)] } {
-		set system(c95_version) "unknown -- version not recognized"
+		puts stderr "Package CRYSTAL: unsupported version"
+		puts stderr "                 adopting a crystal version 14 (BEWARE: this may not work properly)"
+		set system(c95_version) "14"
 	    }
 
 	    puts stderr "Package CRYSTAL: $system(c95_integrals) (version: $system(c95_version))"
