@@ -1162,7 +1162,7 @@ proc SetBarAtrib {gID j i} {
 
     set t [xcToplevel [WidgetName] "Set Bar #$i Attributes" "Set Bar" \
 	    .graph$gID 100 100 1]
-    grab $t
+    catch { grab $t }
 
     set bar_atrib_color($gID,apply_to_all) 0
     set ckb [checkbutton $t.cb \
