@@ -13,7 +13,7 @@
 #############################################################################
 
 proc Lighting {var} {
-    global dispmode xcFonts xcMisc
+    global dispmode xcFonts xcMisc light
     # var -- can be On ro Off
     #        On  - 3D displayModes
     #        Off - 2D displaymodes
@@ -21,6 +21,10 @@ proc Lighting {var} {
 	set dispmode(mode3D_ModeFrame) {}
     }
 
+    if { $var == "Off" || $var == "On" } {
+        set light $var     
+    }   
+
     if { $var == "Off" } {
 	# if 3D widgets exists delete them
 	if {[winfo exists .ctrl.c.f.fr3.canv.mode3D]} { 
@@ -130,8 +134,9 @@ proc Lighting {var} {
     } else {
 	puts stderr "invalid value \"$var\" submitted to proc DispMode, must be one of On, Off"
 	flush stderr
+        return
     }
-    
+
     # add the additional created widgets to the control-toolbar scrolling
     scrollControlToolboxCmd .ctrl.c
     return
