@@ -24,7 +24,7 @@ proc FS_GoFermi {{spin {}}} {
 	incr fs(counter) 
     }
 
-    set fs($spin,togl_w) [expr int(650 * $xcMisc(resolution_ratio1))]
+    set fs($spin,togl_w) [expr int(750 * $xcMisc(resolution_ratio1))]
     set fs($spin,togl_h) $fs($spin,togl_w) 
 
     xcDebug -debug "FS_GoFermi> xcMisc(resolution_ratio1) = $xcMisc(resolution_ratio1)"
@@ -48,10 +48,13 @@ proc FS_GoFermi {{spin {}}} {
     set exit_viewer_win $t
     bind $t <Destroy> "exit_viewer $t"
 
+    if { ! [info exists xcMisc(titlefile)] } {
+        set xcMisc(titlefile) $fs(titlefile)
+    }
     if { $spin != {} } {
-	wm title $t "*** XCrySDen - Fermi Surface ($spin spin): $fs(titlefile)"
+	wm title $t "*** XCrySDen - Fermi Surface ($spin spin): [file tail $xcMisc(titlefile)]"
     } else {
-	wm title $t "*** XCrySDen - Fermi Surface: $fs(titlefile)"
+	wm title $t "*** XCrySDen - Fermi Surface: [file tail $xcMisc(titlefile)]"
     }
     wm iconname $t "Fermi Surface"    
     wm iconbitmap . @$system(BMPDIR)/xcrysden.xbm
@@ -98,43 +101,49 @@ proc FS_GoFermi {{spin {}}} {
 	    #
 	    # Togl
 	    #
-	    #-width  $fs($spin,togl_w) \
-		#	-height $fs($spin,togl_h) \
-		#
-
-	    set fs($spin,$i,togl) [togl $togl \
-		    -ident  $togl \
-		    -rgba           true  \
-		    -redsize        1     \
-		    -greensize      1     \
-		    -bluesize       1     \
-		    -double         true  \
-		    -depth          true  \
-		    -depthsize      1     \
-		    -accum          true  \
-		    -accumredsize   1     \
-		    -accumgreensize 1     \
-		    -accumbluesize  1     \
-		    -accumalphasize 1     \
-		    -alpha          false \
-		    -alphasize      1     \
-		    -stencil        false \
-		    -stencilsize    1     \
-		    -auxbuffers     0     \
-		    -overlay        false \
-		    -stereo         false \
-		    -time           100]
-
+            global toglOpt
+            
+	    set fs($spin,$i,togl) \
+                [togl $togl \
+                     -ident  $togl \
+                     -rgba           true  \
+                     -rgba           $toglOpt(rgba)          \
+                     -redsize        $toglOpt(redsize)       \
+                     -greensize      $toglOpt(greensize)     \
+                     -bluesize       $toglOpt(bluesize)      \
+                     -double         $toglOpt(double)        \
+                     -depth          $toglOpt(depth)         \
+                     -depthsize      $toglOpt(depthsize)     \
+                     -accum          $toglOpt(accum)         \
+                     -accumredsize   $toglOpt(accumredsize)  \
+                     -accumgreensize $toglOpt(accumgreensize) \
+                     -accumbluesize  $toglOpt(accumbluesize)  \
+                     -accumalphasize $toglOpt(accumalphasize) \
+                     -alpha          $toglOpt(alpha)         \
+                     -alphasize      $toglOpt(alphasize)     \
+                     -stencil        $toglOpt(stencil)       \
+                     -stencilsize    $toglOpt(stencilsize)   \
+                     -auxbuffers     $toglOpt(auxbuffers)    \
+                     -overlay        $toglOpt(overlay)       \
+                     -stereo         $toglOpt(stereo)        \
+                     -time           $toglOpt(time)          \
+                     -create    togl_create \
+                     -display   togl_display \
+                     -reshape   togl_reshape \
+                     -destroy   togl_destroy \
+                     -timer     togl_timer ]
+            
 	    pack $togl -fill both -expand 1
-
+            update
+            
 	    # take care of togl's background
 	    FS_UserBackground $togl
 	    
 	    #
-	    bind $fs($spin,$i,togl) <B1-Motion>        { %W xc_B1motion %x %y }
-	    bind $fs($spin,$i,togl) <B2-Motion>        { %W xc_B2motion %x %y }
-	    bind $fs($spin,$i,togl) <B1-ButtonRelease> { %W xc_Brelease B1; MouseZoomBrelease %W }
-	    bind $fs($spin,$i,togl) <B2-ButtonRelease> { %W xc_Brelease B2 }
+	    bind $fs($spin,$i,togl) <B1-Motion>        { xc_B1motion %W %x %y }
+	    bind $fs($spin,$i,togl) <B2-Motion>        { xc_B2motion %W %x %y }
+	    bind $fs($spin,$i,togl) <B1-ButtonRelease> { xc_Brelease %W B1; MouseZoomBrelease %W }
+	    bind $fs($spin,$i,togl) <B2-ButtonRelease> { xc_Brelease %W B2 }
 	    bind $fs($spin,$i,togl) <Button-3>         [list FS_PopupMenu %W %X %Y $i $spin]
 	    bind $fs($spin,$i,togl) <Shift-B1-Motion>         {  MouseZoom %W %X %Y }
 	    bind $fs($spin,$i,togl) <Shift-B1-ButtonRelease>  {  MouseZoomBrelease %W }
@@ -266,7 +275,8 @@ proc FS_GoFermi {{spin {}}} {
 	    
 	    set l5 [label $fff.l5 -text "Isolevel:"]
 	    set e  [entry $fff.e \
-		    -width 15 -textvariable fs($spin,$i,isolevel)]
+                        -width 15 -textvariable fs($spin,$i,isolevel) \
+                        -validate key -validatecommand {string is double %P}]
 	    pack $e $l5 -side right -padx 0m -pady 0m
 	    bind $e <Return> [list FS_Config $i $spin]	
 	}
@@ -1356,4 +1366,4 @@ proc FSbutton_SmallToolbox {button i spin} {
 	    FS_fsConfig $i $spin	    
 	}
     }
-}
\ No newline at end of file
+}
