@@ -442,7 +442,7 @@ proc IsoControl {} {
 	    isoControl unmapWin
 
     if {[winfo exists .iso] } { return }
-
+    
     #
     # initializations
     #
@@ -450,7 +450,8 @@ proc IsoControl {} {
     set isoControl(datagridDim) 3
 
     IsoControl_InitVar
-
+    reloadButtonDisable
+    
     set t [xcToplevel .iso "Isosurface/Property-plane Controls" "IsoControls" . -0 0 1]
     pack propagate .iso
 
@@ -524,7 +525,7 @@ proc IsoControl {} {
 
     ########################################
     # LEFT FRAME
-    if ![info exists isoControl(isosurf)] {
+    if { ![info exists isoControl(isosurf)] } {
 	set isoControl(isosurf) 1
     }
     set ckb [checkbutton $left.cb \
@@ -712,11 +713,11 @@ proc IsoControl {} {
     # REVERT FRONT&BACK SIDE    
     button $f5.b10 \
 	    -font $xcFonts(small) \
-	    -text "Revert (+) Sides" \
+	    -text "Revert (+) sides" \
 	    -command [list RevertIsoSides pos]    
     set isoControl(revert_button2) [button $f5.b10a \
 	    -font $xcFonts(small) \
-	    -text "Revert (-) Sides" \
+	    -text "Revert (-) sides" \
 	    -command [list RevertIsoSides neg]]
 
     # REVERT NORMALS
@@ -730,7 +731,7 @@ proc IsoControl {} {
 	    -command [list RevertIsoNormals neg]]
 
     set isoControl(smooth_button) [button $f5.b2a \
-	    -text "Surface Smoothing" \
+	    -text "Surface smoothing" \
 	    -font $xcFonts(small) \
 	    -command SurfaceSmoothing]
     $isoControl(smooth_button) config -state disabled
