@@ -496,13 +496,15 @@ proc set_origin {} {
 
     # from IFSO we must assign VAR:
     switch -exact -- $inp(IFSO) {
-	0 { set var "Origin derived from the symbol" }
-	1 { set var "Standard shift of origin" }
-	2 { set var "Non-standard shift of origin" }
+	0 { set var "Origin derived from the symbol (IFSO=0)" }
+	1 { set var "Standard shift of origin (IFSO=1)" }
+	2 { set var "Non-standard shift of origin (IFSO=2)" }
     }
 
-    RadioButtons .ifso.frame var top "Origin derived from the symbol" \
-	    "Standard shift of origin" "Non-standard shift of origin" 
+    RadioButtons .ifso.frame var top \
+	"Origin derived from the symbol (IFSO=0)" \
+	"Standard shift of origin (IFSO=1)" \
+	"Non-standard shift of origin (IFSO=2)" 
 
     button .ifso.but -text OK -command {set ok 1}
     pack .ifso.but -pady 7 -expand 1
@@ -814,7 +816,7 @@ proc NewInputCancelProc {w} {
 #	     "XCrySDen\n\nA X-based Interactive Input Builder for Crystal95" \
 #	     -font "-adobe-helvetica-bold-o-normal--25-180-100-100-p-138-iso8859-1"
 #    button .xfile_new -text "New File" -command new_file 
-#    button .xfile_open -text "Open File" -command OpenFile
+#    button .xfile_open -text "Open File" -command OpenCyrstalInput
 # 
 #    button .xfile_exit -text "Exit" -command exit_pr
 #
