@@ -12,7 +12,7 @@
 # Copyright (c) 1996-2014 by Anton Kokalj                                   #
 #############################################################################
 
-proc OpenFile {{file {}}} {
+proc OpenCyrstalInput {{file {}}} {
     global fileselect distext Alist species speciesName \
 	    type_group type_group1 job_title \
 	    inp n_groupsel groupsel crdatom XCState system \
@@ -28,7 +28,13 @@ proc OpenFile {{file {}}} {
 
     
     if { $file == "" } { 
-	fileselect "Open CRYSTAL Input" 
+	#fileselect "Open CRYSTAL Input"
+        set fileselect(path) [tk_getOpenFile -defaultextension .r1 \
+                                  -filetypes { 
+                                      {{All Files}           {.*}}
+                                      {{CRYSTAL Input Files} {.r1}}
+                                  } -initialdir $system(PWD) -title "Open CRYSTAL Input"]
+        
     } elseif { [file isdirectory $file]} {
 	set fileselect(path) [tk_getOpenFile -defaultextension .r1 \
 				  -filetypes { 
@@ -102,7 +108,7 @@ proc OpenFile {{file {}}} {
 	    tk_dialog .errm Details "ERROR MESSAGE:\n$errmsg" {} 0 OK
 	}
 	catch {file delete $system(SCRDIR)/xc_tmp.$system(PID)}
-	OpenFile
+	OpenCyrstalInput
 	return	
     } else {
 	# if Crystal95 find out that file is "bad", it has exited
@@ -124,7 +130,7 @@ proc OpenFile {{file {}}} {
 		puts stdout "grep ERROR catched"
 		tk_dialog .idx2 ERROR "Selected file is bad !!" error 0 OK
 		file delete $system(SCRDIR)/xc_tmp.$system(PID)
-		OpenFile
+		OpenCyrstalInput
 		return
 	    }
 	}
@@ -306,7 +312,7 @@ proc OpenFile {{file {}}} {
     set l [label $td.lbl -text "What to do?" -relief raised -bd 2]
     set f [frame $td.frm]
     set b1 [button $f.but1 -text "Modify File" -command \
-	    [list OpenFileModify $tx $td]]
+	    [list OpenCyrstalInputModify $tx $td]]
     puts stdout "tx> $tx"
     set b2 [button $f.but2 -text "View $speciesName" -command \
 	    [list OpFile2ViewMol $tx $td]]
@@ -315,7 +321,7 @@ proc OpenFile {{file {}}} {
 }
 
 
-proc OpenFileModify {tx td} {
+proc OpenCyrstalInputModify {tx td} {
     global fileselect distext species type_group type_group1 \
 	    inp n_groupsel groupsel XCState XCTrace
 
@@ -383,7 +389,7 @@ proc cxxManageExternal {} {
     # if the species is external we need to copy
     # $system(SCRDIR)/external_unit34 to
     # $system(SCRDIR)/$system(ftn_name).34
-    # (see proc OpenFile)
+    # (see proc OpenCyrstalInput)
     
     xcDebug -stderr "cxxManageExternal:: species = $species"
 
