@@ -45,13 +45,25 @@ proc parseComLinArg comopt {
 		    set xcMisc(reduce_to) $option
 		    continue
 		}
+                "--print" {
+                    # print the structure to a file and exit
+                    if { [winfo exists .mesa] } {
+                        set filedir [GetAbsoluteFileName $option]
+			raise .
+                        update
+                        update idletask
+			printTogl .mesa $filedir
+                        update
+                        exit 0
+                    }
+                }
 	    }	
 	    
 	    set filedir [GetAbsoluteFileName $option]
 
 	    if { ! [file exists $filedir] && $tag != "--wien_struct" } {
 		destroy .title
-		ErrorDialog "file \"$filedir\" does not exists !!!"
+		ErrorDialog "file \"$filedir\" does not exist !!!"
 		exit
 	    }
 
@@ -74,23 +86,31 @@ proc parseComLinArg comopt {
 		"--xcr" -
 		"--animxsf" -
 		"--axsf" {
+                    # reload-capable
+                    reloadRegister $filedir XSF
 		    ViewMol .
 		    xsfOpen $filedir .mesa
-		    #ViewMol .
-		    #xsfAnimInit $filedir .mesa
-		}	
+		}
+		"--xsf2" {
+                    # reload-capable
+                    reloadRegister $filedir XSF2
+		    ViewMol .
+		    xsf2Open $filedir .mesa
+		}
 		"--xmol" -
 		"--xyz" {
+                    reloadRegister $filedir XYZ
 		    ViewMol .
 		    xyzOpen $filedir
 		}
 		"--pdb" {
-		    # first convert to xsf format then set state and render
+                    reloadRegister $filedir PDB
 		    ViewMol .
 		    OpenXYZPDB .mesa pdb $filedir
 		}
 		"--fermi" -
 		"--bxsf" {
+                    set xcMisc(titlefile) $filedir
 		    if { [file isfile $filedir] } {
 			genFSInit $filedir
 		    } else {
@@ -99,9 +119,11 @@ proc parseComLinArg comopt {
 		    }
 		}
 
-		"--pw_inp" - "--pwi" {
-		    if [file exists $filedir] {
-			# pop-up Viewer
+		"--pw_inp" -
+                "--pwi" {
+                    # reload-capable
+		    if { [file exists $filedir] } {
+                        reloadRegister $filedir openExtStruct:reload
 			ViewMol .
 			openExtStruct 3 crystal external \
 			    [list sh $system(TOPDIR)/scripts/pwi2xsf.sh] \
@@ -115,9 +137,11 @@ proc parseComLinArg comopt {
 		    }
 		}
 
-		"--pw_out" - "--pwo" {
-		    if [file exists $filedir] {
-			# pop-up Viewer
+		"--pw_out" -
+                "--pwo" {
+                    # reload-capable
+		    if { [file exists $filedir] } {
+                        reloadRegister $filedir openExtStruct:reload
 			ViewMol .
 			openExtStruct 3 crystal external \
 			    [list sh $system(TOPDIR)/scripts/dummy.sh] \
@@ -133,28 +157,28 @@ proc parseComLinArg comopt {
 
 		    
 		"--fhi_inpini" {
-		    if [file exists $filedir] {
-			# pop-up Viewer
+		    if { [file exists $filedir] } {
+                        reloadRegister $filedir openExtStruct:reload
 			ViewMol .
 			openExtStruct 3 crystal external34 \
-				$system(BINDIR)/fhi_inpini2ftn34 \
-				$system(ftn_name).34 {FHI98MD "ini.inp"} \
-				BOHR -file $filedir \
-				-preset [list fhiPreset inpini]
+                            $system(BINDIR)/fhi_inpini2ftn34 \
+                            $system(ftn_name).34 {FHI98MD "ini.inp"} \
+                            BOHR -file $filedir \
+                            -preset [list fhiPreset inpini]
 		    } else {
 			ErrorDialog "$filedir doesn't exists !!!"
 			exit
 		    }
 		}
 		"--fhi_coord" {
-		    if [file exists $filedir] {
-			# pop-up Viewer
+		    if { [file exists $filedir] } {
+                        reloadRegister $filedir openExtStruct:reload
 			ViewMol .
 			openExtStruct 3 crystal external \
-				$system(BINDIR)/fhi_coord2xcr \
-				fhi_coord.xcr {FHI98MD "coord.out"} \
-				BOHR -file $filedir \
-				-preset [list fhiPreset coord]
+                            $system(BINDIR)/fhi_coord2xcr \
+                            fhi_coord.xcr {FHI98MD "coord.out"} \
+                            BOHR -file $filedir \
+                            -preset [list fhiPreset coord]
 		    } else {
 			ErrorDialog "$filedir doesn't exists !!!"
 			exit
@@ -168,7 +192,7 @@ proc parseComLinArg comopt {
 		"--crystal_inp" {
 		    if { [file exists $filedir] } {
 			ViewMol .
-			OpenFile $filedir
+			OpenCyrstalInput $filedir
 		    } else {
 			ErrorDialog "$filedir doesn't exists !!!"
 			exit
@@ -201,9 +225,9 @@ proc parseComLinArg comopt {
 			ErrorDialog "$filedir is neither directory, neither filehead, niether file"
 			exit
 		    }
-		    # pop-up Viewer
+                    reloadRegister $file WIEN2k
 		    ViewMol .
-		    wnOpenSFile $file; # maybe vice-versa first wnOpenSFile and then ViewMol file
+		    wnOpenSFile $file
 		}
 		"--wien_kpath" {
 		    # struct file must be read, and converted
@@ -216,7 +240,7 @@ proc parseComLinArg comopt {
 			wnDetComOpt $dir
 			wnKPath $filedir			
 		    } else {
-			ErrorDialog "$filedir directory|file does not exists !!!"
+			ErrorDialog "$filedir directory|file does not exist !!!"
 			exit
 		    }
 		}
@@ -230,7 +254,7 @@ proc parseComLinArg comopt {
 			wnOpenSFile $file
 			wnDensity $filedir
 		    } else {
-			ErrorDialog "$filedir directory does not exists !!!"
+			ErrorDialog "$filedir directory does not exist !!!"
 			exit
 		    }
 		}
@@ -246,7 +270,7 @@ proc parseComLinArg comopt {
 			# pop-up decision window
 			wnDensity2D_or_3D $filedir
 		    } else {
-			ErrorDialog "$filedir directory does not exists !!!"
+			ErrorDialog "$filedir directory does not exist !!!"
 			exit
 		    }		    
 		}
@@ -256,34 +280,51 @@ proc parseComLinArg comopt {
 			wnDetComOpt $filedir
 			wnFSInit $filedir
 		    } else {
-			ErrorDialog "$filedir directory does not exists !!!"
+			ErrorDialog "$filedir directory does not exist !!!"
 			exit
 		    }
 		}
 		"--gzmat" {
+                    reloadRegister $filedir GZMAT
+                    ViewMol .
 		    gzmat $filedir
 		}
 		"--g98_out" -
 		"--gXX_out" - 
 		"--gxx_out" -
 		"--gaussian_out" {
+                    # reload-capable
+                    reloadRegister $filedir addOption:reload
 		    # this option is done via new addOption interface ...
 		    addOption:hardcoded \
 			[list sh $system(TOPDIR)/scripts/g98toxsf.sh] $filedir
 		}
 		"--cube" -		
+		"--gxx_cube" -
 		"--gXX_cube" -
 		"--g98_cube" {
 		    g98Cube $filedir
 		}
+		"--orca_out" {
+                    # reload-capable
+                    reloadRegister $filedir addOption:reload
+		    # this option is done via new addOption interface ...
+		    addOption:hardcoded \
+			[list sh $system(TOPDIR)/scripts/orca2xsf.sh] $filedir
+		}
 		"-s" -
 		"--script" {
 		    scripting::source $filedir		    
 		}
+                "--os" -
+                "--oldscript" {
+                    scripting::oldscript $filedir	
+                }
 		default {
 		    #
 		    # check for user-custom options
-		    addOption:parse $tag $filedir
+		    reloadRegister $filedir addOption:reload
+                    addOption:parse $tag $filedir
 		}
 	    }
 	}
@@ -291,9 +332,6 @@ proc parseComLinArg comopt {
 	
     if { $i%2 } {
 	XCrySDenUsage
-	#tk_dialog .mb_error1 Error \
-	#	"ERROR: You called XCrySDen with an odd number of args !" \
-	#	error 0 OK
     }
     unset i
 
@@ -310,7 +348,7 @@ proc parseComLinArg comopt {
 }
 
 
-proc UpdateWMTitle file {
+proc UpdateWMTitle {file} {
     global xcMisc system
     
     set xcMisc(titlefile) $file
