@@ -9,7 +9,7 @@
 #                                                                           #
 # Source: $XCRYSDEN_TOPDIR/Tcl/propC95.tcl                                       
 # ------                                                                    #
-# Copyright (c) 1996-2003 by Anton Kokalj                                   #
+# Copyright (c) 1996-2014 by Anton Kokalj                                   #
 #############################################################################
 
 proc PropC95Cmd {cmd} {
@@ -201,7 +201,7 @@ proc NEWK_Init {} {
 
     if { $periodic(dim) > 0 } {
 	set t [xcToplevel .bwid "NEWK Options" "NEWK" . 100 50 1]
-	grab $t
+	catch { grab $t }
 	set f1 [frame $t.f1 -relief raised -bd 2]
 	pack $f1 -side top -fill both -ipady 10
 	frame $f1.f1 -relief flat
@@ -215,7 +215,7 @@ proc NEWK_Init {} {
 	}
 	pack $f1.f1 $f1.f2 -side top -padx 10 -fill both -expand 1
 	
-	if { $system(c95_version) != "06" && $system(c95_version) != "09" } {
+	if { $system(c95_version) != "06" && $system(c95_version) != "09" && $system(c95_version) != "14" } {
 	    #
 	    # CRYSTAL prior to version-06
 	    #
@@ -224,7 +224,7 @@ proc NEWK_Init {} {
 		"Same as in SCF" "New (IS,ISHF,ISP) values" 
 	} else {
 	    #
-	    # CRYSTAL06
+	    # CRYSTAL06 or later
 	    #
 	    RadioButVarCmd $f1.f1 "Which (IS,ISP) values to take:" \
 		newk(option) NEWK_RadioButCmd top left 1 1 \
@@ -268,14 +268,14 @@ proc NEWK_Init {} {
     #
 
     set    input "NEWK\n"
-    if { $system(c95_version) != "06" && $system(c95_version) != "09" } {
+    if { $system(c95_version) != "06" && $system(c95_version) != "09" && $system(c95_version) != "14" } {
 	#
 	# CRYSTAL prior to version-06
 	#
 	append input "$prop(IS) $prop(ISHF) $prop(ISP)\n"
     } else {
 	#
-	# CRYSTAL06
+	# CRYSTAL06 or later
 	#
 	append input "$prop(IS) $prop(ISP)\n"
     }	
@@ -311,7 +311,7 @@ proc NEWK_IS_ISHF_ISP {} {
     set f11 [frame $t.f11 -relief raised -bd 2]
     set f2  [frame $t.f2 -relief raised -bd 2]
 
-    if { $system(c95_version) != "06" && $system(c95_version) != "09" } {
+    if { $system(c95_version) != "06" && $system(c95_version) != "09" && $system(c95_version) != "14" } {
 	#
 	# CRYSTAL prior to version-06
 	#
@@ -320,7 +320,7 @@ proc NEWK_IS_ISHF_ISP {} {
 	set foclist [list $f1.frame.entry1 $f1.frame.entry2 $f1.frame.entry3]
     } else {
 	#
-	# CRYSTAL06
+	# CRYSTAL06 or later
 	#
 	Entries $f1 {IS: ISP:} {prop(IS) prop(ISP)} 2
 	set varlist [list {prop(IS) posint} {prop(ISP) posint}]
@@ -343,15 +343,15 @@ proc NEWK_IS_ISHF_ISP {} {
     pack $ok $can -side left -expand 1 -padx 10 -pady 10
 
     update
-    grab $t
+    catch { grab $t }
 
     tkwait variable ok
-    if [winfo exists $t] { 
-	grab release $t
+    if { [winfo exists $t] } { 
+	catch { grab release $t }
 	destroy $t 
     }
     if { $oldgrab != "" } {
-	grab $oldgrab
+	catch { grab $oldgrab }
     }
 }
 
@@ -372,8 +372,8 @@ proc NEWK_Can {t} {
 
     set done 1
     set newk(cancel) 1
-    if [winfo exists $t] { 
-	grab release $t
+    if { [winfo exists $t] } { 
+	catch { grab release $t }
 	destroy $t 
     }
 }
@@ -385,8 +385,8 @@ proc NEWK_OK {t} {
     puts stdout "NEWK_OK"
     set done 1
     set newk(cancel) 0
-    if [winfo exists $t] { 
-	grab release $t
+    if { [winfo exists $t] } { 
+	catch { grab release $t }
 	destroy $t 
     }
 }
@@ -459,7 +459,7 @@ proc DOSS_Init {} {
     set doneDOSS 0
 
     set t [xcToplevel [WidgetName] "Density od States" "DOSS" . 100 50 1]
-    grab $t
+    catch { grab $t }
     set f [frame $t.f -relief raised -bd 2]
     set f2 [frame $t.f2 -relief raised -bd 2]    
     set f3 [frame $t.f3 -relief raised -bd 2]
@@ -614,8 +614,8 @@ proc DOSS_Init2 {t varlist foclist} {
     }
 
     xcDebug "DOSS_Init2:: $prop(NPRO)    $prop(doss_criteria)"
-    if [winfo exists $t] {
-	grab release $t
+    if { [winfo exists $t] } {
+	catch { grab release $t }
 	destroy $t
     }
 
@@ -632,7 +632,7 @@ proc PDOSS_Init {} {
     global prop donePDOSS
 
     set t [xcToplevel .npro "Projected DOSS" "PDOSS" . 100 50 1]
-    grab $t
+    catch { grab $t }
     set fb [frame $t.fb]
     pack $fb -side bottom -expand true -fill both 
     # and one frame where canvas&scrollbar will be!!
@@ -698,7 +698,7 @@ proc PDOSS_Init {} {
     
     tkwait variable donePDOSS
     
-    grab release $t
+    catch { grab release $t }
     destroy $t
 }
 
@@ -773,7 +773,7 @@ proc SelectItems {title num} {
     # if .sband already exists, return silenlty
     if [winfo exists .sband] { return }
     set t [xcToplevel .sband $title $title . 100 50 1]
-    grab $t
+    catch { grab $t }
     # in the future I will have to know whether I'm dealing with 
     # close or open shell
     set bandlist ""
@@ -798,7 +798,9 @@ proc SelectItems {title num} {
     
     tkwait variable done
     destroy $t
-    if { $oldgrab != "" } { grab $oldgrab }
+    if { $oldgrab != "" } { 
+	catch { grab $oldgrab }
+    }
     return $value
 }
 
