@@ -141,7 +141,7 @@ proc PropC95 {{path {}}} {
     xcAppendState render
     xcUpdateState
     GenGeomDisplay
-    OpenStruct .mesa $system(SCRDIR)/xc_struc.$system(PID)
+    OpenXSFStruct .mesa $system(SCRDIR)/xc_struc.$system(PID)
 }
 
 
