@@ -12,14 +12,40 @@
 # Copyright (c) 1996-2003 by Anton Kokalj                                   #
 #############################################################################
 
-proc saveState {} {
+# saveState ?state_and_structure? --> save structure and state
+# saveState state --> sane only state
+proc saveState {{what state_and_structure}} {
     global saveState
 
-    # --------------------------------------------------
-    # first remember the loaded file
-    # --------------------------------------------------
+    # get the filename to write the script into
+
+    saveStruct:_queryFilename $what
+
+    # open the channel for writing the script into
     
-    set wID [saveStruct:_xsfFile]; # wID == write-file channel ID
+    set wID [open $saveState(file) w]
+    set saveState(wID) $wID
+
+    # write the top info-head
+    
+    saveStruct:_writeInfoHead $wID $what
+
+    # write the Structure
+    if { $what == "state_and_structure" } {
+        saveStruct:_writeStructure $wID
+    }
+
+    # write the State
+    
+    saveStruct:_writeState $wID
+
+    # close the channel
+    
+    flush $wID
+    close $wID    
+}
+
+proc saveStruct:_writeState {wID} {
 
     puts $wID {
 
@@ -57,7 +83,7 @@ proc saveState {} {
     # remember the size of the main window
     # --------------------------------------------------
 
-    saveState:header "size of the main window fonts"
+    saveState:header "size of the main window"
     set w [winfo width  .]
     set h [winfo height .]
     puts $wID "wm geometry . ${w}x${h}"
@@ -96,40 +122,19 @@ proc saveState {} {
     # Take care of MODIFY menu parameters
     # ------------------------------------------------------------------------
 
-    # This item must be the first one:
-    # Number of Units Drawn (must be after DISPLAY-menu checkbuttons)
-    global nxdir nydir nzdir
-    saveState:header "Number of Units Drawn"
-    puts $wID "set nxdir $nxdir"
-    puts $wID "set nydir $nydir"
-    puts $wID "set nzdir $nzdir"
+    # N.B: loading of script is very slow if (nxdir,nydir,nzdir) are
+    # specified that soon, consider shifting just befor the xc_rotationmatrix
 
-    # Atomic-Labels/Fonts
-    global atomLabel
-    saveState:beginHeader "Atomic-Labels/Fonts"
-    puts $wID "array set atomLabel [list [array get atomLabel]]"
-    puts $wID "set t \[ModAtomLabels\]"
-    puts $wID ".mesa xc_setfont \
-        [list $atomLabel(globalFont)] \
-        [list $atomLabel(globalFont.brightColor)] \
-        [list $atomLabel(globalFont.darkColor)]"
-    foreach name [array names atomLabel *.atomFont.label] {
-	#regsub ?switches? exp string subSpec varName
-	regsub -- {\.atomFont\.label$} $name {} id
-	
-	puts $wID ".mesa xc_setatomlabel $id \
-          [list $atomLabel($id.atomFont.label)] \
-          [list $atomLabel($id.atomFont.font)] \
-          [list $atomLabel($id.atomFont.brightColor)] \
-          [list $atomLabel($id.atomFont.darkColor)]"
-    }
-    puts $wID "ModAtomLabels:advancedCheckButton default"
-    puts $wID "ModAtomLabels:advancedCheckButton custom"
-    puts $wID "ModAtomLabels:advancedCloseUpdate dummy update"
-    puts $wID "CancelProc \$t"
-    saveState:endHeader
+    # t.k. TESTING: let's how it works if this is shifted down !!!
     
-
+    # # This item must be the first one:
+    # # Number of Units Drawn (must be after DISPLAY-menu checkbuttons)
+    # global nxdir nydir nzdir
+    # saveState:header "Number of Units Drawn"
+    # puts $wID "set nxdir $nxdir"
+    # puts $wID "set nydir $nydir"
+    # puts $wID "set nzdir $nzdir"
+  
     saveState:beginHeader "Various colors"
 
     # Atomic-Color
@@ -395,18 +400,12 @@ proc saveState {} {
 	saveState:endHeader
     }
 
-    # --------------------------------------------------
-    # rotation matrix and zooming factor, and translation displacements
-    # --------------------------------------------------
-
-    xcDebug -stderr "saving rotations/translations ..."
-
-    saveState:header "rotation matrix and zooming factor, and translation displacements"
-    puts $wID "xc_rotationmatrix set [xc_rotationmatrix get]"
-    puts $wID "xc_translparam    set [xc_translparam get]"
-    puts $wID ""
-    puts $wID "# this is used to force the update of display"
-    puts $wID ".mesa cry_toglzoom 0.0"
+    # t.k. EXPERIMENTAL: testing for faster speed !!!
+    global nxdir nydir nzdir
+    saveState:header "Number of Units Drawn"
+    puts $wID "set nxdir $nxdir"
+    puts $wID "set nydir $nydir"
+    puts $wID "set nzdir $nzdir"
 
     # --------------------------------------------------
     # PseudoDensity & Anti-Aliasing & Depth Cuing (they are the most
@@ -418,6 +417,52 @@ proc saveState {} {
     saveState:header "Anti-Aliasing & Depth-Cuing & PseudoDensity (these are time consuming)"
     puts $wID "DepthCuing; PseudoDensity; AntiAlias"    
 
+    # update the display
+    if { $periodic(dim) > 0 } {
+	saveState:header "update the display"
+	puts $wID "CellMode 1"
+    }
+
+    #------------------------------------------------------------------------
+    # Atomic-Labels/Fonts
+    #------------------------------------------------------------------------
+    global atomLabel
+    saveState:beginHeader "Atomic-Labels/Fonts"
+    puts $wID "array set atomLabel [list [array get atomLabel]]"
+    puts $wID "set t \[ModAtomLabels\]"
+    puts $wID "xc_setfont .mesa \
+        [list $atomLabel(globalFont)] \
+        [list $atomLabel(globalFont.brightColor)] \
+        [list $atomLabel(globalFont.darkColor)]"
+    foreach name [array names atomLabel *.atomFont.label] {
+	#regsub ?switches? exp string subSpec varName
+	regsub -- {\.atomFont\.label$} $name {} id
+	
+	puts $wID "xc_setatomlabel .mesa $id \
+          [list $atomLabel($id.atomFont.label)] \
+          [list $atomLabel($id.atomFont.font)] \
+          [list $atomLabel($id.atomFont.brightColor)] \
+          [list $atomLabel($id.atomFont.darkColor)]"
+    }
+    puts $wID "ModAtomLabels:advancedCheckButton default"
+    puts $wID "ModAtomLabels:advancedCheckButton custom"
+    puts $wID "ModAtomLabels:advancedCloseUpdate dummy update"
+    puts $wID "CancelProc \$t"
+    saveState:endHeader
+
+    # --------------------------------------------------
+    # rotation matrix and zooming factor, and translation displacements
+    # --------------------------------------------------
+
+    xcDebug -stderr "saving rotations/translations ..."
+
+    saveState:header "rotation matrix and zooming factor, and translation displacements"
+    puts $wID "xc_rotationmatrix set [xc_rotationmatrix get]"
+    puts $wID "xc_translparam    set [xc_translparam get]"
+    puts $wID ""
+    puts $wID "# this is used to force the update of display"
+    puts $wID "cry_toglzoom .mesa 0.0"
+
     # --------------------------------------------------
     # reset cursor and delete the "waiting" window
     # --------------------------------------------------
@@ -425,18 +470,14 @@ proc saveState {} {
     puts $wID "set xcCursor(dont_update) 0"
     puts $wID "ResetCursor"
     puts $wID "destroy \$wait_window"
-    
-    flush $wID
-    close $wID    
 }
 
 
 
+proc saveStruct:_queryFilename {what} {
+    global system saveState
 
-proc saveStruct:_xsfFile {} {
-    global saveState system env mody xcMisc
-
-    if { ![xcIsActive render] } { return }
+    if { ![xcIsActive render] } { return -code return }
 
     set filetypes {
 	{{XCrySDen Files}         {.xcrysden}    }
@@ -444,8 +485,13 @@ proc saveStruct:_xsfFile {} {
 	{{All Files}              *              }
     }
 
+    if { $what == "state" } {
+        set title "Save Current State"
+    } else {
+        set title "Save Current State and Structure"
+    }
     set saveState(file) [tk_getSaveFile -initialdir $system(PWD) \
-			     -title "Save Current State and Structure" \
+			     -title $title \
 			     -defaultextension .xcrysden \
 			     -filetypes $filetypes]
     
@@ -454,10 +500,20 @@ proc saveStruct:_xsfFile {} {
     if { $saveState(file) == "" } { 	
 	return -code return
     }
+
+    # open the channel for writing the script into
+    set saveState(wID) [open $saveState(file) w]
+
+    return $saveState(wID)
+}
+
+proc saveStruct:_writeStructure {wID} {
+    global system mody
     
     # --------------------------------------------------
     # non-XSF to XSF transformations (i.e. Take care of PDB & XYZ files) 
     # --------------------------------------------------
+    
     set FORMAT_NONE  0
     set FORMAT_XSF   1
     set FORMAT_XYZ   2
@@ -467,9 +523,9 @@ proc saveStruct:_xsfFile {} {
 	return -code return
     }
 
-    set file [xcTempFile xc_xsf]
-    xc_writeXSF $file        
-
+    set xsf_tmp_file [xcTempFile xc_xsf]
+    xc_writeXSF $xsf_tmp_file        
+    
     # ------------------------------
     # Take care of CRYSTAL98 Properties
     # ------------------------------
@@ -480,48 +536,24 @@ proc saveStruct:_xsfFile {} {
 	# rendering the isosurface/contours, then this requires some
 	# special treatment.
 	if { $prop(datagridDim) == 2 || $prop(datagridDim) == 3 } {
-	    saveState:_saveDatagrid $file
+	    saveState:_saveDatagrid $xsf_tmp_file
 	} 
     }
-    
+
     # --------------------------------------------------
-    # the XSF file is stored in $file, start writing the XSF part of
+    # the XSF file is stored in $xsf_tmp_file, write the XSF part of
     # *.xcrysden script
     # --------------------------------------------------
 
-    set rID [open $file r]
-    set wID [open $saveState(file) w]
-    set saveState(wID) $wID
-    set date     "Xxx Xxx XX XX:XX:XX CEST 20XX"
-    set user     "unknown"
-    set hostname "localhost"
-    set domain   "local"
-    catch {set date     [clock format [clock seconds]]}
-    catch {set user     $env(USER)}
-    catch {set hostname $env(HOSTNAME)}
-    catch {set domain   [exec dnsdomainname]}
-    set fileHeader [subst {
-# ------------------------------------------------------------------------
-# This is the script saved via the XCRYSDEN "File-->Save Current State
-# and Structure" menu. This feature saves the currently displayed
-# structure. When it will be loaded again it will recall all the
-# display parameters, such as orientation, zoom, perspective, ...
-#
-# Execute this script as: xcrysden --script this_file_name
-#
-# File created by $user on $hostname.$domain
-# File creation date: $date    
-# ------------------------------------------------------------------------
-
-
+    puts $wID {
+        
 # ======================================================================== #
 #                                                                          #
 #                      STRUCTURE-PART OF THE FILE                          #
 #                                                                          #
 # ======================================================================== #
 
-    }]
-    puts $wID $fileHeader    
+    }
 
     saveState:beginHeader "XSF structure data"    
     set xsfFile "\$system(SCRDIR)/xc_xsf.\$system(PID)"
@@ -529,7 +561,9 @@ proc saveStruct:_xsfFile {} {
     puts $wID "# Store the content of the XSF file in the xsfStructure variable"
     puts $wID ""
     puts $wID "set xsfStructure \{"
+    set rID [open $xsf_tmp_file r]
     fcopy $rID $wID
+    close $rID
 
     # check for scalar field
     global sInfo prop DataGrid
@@ -567,16 +601,7 @@ proc saveStruct:_xsfFile {} {
     puts $wID ""
     puts $wID "WriteFile $xsfFile \$xsfStructure w"
     puts $wID ""
-    # ------------------------------------------------------------------------
-    # convert atomic-names to atomic-numbers
-    # ------------------------------------------------------------------------
-    #puts $wID "catch \{exec \$system(BINDIR)/xsf2xsf $xsfRawFile $xsfFile\}"
-    # ------------------------------------------------------------------------
-    #puts $wID "xc_openstr xcr $xsfFile .mesa PL"
     puts $wID "::scripting::open --xsf $xsfFile"
-    #puts $wID "UpdateWMTitle [file tail $saveState(file)]"
-    #puts $wID "set working_XSF_file $xsfFile"
-    #puts $wID "Get_sInfoArray\nDisplayDefaultMode\nxcAppendState render\nxcUpdateState"
 
     saveState:endHeader
    
@@ -642,9 +667,8 @@ proc saveState:fontCreate {font args} {
 
 
 
-proc saveState:_saveDatagrid {file} {
+proc saveState:_saveDatagrid {xsf_tmp_file} {
     global xcMisc system isoControl DataGrid DG
-
     
     set gridFile [xcTempFile xc_xsf_datagrid]
 
@@ -675,7 +699,7 @@ proc saveState:_saveDatagrid {file} {
      }
     
     # take care about the newlines
-    set content   [ReadFile -nonewline $file]
+    set content   [ReadFile -nonewline $xsf_tmp_file]
     set datablock 0
     set out       {}
     foreach line [split $content \n] {
@@ -693,5 +717,46 @@ proc saveState:_saveDatagrid {file} {
     append out "$ident\n"
     append out [ReadFile -nonewline $gridFile]
     append out "\nEND_BLOCK_$dg"
-    WriteFile $file $out w
+    WriteFile $xsf_tmp_file $out w
 }
+
+proc saveStruct:_writeInfoHead {wID what} {
+    global saveState env
+
+    set date     "Xxx Xxx XX XX:XX:XX CEST 20XX"
+    set user     "unknown"
+    set hostname "localhost"
+    set domain   "local"
+    catch {set date     [clock format [clock seconds]]}
+    catch {set user     $env(USER)}
+    catch {set hostname $env(HOSTNAME)}
+    catch {set domain   [exec dnsdomainname]}
+
+    if { $what != "state" } {
+        puts $wID [subst {
+# ------------------------------------------------------------------------
+# This is the script saved via the "File-->Save Current State and
+# Structure" menu. This feature saves the currently displayed
+# structure. When it will be loaded again it will recall all the
+# display parameters, such as orientation, zoom, perspective, ...
+#
+# Execute this script as: xcrysden --script $saveState(file)
+#
+# File created by $user on $hostname.$domain
+# File creation date: $date    
+# ------------------------------------------------------------------------
+        }]
+    } else {
+        puts $wID [subst {
+# ------------------------------------------------------------------------
+# This is a script saved via the "File-->Save Current State" menu. It
+# is useful for the user written scripts as to get the desired "state"
+# of display, but as standalone this script is useless.
+#
+# File created by $user on $hostname.$domain
+# File creation date: $date    
+# ------------------------------------------------------------------------
+        }]
+    }
+}
+
