@@ -174,7 +174,7 @@ proc scripting::atomicLabels::global {args} {
 
     _parseOptions global $args
 
-    .mesa xc_setfont \
+    xc_setfont .mesa \
 	$atomicLabels(global.font) \
 	$atomicLabels(global.brightcolor) \
 	$atomicLabels(global.darkcolor)
@@ -261,7 +261,7 @@ proc scripting::atomicLabels::atomID {atomID args} {
     _checkAtomID     atomID $atomID    
     _mapCustomValues $atomID 
 
-    .mesa xc_setatomlabel $atomID \
+    xc_setatomlabel .mesa $atomID \
 	$atomicLabels(atomID.$atomID.label) \
 	$atomicLabels(atomID.$atomID.font) \
 	$atomicLabels(atomID.$atomID.brightcolor) \
@@ -358,7 +358,7 @@ proc scripting::atomicLabels::atomType {atomType args} {
 
 	    _mapCustomValues $id
 
-	    .mesa xc_setatomlabel $id \
+	    xc_setatomlabel .mesa $id \
 		$atomicLabels(atomID.$id.label) \
 		$atomicLabels(atomID.$id.font) \
 		$atomicLabels(atomID.$id.brightcolor) \
@@ -535,13 +535,13 @@ proc scripting::atomicLabels::clear {mode args} {
     switch -exact -- $mode {
 	"all" {
 	    # usage: clear all
-	    .mesa xc_clearatomlabel all
+	    xc_clearatomlabel .mesa all
 	}
 	
 	"atomID" {
 	    # usage: render atomID id on|off
 	    _checkAtomID render $args
-	    .mesa xc_clearatomlabel $args
+	    xc_clearatomlabel .mesa $args
 	}
 	
 	"atomType" {
@@ -550,7 +550,7 @@ proc scripting::atomicLabels::clear {mode args} {
 	    set natoms     [xc_getvalue $mody(GET_NATOMS)]
 	    for {set id 1} {$id <= $natoms} {incr id} {
 		if { [xc_getvalue $mody(GET_NAT) $id] == $nat } {
-		    .mesa xc_clearatomlabel $id
+		    xc_clearatomlabel .mesa $id
 		}
 	    }
 	}
