@@ -59,19 +59,19 @@ namespace eval scripting::filter {}
 #****f* Scripting/scripting::filter::g98cube
 #
 # NAME
-# scripting::filter::g98cube
+# scripting::filter::gXXcube
 #
 # USAGE
-# scripting::filter::g98cube cube_file mo_index
+# scripting::filter::gXXcube cube_file mo_index
 #
 # PURPOSE
 
 # This proc is used in XCRYSDEN scripts to display a particular
 # molecular orbital (MO) from Gaussian cube-file by specifying the
 # "mo_index", which is the ID of the MO as specified in the Gaussian
-# cube-file. Using instead the "scripting::open --g98_cube cube_file"
+# cube-file. Using instead the "scripting::open --gXX_cube cube_file"
 # proc will result in querying the mo_index. Hence this proc differs
-# from "scripting::open --g98_cube cube_file" in that the mo_index is
+# from "scripting::open --gXX_cube cube_file" in that the mo_index is
 # already specified explicitly and is therefore not queried.
 
 #
@@ -83,10 +83,12 @@ namespace eval scripting::filter {}
 # Undefined.
 #
 # EXAMPLE
-# scripting::filter::g98cube molecular_orbitals.cube 11
+# scripting::filter::gXXcube molecular_orbitals.cube 11
 #****
 # ------------------------------------------------------------------------
-
+proc scripting::filter::gXXcube  {cube_file mo_index} {
+    uplevel { scripting::filter::g98cube $cube_file $mo_index }
+}
 proc scripting::filter::g98cube {cube_file mo_index} {
     global g98
 
@@ -97,7 +99,7 @@ proc scripting::filter::g98cube {cube_file mo_index} {
     
     set ind [lsearch $files $mo_file]
     if { $ind == -1 } {
-	ErrorDialog "molecular orbital with index $mo_index does not exists in cube file: $cube_file"
+	ErrorDialog "molecular orbital with index $mo_index does not exist in cube file: $cube_file"
 	exit
     }
     set mo_file [lindex $files $ind]
@@ -139,7 +141,7 @@ proc scripting::filter::crystalInput {crystalInput_file} {
 
     set crystalInput_file [_init $crystalInput_file]
     
-    OpenFile $crystalInput_file
+    OpenCyrstalInput $crystalInput_file
     if { [xcIsActive c95] } {
 	CalStru
 	foreach t $crystalInput(two_toplevels) {
@@ -201,6 +203,10 @@ proc scripting::filter::pwscfInput {pwscfInput_file reduce {itypNatList {}}} {
     _pwscfInputCheckItypNatList $pwscfInput_file $itypNatList
     _pwscf scripting::filter::pwscfInput $pwscfInput_file $reduce $itypNatList
 
+    # reload-capable
+    
+    reloadRegister $pwscfInput_file openExtStruct:reload
+
     # load the structure
 
     openExtStruct 3 crystal external \
@@ -268,6 +274,14 @@ proc scripting::filter::pwscfOutput {option pwscfOutput_file reduce {itypNatList
     set pwscfOutput_file [_absoluteFilename $pwscfOutput_file]
     _pwscfOutputCheckItypNatList $pwscfOutput_file $itypNatList
     _pwscf scripting::filter::pwscfOutput $pwscfOutput_file $reduce $itypNatList
+
+    # reload-capable
+    global openExtStruct
+    set openExtStruct(state)   external
+    set openExtStruct(program) [list sh $system(TOPDIR)/scripts/dummy.sh]
+    set openExtStruct(program_output) pwo2xsf.xsf
+    
+    reloadRegister $pwscfOutput_file openExtStruct:reload
     
     # load the structure
     
@@ -286,8 +300,7 @@ proc scripting::filter::pwscfOutput {option pwscfOutput_file reduce {itypNatList
 
     pwOutputPresetWhat dummy $pwscfOutput_file
     set xsf [ReadFile $system(SCRDIR)/pwo2xsf.xsf]
-    puts stderr "XSF = \n$xsf"
-    xsfOpen $system(SCRDIR)/pwo2xsf.xsf .mesa
+    xsfOpenParsed $system(SCRDIR)/pwo2xsf.xsf .mesa
 }
 
 
@@ -435,6 +448,9 @@ proc scripting::filter::fhiInpini {fhiInpini_file reduce nameNatList} {
     set fhiInpini_file [_absoluteFilename $fhiInpini_file]
     _fhi scripting::filter::fhiInpini $fhiInpini_file $reduce $nameNatList
 
+    # reload-capable    
+    reloadRegister $fhiInpini_file openExtStruct:reload
+
     openExtStruct 3 crystal external34 \
 	$system(BINDIR)/fhi_inpini2ftn34 \
 	$system(ftn_name).34 {FHI98MD "ini.inp"} \
@@ -486,6 +502,8 @@ proc scripting::filter::fhiCoord {fhiCoord_file reduce nameNatList} {
     
     set fhiCoord_file [_absoluteFilename $fhiCoord_file]
     _fhi scripting::filter::fhiCoord $fhiCoord_file $reduce $nameNatList
+
+    reloadRegister $fhiCoord_file openExtStruct:reload
     
     openExtStruct 3 crystal external \
 	$system(BINDIR)/fhi_coord2xcr \
@@ -581,7 +599,7 @@ proc scripting::filter::_init {file} {
     set file [_absoluteFilename $file]
 
     if { ! [file exists $file] } {
-	ErrorDialog "File $file does not exists"
+	ErrorDialog "File $file does not exist"
 	exit
     }
     return $file
