@@ -180,7 +180,7 @@ proc xcIsActive {word} {
     # external    .... when reading structre from some external file format
     # external34  .... when reading structre from some external file format 
     #                  via FORT.34; !!! *** probably temporal *** !!!
-    if ![info exists XCState(state)] { return 0 }
+    if { ![info exists XCState(state)] } { return 0 }
     return [string match *${word}* $XCState(state)]
 }
 
@@ -199,6 +199,7 @@ proc xcUpdateState {{menu .menu} {menu2 .menu}} {
 	Close 
 	{Save XSF Structure} 
 	{Save Current State and Structure}
+	{Save Current State}
 	{Save CRYSTAL Input} 
 	{Save WIEN2k Struct File} 
 	Print* 
@@ -253,8 +254,13 @@ proc xcUpdateState {{menu .menu} {menu2 .menu}} {
 				   $menu.vmdat  "Tools"]
 
 	# for "render state" enable in File menu:
-	foreach entry { Close {Save XSF Structure} 
-	    {Save Current State and Structure} Print* } {
+	foreach entry {
+            Close
+            {Save XSF Structure} 
+	    {Save Current State and Structure}
+	    {Save Current State}
+            Print*
+        } {
 	    $menu.vmfile${menu2} entryconfig $entry -state normal
 	}
 	
@@ -350,6 +356,8 @@ proc xcUpdateState {{menu .menu} {menu2 .menu}} {
 	xcEnableAll .ctrl .mea
 	# disable PLANE button (temporarily)
 	#xcDisableOne .mea.f1.pln
+
+        reloadButtonQueryState
     }
     
     if { [xcIsActive render] && [xcIsActive c95] && ![xcIsActive properties]} {
@@ -363,6 +371,7 @@ proc xcUpdateState {{menu .menu} {menu2 .menu}} {
 	    Close 
 	    {Save XSF Structure} 
 	    {Save Current State and Structure}
+	    {Save Current State}
 	    {Save CRYSTAL Input} 
 	} {
 	    $menu.vmfile${menu2} entryconfig $entry -state normal
@@ -375,6 +384,7 @@ proc xcUpdateState {{menu .menu} {menu2 .menu}} {
 	    Close 
 	    {Save XSF Structure} 
 	    {Save Current State and Structure}
+	    {Save Current State}
 	    {Save CRYSTAL Input} 
 	    {Save WIEN2k Struct File} 
 	} {
@@ -454,13 +464,12 @@ proc xcUpdateState {{menu .menu} {menu2 .menu}} {
         
     global xcMisc
     if { ! [info exists xcMisc(babel)] } {
-	$menu.vmfile${menu2}.opstr entryconfig "Gaussian Z-Matrix File" -state disabled
+	catch { $menu.vmfile${menu2}.opstr entryconfig "Gaussian Z-Matrix File" -state disabled }
     }
 
     # t.k.: this is temporal
     if { ![info exists xcMisc(0.2.x_hexa/rhombo_debug)] } {
-	$menu.vmdis${menu2} entryconfig "Hexagonal/Rhombohedral ..." \
-	    -state disabled
+	$menu.vmdis${menu2} entryconfig "Hexagonal/Rhombohedral ..." -state disabled
     }
 
     if { ![info exists xcMisc(movie_encoder)] && ![info exists xcMisc(gif_encoder)]} {
@@ -544,7 +553,7 @@ proc xcAppendState {word} {
 proc xcDeleteState {word} {
     global XCState
 
-    # if XCState does not exists, there is nothing to delete; return silently
+    # if XCState does not exist, there is nothing to delete; return silently
     if ![info exists XCState(state)] { return }
 
     set statelist [split $XCState(state) _]
@@ -572,12 +581,12 @@ proc xcTrace {name1 name2 op} {
     # this is for Print command in File-menu
     if { $name1 == "species" } {
 	set name [capitalize $species]
-	.menu.vmfile.menu entryconfig Print* -label "Print $name"
+	.menu.vmfile.menu entryconfig Print* -label "Print $name to File"
     } elseif { $name1 == "groupsel" } {
 	# in MODIFY/CHANGE toplevel there is 
 	# "Type of Cell for Rhombohedral Groups" button, which is activ 
 	# only if $groupsel in RHOMBOHEDRAL ONE
-	if [winfo exists $XCTrace(RHOMBO_TYPE_BUTTON)] {
+	if { [winfo exists $XCTrace(RHOMBO_TYPE_BUTTON)] } {
 	    if { [lindex $groupsel 0] == "R" } {
 		$XCTrace(RHOMBO_TYPE_BUTTON) config -state normal
 	    } else {
