@@ -1,7 +1,7 @@
 proc check_stereo {} {
     global stereo_visual
 
-    set togl [togl [WidgetName .] -stereo true \
+    set togl [togl [WidgetName .] -stereo native \
 		  -rgba           true  \
 		  -redsize        1     \
 		  -greensize      1     \
@@ -26,11 +26,11 @@ proc check_stereo {} {
     set stereo [lindex [$togl configure -stereo] end]
     #set stereo [xc_stereo]	
     
-    if { $stereo } {
+    if { $stereo != "none" } {
     	set stereo_visual true
     } else {
     	set stereo_visual false
     }
  
     destroy $togl
-}
\ No newline at end of file
+}
