@@ -362,10 +362,10 @@ proc SetWignerSeitz nc {
     #
     # make widgets for primitive & conventional modes
     #
-    if ![info exists wsp(mode)] {
+    if { ![info exists wsp(mode)] } {
 	set wsp(mode) "every"
     }
-    if ![info exists wsc(mode)] {
+    if { ![info exists wsc(mode)] } {
 	set wsc(mode) "every"
     }
     foreach f [list [list $f1c wsc] [list $f1p wsp]] { 
@@ -696,7 +696,7 @@ proc SetWignerSeitz_OK {mode {t {}}} {
     if { $radio(cellmode) == "prim" } {
 	set render now
     }
-    if { $wsp(mode) == "selected" } {
+    if { [info exists wsp(mode)] && $wsp(mode) == "selected" } {
 	if { [winfo exists $wsp(can)] } {
 	    set n     [GetWignerSeitz_NSel wsp]
 	    set outID [open $system(SCRDIR)/xc_ndsfp.$system(PID) w]
@@ -732,7 +732,7 @@ proc SetWignerSeitz_OK {mode {t {}}} {
     if { $radio(cellmode) == "conv" } {
 	set render now
     }
-    if { $wsc(mode) == "selected" } {
+    if { [info exists wsc(mode)] && $wsc(mode) == "selected" } {
 	if { [winfo exists $wsp(can)] } {
 	    set n     [GetWignerSeitz_NSel wsc]
 	    set outID [open $system(SCRDIR)/xc_ndsfc.$system(PID) w]
