@@ -142,7 +142,7 @@ proc wnDensity2D_or_3D dir {
     #
     set t [xcToplevel [WidgetName] "wnDensity: 2D/3D plot" \
 	    "wnDensity" . 25 50 1]
-    grab $t
+    catch { grab $t }
     set f [frame $t.f -relief raised -bd 2 -class StressText]
     pack $f -fill both -expand 1
     label $f.l -text "Choose 2D/3D Density Plot" -relief groove -bd 2
@@ -151,9 +151,12 @@ proc wnDensity2D_or_3D dir {
     set d3 [button $f.d3 -text "3D Density Plot" \
 	    -command {global wn; set wn(plot_dim) 3D}]
     pack $f.l $d2 $d3 -side top -padx 20 -pady 10 -ipadx 10 -ipady 10
+
     tkwait variable wn(plot_dim)
-    grab release $t
+
+    catch { grab release $t }
     destroy $t
+
     SetIsoGridSpace \
 	    "wnDensity $wn(plot_dim) Map - Grid Specification" "Grid" \
 	    {WIEN} $wn(plot_dim)
