@@ -154,10 +154,10 @@ scripting::multiScript {
     # now lets print to file what we have on the display window
     # ------------------------------------------------------------------------
 
-    scripting::printToFile print.png windowdump    
+    scripting::printToFile print.png 
 
     # we've done all; exit
     exit 0
 }
 
-#******
\ No newline at end of file
+#******
