@@ -23,7 +23,7 @@ if test $nargc -lt 1; then
 fi
 
 # strip XCrySDen- from the $orig_package
-tmp1=${orig_package#XCrySDen-}
+tmp1=${orig_package#xcrysden-}
 
 # check if the package is a binary one
 is_bin=`echo $orig_package | grep bin`
