@@ -5,8 +5,8 @@ do
 #!/bin/sh -f
 
 # simple wrapper to run $cmd
-XCRYSDEN_TOPDIR=$prefix/share/$xcrysden
-XCRYSDEN_LIB_BINDIR=$prefix/lib/$xcrysden
+XCRYSDEN_TOPDIR="$prefix/share/$xcrysden"
+XCRYSDEN_LIB_BINDIR="$prefix/lib/$xcrysden"
 export XCRYSDEN_TOPDIR
 export XCRYSDEN_LIB_BINDIR
 
@@ -14,21 +14,21 @@ EOF
 done
 
 cat >> xcrysden.wrapper <<EOF
-. \$XCRYSDEN_TOPDIR/xcrysden
+. "\$XCRYSDEN_TOPDIR/xcrysden"
 EOF
 
 cat >> pwo2xsf.wrapper <<EOF
-. \$XCRYSDEN_TOPDIR/scripts/pwo2xsf.sh
+. "\$XCRYSDEN_TOPDIR/scripts/pwo2xsf.sh"
 EOF
 
 cat >> pwi2xsf.wrapper <<EOF
-. \$XCRYSDEN_TOPDIR/scripts/pwi2xsf.sh
+. "\$XCRYSDEN_TOPDIR/scripts/pwi2xsf.sh"
 EOF
 
 cat >> ptable.wrapper <<EOF
-\$XCRYSDEN_TOPDIR/util/ptable
+"\$XCRYSDEN_TOPDIR/util/ptable"
 EOF
 
 cat >> unitconv.wrapper <<EOF
-\$XCRYSDEN_TOPDIR/util/unitconv \$@
+"\$XCRYSDEN_TOPDIR/util/unitconv" \$@
 EOF
